set more off
*Table 1
***************************************************************************************
* Robustness check of Paper1
***************************************************************************************
// Paper1: 
*EMX Table 1: EKPC vs EMX  Regression ////////////////////////////////////////////////////////////////////////////////////////////////////////

global path "\Users\Reina Kawai\Downloads\resavingpurpose\input files_non-MONA"
cd "${path}"

use MONA_cleaned, clear
keep if mneumonic=="NGDP"|mneumonic=="NCP"|mneumonic=="NM"|mneumonic=="NX"|mneumonic=="NCG"| ///
mneumonic=="NFIG"|mneumonic=="NFIP"|mneumonic=="NINV"|mneumonic=="NGDP_R"|mneumonic=="PCPI"| ///
|mneumonic=="PCPIE"

// investigate >= 18 mo issue
// yet to be done to find out how many programs were thown out because of 18 mo rule
// check again if there is not some code regarding that earlier in the cleaning process
gen pct_final_t=(t_end-tminus1_end)/tminus1_end if months>=18
gen pct_first_t=(t-tminus1)/tminus1 if months>=18
keep arrangementnumber countryname mneumonic pct_final_t pct_first_t startyear crisis08 ///
america africa asia europe
save MONA_NGDP, replace

local vars="NGDP NCP NM NX NCG NFIG NFIP NINV NGDP_R PCPI"
foreach v in `vars' {
use MONA_NGDP, clear
if("`v'"=="NGDP") {
keep if mneumonic=="`v'"
drop mneumonic
rename pct_final_t `v'_actual
rename pct_first_t `v'_forecast
save NGDP_actual_forecast, replace
}
else {
keep if mneumonic=="`v'"
drop mneumonic
rename pct_final_t `v'_actual
rename pct_first_t `v'_forecast
merge 1:1 arrangementnumber countryname using NGDP_actual_forecast
drop _merge
save NGDP_actual_forecast, replace
}
}


/*
// find out programs with dropped outliers in NEW MONA
// changed code
local vars="NGDP NCP NM NX NCG NFIG NFIP"
use MONA_regression, clear
foreach v in `vars' {
quietly: sum `v'
gen `v'_mean=r(mean)
gen `v'_sd=r(sd)
gen `v'_min_mean=`v'_mean-4*`v'_sd
gen `v'_max_mean=`v'_mean+4*`v'_sd
drop if `v'==.
gen `v'_drop =0
replace `v'_drop = 1 if  `v'<`v'_min_mean|`v'>`v'_max_mean
*drop if `v'<min_mean|`v'>max_mean
*drop _mean _sd min_mean max_mean
}
sort NGDP_drop NCP_drop NM_drop NX_drop NCG_drop NFIG_drop NFIP_drop
// end changed code return to orig code
*/

* Removing 4sd outliers:
local vars="NGDP NCP NM NX NCG NFIG NFIP"
use MONA_regression, clear
foreach v in `vars' {
quietly: sum `v'
gen _mean=r(mean)
gen _sd=r(sd)
gen min_mean=_mean-4*_sd
gen max_mean=_mean+4*_sd
drop if `v'==.
drop if `v'<min_mean|`v'>max_mean
drop _mean _sd min_mean max_mean
}


* LIC/Non-LIC selection:
*keep if LIC==0

* Merge regression samples with MONA data forecasts and actual values:
keep arrangementnumber countryname startmonth
merge 1:1 arrangementnumber countryname using NGDP_actual_forecast
keep if _merge==3
drop _merge

* Run Mincer-Zarnowitz regressions for each GDP component:
local vars="NGDP_R PCPI NGDP NCP NCG NM NX NFIG NFIP"
local counter=0
foreach v in `vars' {
local counter=`counter'+1
rename `v'_forecast forecast
* F-test:
reg `v'_actual forecast crisis08 africa america asia, robust
est store NGDP`counter'
test (_b[_cons]=0) (_b[forecast]=1)
local Fval=r(F)
local pval_F=r(p)
reg `v'_actual forecast crisis08 africa america asia, robust
* Holden-Peel test:
gen ferror=`v'_actual-forecast
reg ferror crisis08 africa america asia, robust
mat cov=e(V)
mat b=e(b)
local b1=b[1,5]
local varb1=cov[5,5]
local seb1=sqrt(`varb1')
local tstatb1=`b1'/`seb1'
local pvalb1=tprob(e(df_r), abs(`tstatb1'))
drop ferror
* Results output:
outreg2 [NGDP`counter'] using MZreg_NGDP.xls, adds(F-test (a = 0 & b = 1), `Fval', ///
p-val (a = 0 & b = 1), `pval_F', Holden-Peel t-Test, `tstatb1', p-val, `pvalb1') excel bdec(3) noaster
rename forecast `v'_forecast
}


import   delimited  MZreg_NGDP.txt,  clear
export   excel using "Output_IMFNowcasts_June27_2021.xlsx", sheet("table1", replace)  firstrow(variables)
 
* Erasing generated files:
erase MZreg_NGDP.xls
erase MZreg_NGDP.txt
erase NGDP_actual_forecast.dta
erase MONA_NGDP.dta

***********Followed EKPC Format of our Analysis
/// Table 1: paper 2 output


cd "${path}"
clear
set more off

use        "X_M_E_6-27-21_updated.dta", clear
*keep if cancelled!="Y"

local      def_var  = "NM_usd"	         // 1. rename variable here!!!!!!!!!!!!!

//erase      regA_`def_var'.xls
//erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
// Paper2 - regressions1: nocontrol
local reg_name  = "paper2_base1"	

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using regA_tableEMX.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel dec(2) 
	


use        "X_M_E_6-27-21_updated.dta", clear
*keep if cancelled!="Y"

local      def_var  = "NX_usd"	         // 1. rename variable here!!!!!!!!!!!!!

//erase      regA_`def_var'.xls
//erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
// Paper2 - regressions1: nocontrol
local reg_name  = "paper2_base2"	

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using regA_tableEMX.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel dec(2) 
			  


use        "X_M_E_6-27-21_updated.dta", clear
*keep if cancelled!="Y"

local      def_var  = "RENDA"	         // 1. rename variable here!!!!!!!!!!!!!

//erase      regA_`def_var'.xls
//erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
// Paper2 - regressions1: nocontrol
local reg_name  = "paper2_base3"	

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using regA_tableEMX.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel dec(2) 


import   delimited  regA_tableEMX.txt,  clear
export   excel using "Output_IMFNowcasts_June27_2021.xlsx", sheet("table1_new", replace)  firstrow(variables)







***********Followed EKPC Format of our Analysis
/// Table 1: paper 2 output


cd "${path}"
clear
set more off

use        "X_M_E_6-27-21_updated.dta", clear
keep if cancelled!="Y"

local      def_var  = "NM_usd"	         // 1. rename variable here!!!!!!!!!!!!!

//erase      regA_`def_var'.xls
//erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
// Paper2 - regressions1: nocontrol
local reg_name  = "paper2_base1b"	

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using regA_tableEMX_CN.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel dec(2) 
	


use        "X_M_E_6-27-21_updated.dta", clear
keep if cancelled!="Y"

local      def_var  = "NX_usd"	         // 1. rename variable here!!!!!!!!!!!!!

//erase      regA_`def_var'.xls
//erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
// Paper2 - regressions1: nocontrol
local reg_name  = "paper2_base2b"	

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using regA_tableEMX_CN.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel dec(2) 
			  


use        "X_M_E_6-27-21_updated.dta", clear
keep if cancelled!="Y"

local      def_var  = "RENDA"	         // 1. rename variable here!!!!!!!!!!!!!

//erase      regA_`def_var'.xls
//erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
// Paper2 - regressions1: nocontrol
local reg_name  = "paper2_base3b"	

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using regA_tableEMX_CN.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel dec(2) 


import   delimited  regA_tableEMX_CN.txt,  clear
export   excel using "Output_IMFNowcasts_June27_2021.xlsx", sheet("table1_CN", replace)  firstrow(variables)


*EMX Table 2: Subsample Regression Results////////////////////////////////////////////////////////////////////////////////////////////////////////

/// Table 2: Nowcast Accuracy by Subsample

cd "${path}"
clear
set more off	  		

*****************  NM_usd  ***************** 

*use        X_M_E_6-27-21_updated, clear

foreach k in "F" "BOP" "float" "fixed"{

foreach m in "F" "NH" "NHLIC" "NHNLIC"{

disp "k is: `k', m is : `m'"

use        "X_M_E_6-27-21_updated.dta", clear

local      def_var  = "NM_usd"	         // 1. rename variable here!!!!!!!!!!!!!

rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
save tempdata.dta, replace

			  
			  
if "`k'"=="float"{
keep if float_dummy == 1
}
if "`k'"=="fixed"{
keep if fixed_dummy == 1
	* Prof Eicher checked 390 Ecuador was dollarized under 2000, and unclear what is the actual base currency
	replace forecast =. if arrangementnumber == 390 & "`i'" == "RENDA"
	replace actual =. if arrangementnumber == 390 & "`i'" == "RENDA"
}

if "`k'"=="BOP"{
keep if !inlist(arrangementtype, "SAF", "PSI", "PRGF-EFF", "PRGF", "PCI", "ESAF")
}


if "`m'"=="NH"{
keep if  dummy_hyper == 0
}

if "`m'"=="NHLIC"{
keep if  dummy_LIC==1  &  dummy_hyper == 0 //keep if  dummy_LIC==1 *to obtain LIC_All 
}

if "`m'"=="NHNLIC"{
keep if  dummy_LIC==0  &  dummy_hyper == 0 //keep if  dummy_LIC==1 *to obtain NonLIC_All 
}
// Baseline: full sample
local reg_name  = "NM_`k'_`m'"	
disp "`reg_name'"

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using Table2_Regression.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', F-test (alpha=0 & beta=1), `Fval', ///
	          p-value (alpha=0 & beta=1), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel stats(coef pval) dec(2) 

			  
}

}





			  			 			
*****************  NX_usd  *****************  
foreach k in "F" "BOP" "float" "fixed"{

foreach m in "F" "NH" "NHLIC" "NHNLIC"{

disp "k is: `k', m is : `m'"

use        "X_M_E_6-27-21_updated.dta", clear

local      def_var  = "NX_usd"	         // 1. rename variable here!!!!!!!!!!!!!

rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
save tempdata.dta, replace

			  
			  
if "`k'"=="float"{
keep if float_dummy == 1
}
if "`k'"=="fixed"{
keep if fixed_dummy == 1
	* Prof Eicher checked 390 Ecuador was dollarized under 2000, and unclear what is the actual base currency
	replace forecast =. if arrangementnumber == 390 & "`i'" == "RENDA"
	replace actual =. if arrangementnumber == 390 & "`i'" == "RENDA"
}

if "`k'"=="BOP"{
keep if !inlist(arrangementtype, "SAF", "PSI", "PRGF-EFF", "PRGF", "PCI", "ESAF")
}


if "`m'"=="NH"{
keep if  dummy_hyper == 0
}

if "`m'"=="NHLIC"{
keep if  dummy_LIC==1  &  dummy_hyper == 0 //keep if  dummy_LIC==1 *to obtain LIC_All 
}

if "`m'"=="NHNLIC"{
keep if  dummy_LIC==0  &  dummy_hyper == 0 //keep if  dummy_LIC==1 *to obtain NonLIC_All 
}
// Baseline: full sample
local reg_name  = "NX_`k'_`m'"	
disp "`reg_name'"

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using Table2_Regression.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', F-test (alpha=0 & beta=1), `Fval', ///
	          p-value (alpha=0 & beta=1), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel stats(coef pval) dec(2) 

			  
}

}

*****************  RENDA  *****************  

foreach k in "F" "BOP" "float" "fixed"{

foreach m in "F" "NH" "NHLIC" "NHNLIC"{

disp "k is: `k', m is : `m'"

use        "X_M_E_6-27-21_updated.dta", clear

local      def_var  = "RENDA"	         // 1. rename variable here!!!!!!!!!!!!!

rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror
			  
save tempdata.dta, replace

			  
			  
if "`k'"=="float"{
keep if float_dummy == 1
}
if "`k'"=="fixed"{
keep if fixed_dummy == 1
	* Prof Eicher checked 390 Ecuador was dollarized under 2000, and unclear what is the actual base currency
	replace forecast =. if arrangementnumber == 390 & "`i'" == "RENDA"
	replace actual =. if arrangementnumber == 390 & "`i'" == "RENDA"
}

if "`k'"=="BOP"{
keep if !inlist(arrangementtype, "SAF", "PSI", "PRGF-EFF", "PRGF", "PCI", "ESAF")
}


if "`m'"=="NH"{
keep if  dummy_hyper == 0
}

if "`m'"=="NHLIC"{
keep if  dummy_LIC==1  &  dummy_hyper == 0 //keep if  dummy_LIC==1 *to obtain LIC_All 
}

if "`m'"=="NHNLIC"{
keep if  dummy_LIC==0  &  dummy_hyper == 0 //keep if  dummy_LIC==1 *to obtain NonLIC_All 
}
// Baseline: full sample
local reg_name  = "RENDA_`k'_`m'"	
disp "`reg_name'"

	* SJS F-test:
	reg       actual forecast  , robust   // start with no control vairables at all
	est       store `reg_name'  
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  
	local     Fval=r(F)
	local     pval_F=r(p)
	local     adj_r=e(r2_a)
	* Holden-Peel T test:
	reg       ferror            , robust
	local     tstat_gamma = (_b[_cons]/_se[_cons]) 
	local     pval_gamma = tprob(e(df_r), abs(`tstat_gamma'))
	* Results output:
	outreg2   [`reg_name']  using Table2_Regression.xls, ///
	          adds(p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', Adjusted R-squared, `adj_r', F-test (alpha=0 & beta=1), `Fval', ///
	          p-value (alpha=0 & beta=1), `pval_F', Holden-Peel T-Test (gamma=0), `tstat_gamma', p-value, `pval_gamma' ) excel stats(coef pval) dec(2) 

			  
}

}
// Export result to the master output file
import   delimited  Table2_Regression.txt,  clear
export   excel using "Output_IMFNowcasts_June27_2021.xlsx", sheet("Table2", replace)  firstrow(variables)

			 			 
erase  tempdata.dta			  		  
erase      Table2_Regression.xls
erase      Table2_Regression.txt
			  
*EMX Table 3: Source of Bias////////////////////////////////////////////////////////////////////////////////////////////////////////

// Table 3: Regression Output




// setup root directory
cd "${path}"
clear
set more off


*****************  NM_usd *****************  

local      def_var  = "NM_usd"	         // 1. rename variable here!!!!!!!!!!!!!


/// compile dummy files of conflicts/disasters/election 
* Different for RGDP,NGDP,Inflation, because forecast dates are slightly different
{
*******************************
// compile dummy_conflict.dta
*******************************


	
use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data

gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

{
* merge conflicts data   
joinby  iso3 using conflict_raw, unmatched(master)
drop    _m

gsort   +countryname -programyear -date_start_conflict 


gen        exog_conflict = 0
replace    exog_conflict = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   // exog shock if the event fell within the program year t, after the start of the program. 

gen        endo_conflict = 0
replace    endo_conflict = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365   // endo shock if program start within a year after event date


gen        exog_conflict_inter = 0
replace    exog_conflict_inter = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   &   conflict_type == "inter-state"

gen        endo_conflict_inter = 0
replace    endo_conflict_inter = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365    & conflict_type == "inter-state"


gen        exog_conflict_intra = 0
replace    exog_conflict_intra = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   &   conflict_type == "intra-state"

gen        endo_conflict_intra = 0
replace    endo_conflict_intra = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365   &   conflict_type == "intra-state"



collapse   (max)  exog_conflict*  endo_conflict*, by(arrangementnumber programyear countryname)

save       dummy_conflict.dta, replace

tab  endo_conflict
tab  exog_conflict
tab  endo_conflict_inter
tab  exog_conflict_inter
tab  endo_conflict_intra
tab  exog_conflict_intra


}



*******************************
// compile dummy_disaster.dta
*******************************


use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data
*local      def_var  = "NGDP"	         // 1. rename variable here!!!!!!!!!!!!!
gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

{
* merge election data
joinby  iso3 using disaster_raw, unmatched(master)
drop    _m

unique  arrangementnumber
gsort   +countryname -programyear -start_disaster


drop    if  total_damages==.   
drop    if  total_damages<  1000    // if total damages > 1 million USD => adjust in code later
*keep    if  total_affected>1000000 |  total_damages>10000000  


gen        exog_disaster = 0
replace    exog_disaster = 1   if  forecastdate < start_disaster   &  initialenddate > start_disaster  // exog shock if a program ran past event date

gen        endo_disaster = 0
replace    endo_disaster = 1   if  forecastdate >= start_disaster   &  forecastdate <= start_disaster + 365   // endo shock if program start within a year after event date


collapse   (max)  exog_disaster*  endo_disaster*  total_damages, by(arrangementnumber)
unique  arrangementnumber

save       dummy_disaster.dta, replace

}



*******************************
// compile dummy_election.dta
*******************************


use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using  countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data
*local      def_var  = "NGDP"	         // 1. rename variable here!!!!!!!!!!!!!
gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic
{
* merge election data
joinby  iso3 using election_raw, unmatched(master)
drop    _m

gsort   +countryname -programyear -date_election 


gen        exog_election = 0
replace    exog_election = 1   if  forecastdate < date_election   &  programyear == year(date_election)   // exog shock if the event fell within the program year t, after the start of the program. 

gen        endo_election = 0
replace    endo_election = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365   // endo shock if program start within a year after event date


gen        exog_election_pres = 0
replace    exog_election_pres = 1   if  forecastdate < date_election   &  programyear == year(date_election)   &   election_type == "President"

gen        endo_election_pres = 0
replace    endo_election_pres = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365    & election_type == "President"


gen        exog_election_legis = 0
replace    exog_election_legis = 1   if  forecastdate < date_election   &  programyear == year(date_election)   &   election_type == "Legislative (upper +lower)"

gen        endo_election_legis = 0
replace    endo_election_legis = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365   &   election_type == "Legislative (upper +lower)"



collapse   (max)  exog_election*  endo_election*, by(arrangementnumber programyear countryname)

save       dummy_election.dta, replace
}


}

*****************************
// regressions, specify variables

use        "X_M_E_6-27-21_updated.dta", clear
 


*local      def_var  = "RGDP"	         // 1. rename variable here!!!!!!!!!!!!!
gen        mneumonic="`def_var'"

*erase      regA_`def_var'.xls
*erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror

drop       type_new_LT_BOP // 2. omit this type (least obs)

/*
// merge structural condition data
merge 1:1 arrangementnumber using sc_condition   /* condition.dta is file for all info , condition_t_only*/

local 	   vars="sc_civil_service sc_econ_stat sc_exchange_sys sc_fin_sector sc_gen_govt sc_intl_trade sc_other sc_pension sc_pub_enterprise sc_central_bank sc_labor_mkt"
  foreach    v in `vars' {
	       replace `v' = 0     if  _m==1
  }		
drop      if _m==2
drop      _m
*/

** merge data
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

merge 1:1  arrangementnumber  using dummy_disaster   // merge disaster data
drop if    _m==2
replace    exog_disaster = 0   if _m==1
replace    endo_disaster = 0   if _m==1
drop       _m
tab        endo_disaster
tab        exog_disaster


merge 1:1  arrangementnumber  using dummy_election   // merge election data
drop if    _m==2
drop       _m   
*replace    endo_election =1  if arrangementnumber==10  // Ethiopia 1992, reginal level election not count
*replace    endo_conflict =1  if arrangementnumber==10  // Ethiopia 1992 


merge 1:1  arrangementnumber  using dummy_conflict   // merge conflict data
drop if    _m==2
drop       _m   



// crises dummies
* endo & exog crises dummies for 08 crisis
gen        exog_crisis08 = 0
replace    exog_crisis08 = 1    if   forecastdate<td(15sep2008)   &  programyear == 2008   // exog shock if the event fell within the program year t, after the start of the program. 
gen        endo_crisis08 = 0
replace    endo_crisis08 = 1    if   inrange(forecastdate, td(15sep2008), td(15sep2009))      // endo shock if program start within a year after 8/15/2008

* endo & exog crises dummies for 97 asian crisis
* no IMF programs for Mainland China, Hong Kong, Malaysia, Japan, Singapore
kountry    countrycode, from(imfn) geo(sov)
gen        contagion97 = 0
replace    contagion97 = 1       if  inlist(countryname, "THAILAND", "INDONESIA", "KOREA", "PHILIPPINES", "MONGOLIA")  // directly affected
replace    contagion97 = 1       if  inlist(countryname, "RUSSIAN FEDERATION", "MEXICO")  |  GEO=="Post Soviet"  // contagion

gen        exog_crisis97 = 0
replace    exog_crisis97 = 1    if  forecastdate<td(2jul1997)   &  programyear == 1997  &  contagion97 == 1    // exog shock if a program ran past 7/2/1997

gen        endo_crisis97 = 0
replace    endo_crisis97 = 1    if   inrange(forecastdate, td(2jul1997), td(1jan1999))          &  contagion97 == 1   // endo shock if program start after 7/2/1997 up to 1/1/1999 (Russia)



// select subsamples 
*keep      if  arrangementnumber>500   // B. new MONA only
*keep      if  arrangementnumber<500   // C. old MONA only
*keep      if  dummy_hyper == 1         // D. hyperinflation
*keep      if  dummy_hyper == 0         // E. NO hyperinflation
*keep      if  dummy_LIC==1          // F. LIC only
*keep      if  dummy_LIC==0          // G. non-LIC        

*keep      if  dummy_LIC==1    & dummy_hyper == 0      // H. LIC & non-hyper
*keep      if  dummy_LIC==0    & dummy_hyper == 0      // I. non-LIC & non-hyper 

save temp_`def_var'_full, replace
*drop sc_labor_mkt 
**************************
keep if fixed_dummy == 1
keep if  dummy_LIC==1  &  dummy_hyper == 0 //keep if  dummy_LIC==1 *to obtain LIC_All 

local reg_name  = "`def_var'_F_fixed_NHLIC"

	* SJS F-test:
	reg       actual forecast ///
			  approveaccess_to_quota ///
			  cond_*  sc_* ///
			  endo_election ///
			  endo_disaster ///
			  endo_conflict_inter ///
			  endo_conflict_intra ///
			  ,  robust

	est       store `reg_name'   // don't forget to change this one!!!!
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  ///
         	  (_b[endo_election]=0) (_b[endo_disaster]=0) (_b[approveaccess_to_quota]=0)  ///
			  (_b[endo_conflict_inter]=0) (_b[endo_conflict_intra]=0) ///
			  (_b[sc_civil_service]=0) (_b[sc_econ_stat]=0) (_b[sc_exchange_sys]=0) (_b[sc_gen_govt]=0) (_b[sc_intl_trade]=0) (_b[sc_pension]=0) ///
			  (_b[sc_pub_enterprise]=0) (_b[sc_central_bank]=0) (_b[sc_fin_sector]=0) (_b[sc_other]=0) ///
			  (_b[cond_ML_term_external_debt]=0) (_b[cond_bop_reserve_test]=0) (_b[cond_ceiling_external_arrears]=0)  (_b[cond_credit_to_govt_public_s]=0) ///
			  (_b[cond_domestic_arrears]=0) (_b[cond_fiscal_balance]=0)  (_b[cond_no_new_arrears_default_ci]=0)  (_b[cond_short_term_debt]=0)  (_b[cond_total_domestic_credit]=0)    
			 
	local     Fval=r(F)
	local     pval_F=r(p)
    local     adj_r=e(r2_a)
	* Holden-Peel T test:
	* Results output:
	outreg2   [`reg_name']  using reg_table4.xls, ///
	          adds(Adjusted R-squared, `adj_r', p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F') excel stats(coef pval)  dec(2) 
	

				  
*****************  NX_usd *****************  

local      def_var  = "NX_usd"	         // 1. rename variable here!!!!!!!!!!!!!


/// compile dummy files of conflicts/disasters/election 
* Different for RGDP,NGDP,Inflation, because forecast dates are slightly different

{
*******************************
// compile dummy_conflict.dta
*******************************


	
use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data

gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

{
* merge conflicts data   
joinby  iso3 using conflict_raw, unmatched(master)
drop    _m

gsort   +countryname -programyear -date_start_conflict 


gen        exog_conflict = 0
replace    exog_conflict = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   // exog shock if the event fell within the program year t, after the start of the program. 

gen        endo_conflict = 0
replace    endo_conflict = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365   // endo shock if program start within a year after event date


gen        exog_conflict_inter = 0
replace    exog_conflict_inter = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   &   conflict_type == "inter-state"

gen        endo_conflict_inter = 0
replace    endo_conflict_inter = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365    & conflict_type == "inter-state"


gen        exog_conflict_intra = 0
replace    exog_conflict_intra = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   &   conflict_type == "intra-state"

gen        endo_conflict_intra = 0
replace    endo_conflict_intra = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365   &   conflict_type == "intra-state"



collapse   (max)  exog_conflict*  endo_conflict*, by(arrangementnumber programyear countryname)

save       dummy_conflict.dta, replace

tab  endo_conflict
tab  exog_conflict
tab  endo_conflict_inter
tab  exog_conflict_inter
tab  endo_conflict_intra
tab  exog_conflict_intra


}



*******************************
// compile dummy_disaster.dta
*******************************


use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data
*local      def_var  = "NGDP"	         // 1. rename variable here!!!!!!!!!!!!!
gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

{
* merge election data
joinby  iso3 using disaster_raw, unmatched(master)
drop    _m

unique  arrangementnumber
gsort   +countryname -programyear -start_disaster


drop    if  total_damages==.   
drop    if  total_damages<  1000    // if total damages > 1 million USD => adjust in code later
*keep    if  total_affected>1000000 |  total_damages>10000000  


gen        exog_disaster = 0
replace    exog_disaster = 1   if  forecastdate < start_disaster   &  initialenddate > start_disaster  // exog shock if a program ran past event date

gen        endo_disaster = 0
replace    endo_disaster = 1   if  forecastdate >= start_disaster   &  forecastdate <= start_disaster + 365   // endo shock if program start within a year after event date


collapse   (max)  exog_disaster*  endo_disaster*  total_damages, by(arrangementnumber)
unique  arrangementnumber

save       dummy_disaster.dta, replace

}



*******************************
// compile dummy_election.dta
*******************************


use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data
*local      def_var  = "NGDP"	         // 1. rename variable here!!!!!!!!!!!!!
gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic
{
* merge election data
joinby  iso3 using election_raw, unmatched(master)
drop    _m

gsort   +countryname -programyear -date_election 


gen        exog_election = 0
replace    exog_election = 1   if  forecastdate < date_election   &  programyear == year(date_election)   // exog shock if the event fell within the program year t, after the start of the program. 

gen        endo_election = 0
replace    endo_election = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365   // endo shock if program start within a year after event date


gen        exog_election_pres = 0
replace    exog_election_pres = 1   if  forecastdate < date_election   &  programyear == year(date_election)   &   election_type == "President"

gen        endo_election_pres = 0
replace    endo_election_pres = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365    & election_type == "President"


gen        exog_election_legis = 0
replace    exog_election_legis = 1   if  forecastdate < date_election   &  programyear == year(date_election)   &   election_type == "Legislative (upper +lower)"

gen        endo_election_legis = 0
replace    endo_election_legis = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365   &   election_type == "Legislative (upper +lower)"



collapse   (max)  exog_election*  endo_election*, by(arrangementnumber programyear countryname)

save       dummy_election.dta, replace
}


}

*****************************
// regressions, specify variables

use        "X_M_E_6-27-21_updated.dta", clear
 


*local      def_var  = "RGDP"	         // 1. rename variable here!!!!!!!!!!!!!
gen        mneumonic="`def_var'"

*erase      regA_`def_var'.xls
*erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror

drop       type_new_LT_BOP // 2. omit this type (least obs)

** merge data
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

merge 1:1  arrangementnumber  using dummy_disaster   // merge disaster data
drop if    _m==2
replace    exog_disaster = 0   if _m==1
replace    endo_disaster = 0   if _m==1
drop       _m
tab        endo_disaster
tab        exog_disaster


merge 1:1  arrangementnumber  using dummy_election   // merge election data
drop if    _m==2
drop       _m   
*replace    endo_election =1  if arrangementnumber==10  // Ethiopia 1992, reginal level election not count
*replace    endo_conflict =1  if arrangementnumber==10  // Ethiopia 1992 


merge 1:1  arrangementnumber  using dummy_conflict   // merge conflict data
drop if    _m==2
drop       _m   



// crises dummies
* endo & exog crises dummies for 08 crisis
gen        exog_crisis08 = 0
replace    exog_crisis08 = 1    if   forecastdate<td(15sep2008)   &  programyear == 2008   // exog shock if the event fell within the program year t, after the start of the program. 
gen        endo_crisis08 = 0
replace    endo_crisis08 = 1    if   inrange(forecastdate, td(15sep2008), td(15sep2009))      // endo shock if program start within a year after 8/15/2008

* endo & exog crises dummies for 97 asian crisis
* no IMF programs for Mainland China, Hong Kong, Malaysia, Japan, Singapore
kountry    countrycode, from(imfn) geo(sov)
gen        contagion97 = 0
replace    contagion97 = 1       if  inlist(countryname, "THAILAND", "INDONESIA", "KOREA", "PHILIPPINES", "MONGOLIA")  // directly affected
replace    contagion97 = 1       if  inlist(countryname, "RUSSIAN FEDERATION", "MEXICO")  |  GEO=="Post Soviet"  // contagion

gen        exog_crisis97 = 0
replace    exog_crisis97 = 1    if  forecastdate<td(2jul1997)   &  programyear == 1997  &  contagion97 == 1    // exog shock if a program ran past 7/2/1997

gen        endo_crisis97 = 0
replace    endo_crisis97 = 1    if   inrange(forecastdate, td(2jul1997), td(1jan1999))          &  contagion97 == 1   // endo shock if program start after 7/2/1997 up to 1/1/1999 (Russia)


save temp_`def_var'_full, replace

local reg_name  = "`def_var'_full"

	* SJS F-test:
	reg       actual forecast ///
			  approveaccess_to_quota ///
			  cond_*  sc_* ///
			  endo_election ///
			  endo_disaster ///
			  endo_conflict_inter ///
			  endo_conflict_intra ///
			  ,  robust

	est       store `reg_name'   // don't forget to change this one!!!!
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  ///
         	  (_b[endo_election]=0) (_b[endo_disaster]=0) (_b[approveaccess_to_quota]=0)  ///
			  (_b[endo_conflict_inter]=0) (_b[endo_conflict_intra]=0) ///
			  (_b[sc_civil_service]=0) (_b[sc_econ_stat]=0) (_b[sc_exchange_sys]=0) (_b[sc_gen_govt]=0) (_b[sc_intl_trade]=0) (_b[sc_pension]=0) ///
			  (_b[sc_pub_enterprise]=0) (_b[sc_central_bank]=0) (_b[sc_fin_sector]=0) (_b[sc_other]=0) ///
			  (_b[cond_ML_term_external_debt]=0) (_b[cond_bop_reserve_test]=0) (_b[cond_ceiling_external_arrears]=0)  (_b[cond_credit_to_govt_public_s]=0) ///
			  (_b[cond_domestic_arrears]=0) (_b[cond_fiscal_balance]=0)  (_b[cond_no_new_arrears_default_ci]=0)  (_b[cond_short_term_debt]=0)  (_b[cond_total_domestic_credit]=0)    
			 
	local     Fval=r(F)
	local     pval_F=r(p)
    local     adj_r=e(r2_a)
	* Holden-Peel T test:
	* Results output:
	outreg2   [`reg_name']  using reg_table4.xls, ///
	          adds(Adjusted R-squared, `adj_r', p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F') stats(coef pval)  excel dec(2) 
	
	
*****************  RENDA *****************  

local      def_var  = "RENDA"	         // 1. rename variable here!!!!!!!!!!!!!


/// compile dummy files of conflicts/disasters/election 

{
*******************************
// compile dummy_conflict.dta
*******************************


	
use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data

gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

{
* merge conflicts data   
joinby  iso3 using conflict_raw, unmatched(master)
drop    _m

gsort   +countryname -programyear -date_start_conflict 


gen        exog_conflict = 0
replace    exog_conflict = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   // exog shock if the event fell within the program year t, after the start of the program. 

gen        endo_conflict = 0
replace    endo_conflict = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365   // endo shock if program start within a year after event date


gen        exog_conflict_inter = 0
replace    exog_conflict_inter = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   &   conflict_type == "inter-state"

gen        endo_conflict_inter = 0
replace    endo_conflict_inter = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365    & conflict_type == "inter-state"


gen        exog_conflict_intra = 0
replace    exog_conflict_intra = 1   if   forecastdate!=.  &  forecastdate < date_start_conflict   &  programyear == year(date_start_conflict)   &   conflict_type == "intra-state"

gen        endo_conflict_intra = 0
replace    endo_conflict_intra = 1   if   forecastdate!=.  &  forecastdate >= date_start_conflict   &  forecastdate <= date_start_conflict + 365   &   conflict_type == "intra-state"



collapse   (max)  exog_conflict*  endo_conflict*, by(arrangementnumber programyear countryname)

save       dummy_conflict.dta, replace

tab  endo_conflict
tab  exog_conflict
tab  endo_conflict_inter
tab  exog_conflict_inter
tab  endo_conflict_intra
tab  exog_conflict_intra


}



*******************************
// compile dummy_disaster.dta
*******************************


use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data
*local      def_var  = "NGDP"	         // 1. rename variable here!!!!!!!!!!!!!
gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

{
* merge election data
joinby  iso3 using disaster_raw, unmatched(master)
drop    _m

unique  arrangementnumber
gsort   +countryname -programyear -start_disaster


drop    if  total_damages==.   
drop    if  total_damages<  1000    // if total damages > 1 million USD => adjust in code later
*keep    if  total_affected>1000000 |  total_damages>10000000  


gen        exog_disaster = 0
replace    exog_disaster = 1   if  forecastdate < start_disaster   &  initialenddate > start_disaster  // exog shock if a program ran past event date

gen        endo_disaster = 0
replace    endo_disaster = 1   if  forecastdate >= start_disaster   &  forecastdate <= start_disaster + 365   // endo shock if program start within a year after event date


collapse   (max)  exog_disaster*  endo_disaster*  total_damages, by(arrangementnumber)
unique  arrangementnumber

save       dummy_disaster.dta, replace

}



*******************************
// compile dummy_election.dta
*******************************


use MONAall_info, clear
sort arrangementnumber
keep arrangementnumber countrycode programyear *date

* merge countryname (to get iso3 for merge later)
merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 


* merge forecast data
*local      def_var  = "NGDP"	         // 1. rename variable here!!!!!!!!!!!!!
gen        mneumonic="`def_var'"
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic
{
* merge election data
joinby  iso3 using election_raw, unmatched(master)
drop    _m

gsort   +countryname -programyear -date_election 


gen        exog_election = 0
replace    exog_election = 1   if  forecastdate < date_election   &  programyear == year(date_election)   // exog shock if the event fell within the program year t, after the start of the program. 

gen        endo_election = 0
replace    endo_election = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365   // endo shock if program start within a year after event date


gen        exog_election_pres = 0
replace    exog_election_pres = 1   if  forecastdate < date_election   &  programyear == year(date_election)   &   election_type == "President"

gen        endo_election_pres = 0
replace    endo_election_pres = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365    & election_type == "President"


gen        exog_election_legis = 0
replace    exog_election_legis = 1   if  forecastdate < date_election   &  programyear == year(date_election)   &   election_type == "Legislative (upper +lower)"

gen        endo_election_legis = 0
replace    endo_election_legis = 1   if  forecastdate >= date_election   &  forecastdate <= date_election + 365   &   election_type == "Legislative (upper +lower)"



collapse   (max)  exog_election*  endo_election*, by(arrangementnumber programyear countryname)

save       dummy_election.dta, replace
}


}

*****************************
// regressions, specify variables

use        "X_M_E_6-27-21_updated.dta", clear
 

gen        mneumonic="`def_var'"

*erase      regA_`def_var'.xls
*erase      regA_`def_var'.txt


rename     actual_`def_var'       actual       
rename     forecast_`def_var'     forecast    
rename     fe_imf_`def_var'       ferror
sum        actual forecast ferror

drop       type_new_LT_BOP // 2. omit this type (least obs)

/*
// merge structural condition data
merge 1:1 arrangementnumber using sc_condition   /* condition.dta is file for all info , condition_t_only*/

local 	   vars="sc_civil_service sc_econ_stat sc_exchange_sys sc_fin_sector sc_gen_govt sc_intl_trade sc_other sc_pension sc_pub_enterprise sc_central_bank sc_labor_mkt"
  foreach    v in `vars' {
	       replace `v' = 0     if  _m==1
  }		
drop      if _m==2
drop      _m
*/

** merge data
merge 1:1  arrangementnumber mneumonic using forecastdate_reina   // merge forecast data
drop if    _m==2
drop       _m  mneumonic

merge 1:1  arrangementnumber  using dummy_disaster   // merge disaster data
drop if    _m==2
replace    exog_disaster = 0   if _m==1
replace    endo_disaster = 0   if _m==1
drop       _m
tab        endo_disaster
tab        exog_disaster


merge 1:1  arrangementnumber  using dummy_election   // merge election data
drop if    _m==2
drop       _m   
*replace    endo_election =1  if arrangementnumber==10  // Ethiopia 1992, reginal level election not count
*replace    endo_conflict =1  if arrangementnumber==10  // Ethiopia 1992 


merge 1:1  arrangementnumber  using dummy_conflict   // merge conflict data
drop if    _m==2
drop       _m   



// crises dummies
* endo & exog crises dummies for 08 crisis
gen        exog_crisis08 = 0
replace    exog_crisis08 = 1    if   forecastdate<td(15sep2008)   &  programyear == 2008   // exog shock if the event fell within the program year t, after the start of the program. 
gen        endo_crisis08 = 0
replace    endo_crisis08 = 1    if   inrange(forecastdate, td(15sep2008), td(15sep2009))      // endo shock if program start within a year after 8/15/2008

* endo & exog crises dummies for 97 asian crisis
* no IMF programs for Mainland China, Hong Kong, Malaysia, Japan, Singapore
kountry    countrycode, from(imfn) geo(sov)
gen        contagion97 = 0
replace    contagion97 = 1       if  inlist(countryname, "THAILAND", "INDONESIA", "KOREA", "PHILIPPINES", "MONGOLIA")  // directly affected
replace    contagion97 = 1       if  inlist(countryname, "RUSSIAN FEDERATION", "MEXICO")  |  GEO=="Post Soviet"  // contagion

gen        exog_crisis97 = 0
replace    exog_crisis97 = 1    if  forecastdate<td(2jul1997)   &  programyear == 1997  &  contagion97 == 1    // exog shock if a program ran past 7/2/1997

gen        endo_crisis97 = 0
replace    endo_crisis97 = 1    if   inrange(forecastdate, td(2jul1997), td(1jan1999))          &  contagion97 == 1   // endo shock if program start after 7/2/1997 up to 1/1/1999 (Russia)


save temp_`def_var'_full, replace

keep if float_dummy == 1
keep if  dummy_LIC==1  &  dummy_hyper == 0 //keep if  dummy_LIC==1 *to obtain LIC_All 

local reg_name  = "`def_var'_float_NHLIC"

	* SJS F-test:
	reg       actual forecast ///
			  approveaccess_to_quota ///
			  cond_*  sc_* ///
			  endo_election ///
			  endo_disaster ///
			  endo_conflict_inter ///
			  endo_conflict_intra ///
			  ,  robust

	est       store `reg_name'   // don't forget to change this one!!!!
	test      (_b[_cons]=0)           
	local     pval_alphais0=r(p)
	test      (_b[forecast]=1)           
	local     pval_betais1=r(p)
	test      (_b[_cons]=0) (_b[forecast]=1)  ///
         	  (_b[endo_election]=0) (_b[endo_disaster]=0) (_b[approveaccess_to_quota]=0)  ///
			  (_b[endo_conflict_inter]=0) (_b[endo_conflict_intra]=0) ///
			  (_b[sc_civil_service]=0) (_b[sc_econ_stat]=0) (_b[sc_exchange_sys]=0) (_b[sc_gen_govt]=0) (_b[sc_intl_trade]=0) (_b[sc_pension]=0) ///
			  (_b[sc_pub_enterprise]=0) (_b[sc_central_bank]=0) (_b[sc_fin_sector]=0) (_b[sc_other]=0) ///
			  (_b[cond_ML_term_external_debt]=0) (_b[cond_bop_reserve_test]=0) (_b[cond_ceiling_external_arrears]=0)  (_b[cond_credit_to_govt_public_s]=0) ///
			  (_b[cond_domestic_arrears]=0) (_b[cond_fiscal_balance]=0)  (_b[cond_no_new_arrears_default_ci]=0)  (_b[cond_short_term_debt]=0)  (_b[cond_total_domestic_credit]=0)    
			 
	local     Fval=r(F)
	local     pval_F=r(p)
    local     adj_r=e(r2_a)
	* Holden-Peel T test:
	* Results output:
	outreg2   [`reg_name']  using reg_table4.xls, ///
	          adds(Adjusted R-squared, `adj_r', p-value (alpha=0), `pval_alphais0', p-value (beta=1), `pval_betais1', SJS F-test (alpha=0 & beta=1 & theta=0), `Fval', ///
	          p-value (alpha=0 & beta=1 & theta=0), `pval_F') excel stats(coef pval)  dec(2) 
	

					  
// Export result to the master output file
import   delimited  reg_table4.txt,  clear
export   excel using "Output_IMFNowcasts_June27_2021.xlsx", sheet("Table4", replace)  firstrow(variables)

// erase at the end
erase  reg_table4.xls
erase  reg_table4.txt
*erase  tempdata.dta	

*EMX Table 4: Turning Point////////////////////////////////////////////////////////////////////////////////////////////////////////


use "X_M_E_6-27-21_updated.dta", clear
count if forecast_NM_usd>0 & actual_NM_usd>0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd>0 & actual_NX_usd>0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA>0 & actual_RENDA>0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd<=0 & actual_NM_usd<=0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd<=0 & actual_NX_usd<=0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA<=0 & actual_RENDA<=0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd>0 & actual_NM_usd<=0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd>0 & actual_NX_usd<=0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA>0 & actual_RENDA<=0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd<=0 & actual_NM_usd>0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd<=0 & actual_NX_usd>0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA<=0 & actual_RENDA>0 & forecast_RENDA!=.& actual_RENDA!=.


use "X_M_E_6-27-21_updated.dta", clear
keep if  dummy_hyper == 0  
count if forecast_NM_usd>0 & actual_NM_usd>0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd>0 & actual_NX_usd>0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA>0 & actual_RENDA>0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd<=0 & actual_NM_usd<=0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd<=0 & actual_NX_usd<=0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA<=0 & actual_RENDA<=0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd>0 & actual_NM_usd<=0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd>0 & actual_NX_usd<=0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA>0 & actual_RENDA<=0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd<=0 & actual_NM_usd>0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd<=0 & actual_NX_usd>0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA<=0 & actual_RENDA>0 & forecast_RENDA!=.& actual_RENDA!=.




use "X_M_E_6-27-21_updated.dta", clear
keep if  dummy_LIC==1    & dummy_hyper == 0  
count if forecast_NM_usd>0 & actual_NM_usd>0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd>0 & actual_NX_usd>0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA>0 & actual_RENDA>0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd<=0 & actual_NM_usd<=0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd<=0 & actual_NX_usd<=0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA<=0 & actual_RENDA<=0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd>0 & actual_NM_usd<=0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd>0 & actual_NX_usd<=0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA>0 & actual_RENDA<=0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd<=0 & actual_NM_usd>0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd<=0 & actual_NX_usd>0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA<=0 & actual_RENDA>0 & forecast_RENDA!=.& actual_RENDA!=.



use "X_M_E_6-27-21_updated.dta", clear
keep if  dummy_LIC==0    & dummy_hyper == 0  
count if forecast_NM_usd>0 & actual_NM_usd>0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd>0 & actual_NX_usd>0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA>0 & actual_RENDA>0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd<=0 & actual_NM_usd<=0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd<=0 & actual_NX_usd<=0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA<=0 & actual_RENDA<=0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd>0 & actual_NM_usd<=0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd>0 & actual_NX_usd<=0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA>0 & actual_RENDA<=0 & forecast_RENDA!=.& actual_RENDA!=.

count if forecast_NM_usd<=0 & actual_NM_usd>0 & forecast_NM_usd!=.& actual_NM_usd!=.
count if forecast_NX_usd<=0 & actual_NX_usd>0 & forecast_NX_usd!=.& actual_NX_usd!=.
count if forecast_RENDA<=0 & actual_RENDA>0 & forecast_RENDA!=.& actual_RENDA!=.

* Example generated by -dataex-. To install: ssc install dataex
clear
input str1 variable byte(pos neg posneg negpos)
"A" 346 94 111 27
"B" 385 61 96 34
"C" 170 269 48 78
end
/*
gen p = .

quietly forval i = 1/`=_N' {
    tabi `=pos[`i']' `=negpos[`i']' \ `=neg[`i']' `=posneg[`i']', chi2
    replace p = r(p) in `i'
}

list 
*/



tabi 346 27 \ 94 111, chi2
tabi 385 34 \ 61 96, chi2
tabi 170 78 \ 269 48, chi2

tabi 317 22 \ 71 102, chi2
tabi 344 31 \ 47 89, chi2
tabi 135 76 \ 245 44, chi2

tabi 169 11 \ 27 62, chi2
tabi 174 17 \ 17 60, chi2
tabi 71 51 \ 109 31, chi2

tabi 148 11 \ 44 40, chi2
tabi 170 14 \ 30 29, chi2
tabi 64 25 \ 136 13, chi2

******************************* TheilU sample code for NM *****************************
use        "X_M_E_6-27-21_updated.dta", clear
*keep      if  dummy_LIC == 0  &  dummy_hyper == 0        // LIC + non-hyper
keep arrangementnumber programyear actual_NM_usd forecast_NM_usd fe_imf_NM_usd 
gen X1=actual_NM_usd 
gen F1=forecast_NM_usd  
gen numa = (F1-X1)^2 
gen num1 = sum(numa)   
gen dena = (X1)^2  
gen den1 = sum(dena)  
gen TUnum= num1[_N] 
gen TUden = den1[_N] 
gen TheilU = sqrt(TUnum/TUden)


use        "X_M_E_6-27-21_updated.dta", clear
keep      if  dummy_hyper == 0        // non-hyper
keep arrangementnumber programyear actual_NM_usd forecast_NM_usd fe_imf_NM_usd 
gen X1=actual_NM_usd 
gen F1=forecast_NM_usd  
gen numa = (F1-X1)^2 
gen num1 = sum(numa)   
gen dena = (X1)^2  
gen den1 = sum(dena)  
gen TUnum= num1[_N] 
gen TUden = den1[_N] 
gen TheilU = sqrt(TUnum/TUden)


use        "X_M_E_6-27-21_updated.dta", clear
keep      if  dummy_LIC == 1  &  dummy_hyper == 0        // LIC + non-hyper
keep arrangementnumber programyear actual_NM_usd forecast_NM_usd fe_imf_NM_usd 
gen X1=actual_NM_usd 
gen F1=forecast_NM_usd  
gen numa = (F1-X1)^2 
gen num1 = sum(numa)   
gen dena = (X1)^2  
gen den1 = sum(dena)  
gen TUnum= num1[_N] 
gen TUden = den1[_N] 
gen TheilU = sqrt(TUnum/TUden)


use        "X_M_E_6-27-21_updated.dta", clear
keep      if  dummy_LIC == 0  &  dummy_hyper == 0        // non-LIC + non-hyper
keep arrangementnumber programyear actual_NM_usd forecast_NM_usd fe_imf_NM_usd 
gen X1=actual_NM_usd 
gen F1=forecast_NM_usd  
gen numa = (F1-X1)^2 
gen num1 = sum(numa)   
gen dena = (X1)^2  
gen den1 = sum(dena)  
gen TUnum= num1[_N] 
gen TUden = den1[_N] 
gen TheilU = sqrt(TUnum/TUden)

