

********************************************************************************
*           STATA FILE FOR PAPER: The Accuracy of IMF Crises Nowcasts          *
*                              Revisd on June 27, 2021    					   *
*   																		   *	
* 1. Prepare data files														   *
* 2. Compile OLD MONA data (including mapping final offical data from WEO)     *
* 3. Compile NEW MONA data (including mapping final offical data from WEO)     *
* 4. Constructing our paper database                                           *
*                                                                              *
*    See individual do files for codes to create figures and table outputs     *
*                                                                              *
********************************************************************************
{
*cd "/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/input files_non-MONA"
clear all
*ssc install kountry
*ssc install mdesc
set more off

********************Please change this following global directory***************
global path "C:\Users\Reina Kawai\Downloads\resavingpurpose"
* directory of MONA mirror files 

local dir_to_use MONA_mirror_Nov19

capture mkdir "${path}/`dir_to_use'"

* directory of other input files 

local dir_to_use "input files_non-MONA"

capture mkdir "${path}/`dir_to_use'"

cd "${path}/`dir_to_use'"

********************************************************************************
*   1. Prepare data files
*      (i)   import MONA files
*      (ii)   total actual & approved access   => totalaccess.dta
*      (iii)  cancelled programs      => cancelled_all.dta
*      (iv)   QPC conditionality      => condition.dta
*      (v)    SPC conditionality      => sc_condition.dta

********************************************************************************
global MONA_mirror="${path}/MONA_mirror_Nov19"
global inputfiles="${path}/input files_non-MONA"
}
// (i) import MONA files (run only once and save files in the "mirror" folder)
{

    * import excel "Mecon.xlsx", sheet("MonaData") firstrow case(lower) clear
	import excel "https://www.imf.org/external/np/pdr/mona/ArrangementsData/Mecon.xlsx", sheet("MonaData") firstrow case(lower) clear
	compress
	save "${MONA_mirror}/Mecon", replace
	
	*import excel "Combined.xlsx", sheet("MonaData") firstrow case(lower) clear
	import excel "https://www.imf.org/external/np/pdr/mona/ArrangementsData/Combined.xlsx", sheet("MonaData") firstrow case(lower) clear
	compress
	save "${MONA_mirror}/Combined", replace

	*import excel "Description.xlsx", sheet("MonaData") firstrow case(lower) clear
	import excel "https://www.imf.org/external/np/pdr/mona/ArrangementsData/Description.xlsx", sheet("MonaData") firstrow case(lower) clear
	compress
	save "${MONA_mirror}/Description", replace

	*import excel "Purchases.xlsx", sheet("MonaData") firstrow case(lower) clear
	import excel "https://www.imf.org/external/np/pdr/mona/ArrangementsData/Purchases.xlsx", sheet("MonaData") firstrow case(lower) clear
	compress
	save "${MONA_mirror}/Purchases", replace

	*import excel "QPC.xlsx", sheet("MonaData") firstrow case(lower) clear
	import excel "https://www.imf.org/external/np/pdr/mona/ArrangementsData/QPC.xlsx", sheet("MonaData") firstrow case(lower) clear
	compress
	save "${MONA_mirror}/QPC", replace
	
	*import excel "Program.xlsx", sheet("MonaData") firstrow case(lower) clear
	import excel "https://www.imf.org/external/np/pdr/mona/ArrangementsData/Program.xlsx", sheet("MonaData") firstrow case(lower) clear
	replace reviewtype = strtrim(reviewtype)
	compress
	save "${MONA_mirror}/Program", replace
	
	* import Reviews
	import excel "https://www.imf.org/external/np/pdr/mona/ArrangementsData/Reviews.xlsx", sheet("MonaData") firstrow case(lower) clear
	compress
	save "${MONA_mirror}/Reviews", replace

	*import delimited "ArchMecon.csv", encoding(ISO-8859-1) clear
	insheet using "https://www.imf.org/external/np/pdr/mona/HistoricalDataCsv/ArchMecon.csv", clear
	compress
	save "${MONA_mirror}/ArchMecon", replace
	
	*import delimited "ArchDescription.csv", encoding(ISO-8859-1)clear
	import delimited "https://www.imf.org/external/np/pdr/mona/HistoricalDataCsv/ArchDescription.csv", encoding(ISO-8859-1)clear
	compress
	save "${MONA_mirror}/ArchDescription", replace
	
	*import delimited "ArchPurchases.csv", encoding(ISO-8859-1)clear
	import delimited "https://www.imf.org/external/np/pdr/mona/HistoricalDataCsv/ArchPurchases.csv", encoding(ISO-8859-1)clear
	compress
	save "${MONA_mirror}/ArchPurchases", replace
	
	*import delimited "ArchQPC.csv", bindquote(strict) encoding(ISO-8859-1)clear
	import delimited "https://www.imf.org/external/np/pdr/mona/HistoricalDataCsv/ArchQPC.csv", bindquote(strict) encoding(ISO-8859-1)clear
	compress
	save "${MONA_mirror}/ArchQPC", replace
	
	*import delimited "ArchSPCPASB.csv", encoding(ISO-8859-1)clear
	import delimited "https://www.imf.org/external/np/pdr/mona/HistoricalDataCsv/ArchSPCPASB.csv", encoding(ISO-8859-1)clear
	compress
	save "${MONA_mirror}/ArchSPCPASB", replace
	
	* import ArchReviews
	import delimited "https://www.imf.org/external/np/pdr/mona/HistoricalDataCsv/ArchReviews.csv", encoding(ISO-8859-1)clear
	compress
	save "${MONA_mirror}/ArchReviews", replace

}

// (ii.1)  calculate ACTUAL totalaccess => actual_totalaccess.dta

{

    use "${MONA_mirror}/Purchases.dta", clear
	drop if actualdate == .
	// delete duplicate observations of the "actualdate" in ArchPurchases
	// (no duplicate exists in this data file)
	levelsof arrangementnumber, local(levels)
	foreach i of local levels {
		duplicates drop actualdate if arrangementnumber == `i', force
	}
	// calculate the total amount of support received from IMF during life of program, new var "actualamount"
	bysort arrangementnumber: egen actualamounttotalaccess = sum(actualamount)
	// leave only one observation for each arrangementnumber
	duplicates drop arrangementnumber,force
	compress
	keep arrangementnumber actualamounttotalaccess
	save temp_totalaccess, replace //zzzz

	
	use "${MONA_mirror}/ArchPurchases.dta", clear
	// renaming variables that have the same observations but different names in different files
	// and other fixes
	rename boarddocumentnumber boarddocno
	replace boarddocno = strtrim(boarddocno)
	drop if arrangementnumber == 207 & boarddocno == "SM/97/267" // ETHIOPIA two ESB docs for 1 set of observations

	// delete duplicate observations of the "actualdate" in ArchPurchases
	drop if actualdate == "NULL"
	destring actualamount, replace force
	levelsof arrangementnumber, local(levels)
	foreach i of local levels {
		duplicates drop actualdate if arrangementnumber == `i', force
	}
	// create a new variable that shows the actual amount that the country received over the life of the program 
	bysort arrangementnumber: egen actualamounttotalaccess = sum(actualamount)
	// leave only one observation for each arrangementnumber
	duplicates drop arrangementnumber,force
	keep arrangementnumber actualamounttotalaccess
	
	append  using  temp_totalaccess
	save    actual_totalaccess, replace
	erase   temp_totalaccess.dta


// (ii.2) calculate APPROVED totalaccess => totalaccess.dta
	use "${MONA_mirror}/Purchases.dta", clear
	replace reviewsequence = strtrim(reviewsequence)
	replace reviewsequence = "E"  if  inlist(arrangementnumber, 580, 582, 587)
	drop if originalscheduleddate == .   |  reviewsequence=="BLANK"  |  reviewsequence=="L" 
	// delete duplicate observations of the "actualdate" in ArchPurchases
	// (no duplicate exists in this data file)
	levelsof arrangementnumber, local(levels)
	foreach i of local levels {
		duplicates drop originalscheduleddate if arrangementnumber == `i', force
	}
	// calculate the total amount of support received from IMF during life of program, new var "actualamount"
	bysort arrangementnumber: egen approveamounttotalaccess = sum(originalscheduledamount)
	// leave only one observation for each arrangementnumber
	duplicates drop arrangementnumber,force
	compress
	keep arrangementnumber approveamounttotalaccess
	save temp_approvetotalaccess, replace //zzzz

	
	use "${MONA_mirror}/ArchPurchases.dta", clear
	// renaming variables that have the same observations but different names in different files
	// and other fixes
	rename boarddocumentnumber boarddocno
	replace boarddocno = strtrim(boarddocno)
	replace reviewtype = strtrim(reviewtype)
	drop if arrangementnumber == 207 & boarddocno == "SM/97/267" // ETHIOPIA two ESB docs for 1 set of observations

	// delete duplicate observations of the "actualdate" in ArchPurchases
	replace reviewtype = "OldBoardApproval"  if  inlist(arrangementnumber, 126)
	drop if originalscheduleddate == "NULL" |  reviewtype!="OldBoardApproval"  
	destring originalscheduledamount, replace force
	levelsof arrangementnumber, local(levels)
	foreach i of local levels {
		duplicates drop originalscheduleddate if arrangementnumber == `i', force
	}
	
	// create a new variable that shows the actual amount that the country received over the life of the program 
	bysort arrangementnumber: egen approveamounttotalaccess = sum(originalscheduledamount)
	// leave only one observation for each arrangementnumber
	duplicates drop arrangementnumber,force
	keep arrangementnumber approveamounttotalaccess
	
	append  using  temp_approvetotalaccess
	save    approve_totalaccess, replace
	
    merge 1:1  arrangementnumber  using  actual_totalaccess
	drop    _m
	replace actualamounttotalaccess=0 if actualamounttotalaccess==.
	save    totalaccess, replace
	
	erase   temp_approvetotalaccess.dta
	erase   approve_totalaccess.dta
	erase   actual_totalaccess.dta
	
}	
	
// (iii) cancelled programs  => cancelled_all.dta
{
	use "${MONA_mirror}/Description", clear
	
	keep arrangementnumber arrangementtype approvalyear countryname cancelled
	keep if cancelled=="Y"
	duplicates drop
	keep arrangementnumber cancelled
	save cancelled_new, replace
	
	append  using "${inputfiles}/cancelled_old_Theo.dta"
	save cancelled_all, replace
	
	erase   cancelled_new.dta
	
	
	*import delimited "https://www.imf.org/external/np/pdr/mona/HistoricalDataCsv/ArchDescription.csv", encoding(ISO-8859-1)clear
	*compress
	*save "ArchDescription", replace
}	
	
// (iv) conditionality => condition.dta
{
    use "${MONA_mirror}/QPC", clear
	// recoding variables and creating QPC dummies as in OLD MONA
	rename boarddocumentnumber boarddocno
	gen     newcode = "cond_total_domestic_credit"                  if criteriaorder == 1
	replace newcode = "cond_credit_to_govt_public_s" 				if criteriaorder == 16
	replace newcode = "cond_bop_reserve_test" 						if criteriaorder == 32
	replace newcode = "cond_ceiling_external_arrears" 				if criteriaorder == 114
	replace newcode = "cond_no_new_arrears_default_ci" 				if criteriaorder == 107
	replace newcode = "cond_ML_term_external_debt" 					if criteriaorder == 47 | criteriaorder == 74
	replace newcode = "cond_short_term_debt" 						if criteriaorder == 84
	replace newcode = "cond_fiscal_balance" 						if criteriaorder == 135
	replace newcode = "cond_domestic_arrears" 						if criteriaorder == 149
	// QPC DUMMIES temporary var
	levelsof newcode, local(levels)
	foreach var of local levels {
		gen t_`var' = (newcode == "`var'")
	}
	// QPC DUMMIES generated
	levelsof newcode, local(levels)
	foreach var of local levels {
		bysort arrangementnumber: egen `var' = max(t_`var')
	}
	duplicates drop arrangementnumber,force
	drop t_*
	compress
	
    keep arrangementnumber  cond_*
	save temp_condition, replace //zzzz
	
	
	use "${MONA_mirror}/ArchQPC", clear
	// renaming variables that have the same observations but different names in different files
	rename boarddocumentnumber boarddocno
	drop if arrangementnumber == 207 & boarddocno == "SM/97/267"
	// QPC (quality performance conditions, QPC) is identified with numbers
	// we create QPC dummy variables and program performance categroies that conform with NEW MONA QPC categories
	// see definitions at https://www.imf.org/external/np/pdr/mona/ArchQPC_Codes.htm
	gen     newcode = "cond_total_domestic_credit" 				 	if criteriaorder <=14
	replace newcode = "cond_credit_to_govt_public_s" 			    if criteriaorder >= 18 & criteriaorder <= 37
	replace newcode = "cond_bop_reserve_test" 						if criteriaorder >= 46 & criteriaorder <= 54
	replace newcode = "cond_ceiling_external_arrears" 			    if criteriaorder >= 61 & criteriaorder <= 80
	replace newcode = "cond_no_new_arrears_default_ci" 				if criteriaorder >= 81 & criteriaorder <= 84
	replace newcode = "cond_ML_term_external_debt" 			        if criteriaorder >= 90 & criteriaorder <= 94
	replace newcode = "cond_short_term_debt"							if criteriaorder >= 119 & criteriaorder <= 131
	replace newcode = "cond_fiscal_balance" 							if criteriaorder >= 157 & criteriaorder <= 171
	replace newcode = "cond_fiscal_balance" 							if criteriaorder == 174
	replace newcode = "cond_domestic_arrears" 				    	if criteriaorder == 172
	// QPC DUMMIES (temporary var)
	levelsof newcode, local(levels)
	foreach var of local levels {
		gen t_`var' = (newcode == "`var'")
	}
	// QPC DUMMIES (generating dummy variables)
	levelsof newcode, local(levels)
	foreach var of local levels {
		bysort arrangementnumber: egen `var' = max(t_`var')
	}
	duplicates drop arrangementnumber,force
	drop t_*
	compress
    keep arrangementnumber  cond_*
	
    append  using   temp_condition
	save   condition, replace
	
	erase temp_condition.dta
	
}	

// (v) SPC (structral) conditionality => condition.dta	

{
	
	// combined SPC PA and SB, new MONA    
	use "${MONA_mirror}/Combined", clear
	save SPC_newMONA.dta, replace
	
	*use SPC_newMONA.dta, clear
	
	**unique arrangementnumber
	tab economicdescriptor
	
	gen         economiccode_sub = floor(economiccode)
	gen         newcode = ""  
	replace     newcode = "sc_gen_govt"              if economiccode_sub == 20
	replace     newcode = "sc_central_bank"          if economiccode_sub == 21
	replace     newcode = "sc_civil_service"         if economiccode_sub == 22
	replace     newcode = "sc_pension"               if economiccode_sub == 23
	replace     newcode = "sc_pub_enterprise"        if economiccode_sub == 24
	replace     newcode = "sc_fin_sector"            if economiccode_sub == 25
	replace     newcode = "sc_exchange_sys"          if economiccode_sub == 26
	replace     newcode = "sc_intl_trade"            if economiccode_sub == 27
	replace     newcode = "sc_labor_mkt"             if economiccode_sub == 28
	replace     newcode = "sc_econ_stat"             if economiccode_sub == 29
	replace     newcode = "sc_other"                 if economiccode_sub == 30
	
	/*
	* labels
	20	1. General government
	21	2. Central Bank
	22	3. Civil service and public employment reforms, and wages
	23	4. Pension and other social sector reforms
	24	5. Public enterprise reform and pricing  (non financial sector)
	25	6. Financial sector
	26	7. Exchange systems and restrictions (current and capital)
	27	8. International trade policy, excluding customs reforms
	28	9. Labor markets, excluding public sector employment
	29	10. Economic statistics (excluding fiscal and central bank transparency and similar measures)
	30	11. Other structural measures
	*/
	
	// SC DUMMIES temporary var
	levelsof newcode, local(levels)
	foreach var of local levels {
		gen t_`var' = (newcode == "`var'")
	}
	// SC DUMMIES generated by program 
	levelsof newcode, local(levels)
	foreach var of local levels {
		bysort arrangementnumber: egen `var' = max(t_`var')
	}
	duplicates drop arrangementnumber,force
	drop t_*
	compress
	
    keep arrangementnumber  sc_*
	save temp_sc, replace 
	
	
	
// combined SPC PA and SB, old MONA  		
	use "${MONA_mirror}/ArchSPCPASB", clear
	save SPC_oldMONA.dta, replace	
	**unique arrangementnumber

	
	* clean up descriptor
	replace economicdescriptor = lower(economicdescriptor)
	gen ed_code = .
	
	// recode to be consistent with new MONA code above
	{
	* General government
	replace ed_code = 20 if economicdescriptor == "tax expenditure reform"
	replace ed_code = 20 if economicdescriptor == "tax expenditure reform (cont.)"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure (6th/7th revie"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure (pgm prior act"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure (structural be"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure ref. (con't)"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (4th/5t"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (ccr 3r"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (ccr 4t"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (ccr 5t"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (ccr, 2"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (cont.)"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (contin"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (perf."
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (perfor"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (prior"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform (struct"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform 2"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform cont."
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform cont. 1"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform cont. 2"
	replace ed_code = 20 if economicdescriptor == "tax/expenditure reform--con't"
	replace ed_code = 20 if economicdescriptor == "other-tax/exp. reform (cont.)"
	replace ed_code = 20 if economicdescriptor == "other: customs reform"
	replace ed_code = 20 if economicdescriptor == "cont. - tax/expenditure reform"
	replace ed_code = 20 if economicdescriptor == "cont. tax expenditure reform"
	replace ed_code = 20 if economicdescriptor == "cont.-tax/expenditure reform"
	replace ed_code = 20 if economicdescriptor == "cont2.-tax/expenditure reform"
	replace ed_code = 20 if economicdescriptor == "other (fiscal monitoring, repo"
	replace ed_code = 20 if economicdescriptor == "other (fiscal reform)"
	replace ed_code = 20 if economicdescriptor == "other (fiscal reforms)"
	replace ed_code = 20 if economicdescriptor == "other (ta/expend reform, contd"
	replace ed_code = 20 if economicdescriptor == "other (tax/expenditure reform"
	replace ed_code = 20 if economicdescriptor == "other (tax/expenditure reform)"
	replace ed_code = 20 if economicdescriptor == "other (tax/expenditure reform,"
	replace ed_code = 20 if economicdescriptor == "other (tax/expenditure reform:"
	replace ed_code = 20 if economicdescriptor == "other tax/expend. (continued)"
	replace ed_code = 20 if economicdescriptor == "other (governance)"
	replace ed_code = 20 if economicdescriptor == "other (governance, transparenc"
	replace ed_code = 20 if economicdescriptor == "domestic arrears"
	
	* Central Bank
	
	
	* Civil service and public employment reforms, and wages
	replace ed_code = 22 if economicdescriptor == "civil service reform"
	replace ed_code = 22 if economicdescriptor == "civil service reform (4th/5th"
	replace ed_code = 22 if economicdescriptor == "other - civil service"
	replace ed_code = 22 if economicdescriptor == "other (public employment)"
	replace ed_code = 22 if economicdescriptor == "other: civil service"
	replace ed_code = 22 if economicdescriptor == "other: civil service reform"
	replace ed_code = 22 if economicdescriptor == "other (civil service reform)"
	replace ed_code = 22 if economicdescriptor == "other (civli service reform)"
	replace ed_code = 22 if economicdescriptor == "other- civil service reform"
	replace ed_code = 22 if economicdescriptor == "other-civil service reform"
	
    * Pension and other social sector reforms
	replace ed_code = 23 if economicdescriptor == "pension reform (4th/5th review"
	replace ed_code = 23 if economicdescriptor == "pension reform (6th/7th review"
	replace ed_code = 23 if economicdescriptor == "social security reform"
	replace ed_code = 23 if economicdescriptor == "social security reform-con't"
	replace ed_code = 23 if economicdescriptor == "other (social policy)"	
	replace ed_code = 23 if economicdescriptor == "other (civil service pensions)"
	replace ed_code = 23 if economicdescriptor == "other (social sector)"
	replace ed_code = 23 if economicdescriptor == "other (social security system)"
	replace ed_code = 23 if economicdescriptor == "other (pension reform)"	
	replace ed_code = 23 if economicdescriptor == "other (social safety net)"
	
	* Public enterprise reform and pricing  (non financial sector)
	replace ed_code = 24 if economicdescriptor == "public enterpises (continued)"
	replace ed_code = 24 if economicdescriptor == "public enterprises"
	replace ed_code = 24 if economicdescriptor == "public enterprises (con't)"
	replace ed_code = 24 if economicdescriptor == "public enterprises (cont. 2)"
	replace ed_code = 24 if economicdescriptor == "public enterprises (cont.)"
	replace ed_code = 24 if economicdescriptor == "public enterprises (continued)"
	replace ed_code = 24 if economicdescriptor == "public enterprises (prior acti"
	replace ed_code = 24 if economicdescriptor == "public enterprises (str. bench"
	replace ed_code = 24 if economicdescriptor == "public enterprises (structural"
	replace ed_code = 24 if economicdescriptor == "public enterprises and civil s"
	replace ed_code = 24 if economicdescriptor == "public enterprises continued"
	replace ed_code = 24 if economicdescriptor == "other (public enterprises)"
    replace ed_code = 24 if economicdescriptor == "other (public enterprises, con"
	replace ed_code = 24 if economicdescriptor == "pricing & marketing policies"
	replace ed_code = 24 if economicdescriptor == "pricing & marketing policies ("
	replace ed_code = 24 if economicdescriptor == "pricing & marketing policies 2"
	replace ed_code = 24 if economicdescriptor == "pricing and marketing (prior a"
	replace ed_code = 24 if economicdescriptor == "pricing and marketing policies"
	replace ed_code = 24 if economicdescriptor == "pricing/marketing (structural"
	replace ed_code = 24 if economicdescriptor == "other (pricing & marketing pol"
	replace ed_code = 24 if economicdescriptor == "other (pricing and marketing p"
	replace ed_code = 24 if economicdescriptor == "system/ownership reform cont.1"
	replace ed_code = 24 if economicdescriptor == "system/ownership reform cont.2"
	replace ed_code = 24 if economicdescriptor == "systemic & owner ref. (con't)"
	replace ed_code = 24 if economicdescriptor == "systemic & owner. ref.(concl.)"
	replace ed_code = 24 if economicdescriptor == "systemic & ownership (ccr)"
	replace ed_code = 24 if economicdescriptor == "systemic & ownership reform (s"
	replace ed_code = 24 if economicdescriptor == "systemic & ownership reform 2"
	replace ed_code = 24 if economicdescriptor == "systemic and ownership reform"
	replace ed_code = 24 if economicdescriptor == "systemic and ownership reform:"
	replace ed_code = 24 if economicdescriptor == "systemic/owner. reform (con't)"
	replace ed_code = 24 if economicdescriptor == "systemic/ownership (prior acti"
	replace ed_code = 24 if economicdescriptor == "systemic/ownership (structural"
	replace ed_code = 24 if economicdescriptor == "systemic/ownership reform"
	replace ed_code = 24 if economicdescriptor == "systemic/ownership reform (cnt"
	replace ed_code = 24 if economicdescriptor == "systemic/ownership reform 2"
	replace ed_code = 24 if economicdescriptor == "systemic/ownership reform cont"
	replace ed_code = 24 if economicdescriptor == "other (systemic and ownership"
	replace ed_code = 24 if economicdescriptor == "other (systemic,ownership refo"
	replace ed_code = 24 if economicdescriptor == "other (systemic/ownership refo"
	replace ed_code = 24 if economicdescriptor == "other-pub. enterprises (cont.)"
	replace ed_code = 24 if economicdescriptor == "cont-systemic/ownership reform"
	replace ed_code = 24 if economicdescriptor == "other-cont. systemic&ownersh."
	replace ed_code = 24 if economicdescriptor == "other - systemic and ownership"
	
	
	* Financial sector
	replace ed_code = 25 if economicdescriptor == "financial sector"
	replace ed_code = 25 if economicdescriptor == "financial sector (2)"
	replace ed_code = 25 if economicdescriptor == "financial sector (ccr 3rd revi"
	replace ed_code = 25 if economicdescriptor == "financial sector (ccr 4th revi"
	replace ed_code = 25 if economicdescriptor == "financial sector (ccr 5th and"
	replace ed_code = 25 if economicdescriptor == "financial sector (cont.)"
	replace ed_code = 25 if economicdescriptor == "financial sector (continued 3)"
	replace ed_code = 25 if economicdescriptor == "financial sector (continued)"
	replace ed_code = 25 if economicdescriptor == "financial sector (continued, 2"
	replace ed_code = 25 if economicdescriptor == "financial sector (prior action"
	replace ed_code = 25 if economicdescriptor == "financial sector (program prio"
	replace ed_code = 25 if economicdescriptor == "financial sector (str. benchma"
	replace ed_code = 25 if economicdescriptor == "financial sector (structural b"
	replace ed_code = 25 if economicdescriptor == "financial sector - continued"
	replace ed_code = 25 if economicdescriptor == "financial sector continued"
	replace ed_code = 25 if economicdescriptor == "financial sector continued 1"
	replace ed_code = 25 if economicdescriptor == "financial sector continued 2"
	replace ed_code = 25 if economicdescriptor == "financial sector reform (conti"
	replace ed_code = 25 if economicdescriptor == "financial sector reform (prior"
	replace ed_code = 25 if economicdescriptor == "financial sector reform (struc"
	replace ed_code = 25 if economicdescriptor == "other-financial sector"
	replace ed_code = 25 if economicdescriptor == "other (financial sector 2)"
	replace ed_code = 25 if economicdescriptor == "other (financial sector reform"
	replace ed_code = 25 if economicdescriptor == "other (financial sector)"
	replace ed_code = 25 if economicdescriptor == "other (financial sector, 2)"
	replace ed_code = 25 if economicdescriptor == "other (financial sector: 4th r"
	replace ed_code = 25 if economicdescriptor == "financial reform (ccr, 2nd rev"
	replace ed_code = 25 if economicdescriptor == "financial reform (concluded)"
	
	* Exchange systems and restrictions (current and capital)
	replace ed_code = 26 if economicdescriptor == "exchange system"
	replace ed_code = 26 if economicdescriptor == "exchange system (continued)"
	replace ed_code = 26 if economicdescriptor == "exchange system contd"
	replace ed_code = 26 if economicdescriptor == "exchange system continued"
	replace ed_code = 26 if economicdescriptor == "other (foreign reserve managem"
	replace ed_code = 26 if economicdescriptor == "other (external debt)"
	
	* International trade policy, excluding customs reforms
	replace ed_code = 27 if economicdescriptor == "other (trade reform)"
	replace ed_code = 27 if economicdescriptor == "other (trade system)"
	replace ed_code = 27 if economicdescriptor == "other (trade system, cont'd)"
	replace ed_code = 27 if economicdescriptor == "trade policy (prior actions)"
	replace ed_code = 27 if economicdescriptor == "trade system (continued)"
	replace ed_code = 27 if economicdescriptor == "trade system (prior action)"
	replace ed_code = 27 if economicdescriptor == "trade system (structural bench"
	replace ed_code = 27 if economicdescriptor == "trade system continued"
	replace ed_code = 27 if economicdescriptor == "trade systems"
	replace ed_code = 27 if economicdescriptor == "trade systems (structural benc"
	replace ed_code = 27 if economicdescriptor == "trade systems continued"
	replace ed_code = 27 if economicdescriptor == "trade systems continued 1"
	replace ed_code = 27 if economicdescriptor == "trade systems continued 2"
	
	* Labor markets, excluding public sector employment
	
    * Economic statistics (excluding fiscal and central bank transparency and similar measures)
	replace ed_code = 29 if economicdescriptor == "other (data)"
	replace ed_code = 29 if economicdescriptor == "other (investment, statistics)"
	replace ed_code = 29 if economicdescriptor == "other (national accounts)"
	replace ed_code = 29 if economicdescriptor == "other (statistics strengthenin"
	replace ed_code = 29 if economicdescriptor == "other (statistics)"
	
    * Other structural measures
	replace ed_code = 30 if economicdescriptor == "other (private sector)"
	replace ed_code = 30 if economicdescriptor == "other (energy sector, ccr 2nd"
	replace ed_code = 30 if economicdescriptor == "other (energy sector, ccr 3rd"
	replace ed_code = 30 if economicdescriptor == "other (energy)"
	replace ed_code = 30 if economicdescriptor == "other (energy, cont'd)"
	replace ed_code = 30 if economicdescriptor == "other (prior actions, board ap"
	replace ed_code = 30 if economicdescriptor == "other, 1"
	replace ed_code = 30 if economicdescriptor == "other, 2"
	replace ed_code = 30 if economicdescriptor == "other, 3"
	replace ed_code = 30 if economicdescriptor == "other-1"
	replace ed_code = 30 if economicdescriptor == "other-2"
    replace ed_code = 30 if ed_code == .  // the rest are all other
    }

    * recode to be consistent with new MONA
	gen         newcode = ""  
	replace     newcode = "sc_gen_govt"              if ed_code == 20
	replace     newcode = "sc_central_bank"          if ed_code == 21  // missing in old MONA, check later?
	replace     newcode = "sc_civil_service"         if ed_code == 22
	replace     newcode = "sc_pension"               if ed_code == 23
	replace     newcode = "sc_pub_enterprise"        if ed_code == 24
	replace     newcode = "sc_fin_sector"            if ed_code == 25
	replace     newcode = "sc_exchange_sys"          if ed_code == 26
	replace     newcode = "sc_intl_trade"            if ed_code == 27
	replace     newcode = "sc_labor_mkt"             if ed_code == 28  // missing in old MONA, check later?
	replace     newcode = "sc_econ_stat"             if ed_code == 29
	replace     newcode = "sc_other"                 if ed_code == 30
	

	// SC DUMMIES temporary var
	levelsof newcode, local(levels)
	foreach var of local levels {
		gen t_`var' = (newcode == "`var'")
	}
	// SC DUMMIES generated by program 
	levelsof newcode, local(levels)
	foreach var of local levels {
		bysort arrangementnumber: egen `var' = max(t_`var')
	}
	duplicates drop arrangementnumber,force
	drop t_*
	compress
	
    keep arrangementnumber  sc_*
	gen  sc_central_bank=0
	gen  sc_labor_mkt=0
	
	* combine old and new MONA
	append  using   temp_sc
	save   sc_condition, replace
	
	erase temp_sc.dta
	erase SPC_oldMONA.dta
	erase SPC_newMONA.dta
		

}
	


********************************************************************************
*   2. Compile OLD MONA data (including mapping final offical data from WEO)
*      (i) prepare IMF data for merging old MONA
*      (ii) clean old MONA data (keep all reviews)
*      (iii) merge IMF and old MONA data
*      (iv) get ready of old MONA for append new MONA
********************************************************************************

/*
// setup root directory
cd "/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/input files_non-MONA"
clear
set more off

* directory of MONA mirror files 
local MONA_mirror="/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/MONA_mirror_Nov19"
* directory of other input files 
local inputfiles="/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/input files_non-MONA"
*/



*************************************************
// (i) prepare IMF data for merging old MONA

use WEO_export_Oct2020, clear

* Fixed bug of code for Serbia, Kosova
replace   iso2="RS"       if iso3 == "SRB"     /*Serbia*/
replace   iso2="XK"       if iso3 == "UVK"     /*Kosovo*/

// ERROR FIX of IMF data
* fix the unit issue of Senegal's NGDP
replace   yvalue = yvalue*1000    if iso3=="SEN" & mneumonic=="NGDP"
append    using USD2_BOPIFS_export.dta, force
append using NEW_WB_USD2_export.dta, force

*BOPIFS_export.dta
kountry   iso2, from(iso2c) to(imfn)
rename    _IMFN_ countrycode    /* (PRI, SSD, TUV, UVK) can't be found */

kountry   iso3, from(iso3c) to(imfn)
drop _IMFN_

kountry   iso2c, from(iso2c) to(imfn)


rename _IMFN_ countrycode2
replace countrycode = countrycode2 if countrycode ==.
drop countrycode2
replace iso2 = iso2c if iso2 ==""
replace weo_yearid = year if weo_yearid ==.

replace   countrycode=942 if iso2 == "RS"     /* Servia */
replace   countrycode=967 if iso2 == "XK"     /* Kosovo */
drop      if countrycode==.  | countrycode==728    // dupliate data of Namibia. not in MONA 


replace mneumonic = "BCA"  if INDICATOR =="BCA_BP6_USD"
replace mneumonic = "BFD"  if INDICATOR =="BFD_BP6_USD"
replace mneumonic = "BFO"  if INDICATOR =="BFO_BP6_USD"
replace mneumonic = "BFP"  if INDICATOR =="BFP_BP6_USD"
replace mneumonic = "BFRA"  if INDICATOR =="BFRA_BP6_USD"
replace mneumonic = "BF"  if INDICATOR =="BF_BP6_USD"
replace mneumonic = "BI"  if INDICATOR =="BIP_BP6_USD"
replace mneumonic = "BTR"  if INDICATOR =="BIS_BP6_USD"
replace mneumonic = "BMGS"  if INDICATOR =="BMGS_BP6_USD"
replace mneumonic = "BMG"  if INDICATOR =="BMG_BP6_USD"
replace mneumonic = "BMS"  if INDICATOR =="BMS_BP6_USD"
replace mneumonic = "BXGS"  if INDICATOR =="BXGS_BP6_USD"
replace mneumonic = "BXG"  if INDICATOR =="BXG_BP6_USD"
replace mneumonic = "BXS"  if INDICATOR =="BXS_BP6_USD"
replace mneumonic = "ENDA"  if INDICATOR =="ENDA_XDC_USD_RATE"
replace mneumonic = "ENDE"  if INDICATOR =="ENDE_XDC_USD_RATE"
replace mneumonic = "ENSA"  if INDICATOR =="ENSA_XDC_XDR_RATE"
replace mneumonic = "NCG"  if INDICATOR =="NCGG_XDC"
replace mneumonic = "NCP"  if INDICATOR =="NCP_XDC"
replace mneumonic = "NFIP"  if INDICATOR =="NFIAXD_XDC"
replace mneumonic = "NFI"  if INDICATOR =="NFI_XDC"
replace mneumonic = "NI"  if INDICATOR =="NI_XDC"
replace mneumonic = "NMG"  if INDICATOR =="NMG_XDC"
replace mneumonic = "NMS"  if INDICATOR =="NMS_XDC"
replace mneumonic = "NM"  if INDICATOR =="NM_XDC"
replace mneumonic = "NXG"  if INDICATOR =="NXG_XDC"
replace mneumonic = "NXS"  if INDICATOR =="NXS_XDC"
replace mneumonic = "NX"  if INDICATOR =="NX_XDC"
replace mneumonic = "NM1"  if INDICATOR =="TMG_FOB_USD"
replace mneumonic = "NX1"  if INDICATOR =="TXG_FOB_USD"
*NFIAXD: National Accounts, Expenditure, Gross Domestic Product, Gross Capital Formation, Private Sector (Corporations, Households, and Non-profit Institutions Serving Households), Acquisitions less Disposals of Valuables, Nominal, Domestic Currency
*NFI:National Accounts, Expenditure, Gross Domestic Product, Gross Capital Formation, Gross Fixed Capital Formation, Nominal, Domestic Currency

keep      countrycode mneumonic weo_yearid yvalue
sort      countrycode mneumonic weo_yearid


// for MONA programs labeled as "FY", map with NGDP_FY instead
drop if   mneumonic == "NGDP"  &  inlist(countrycode, 263,316,343,469,512,513,536,558,564,622,638,644,664,666,668,724,738,746)
replace   mneumonic = "NGDP"  if mneumonic == "NGDP_FY" &  inlist(countrycode, 263,316,343,469,512,513,536,558,564,622,638,644,664,666,668,724,738,746)
drop if   mneumonic == "NGDP_FY"
sort      countrycode mneumonic weo_yearid

*duplicates drop
drop if mneumonic ==""

duplicates drop
reshape   wide yvalue, i(countrycode weo_yearid) j(mneumonic, string)

*new variable constructed ********************************************

* create new variables for comparing with OLD MONA
gen       yvalueGCECY = yvalueNCG/yvalueNGDP *100 /* GCECY is Current Non-Interest Expenditures (percent of GDP)*/
gen       yvalueNI_Y  = yvalueNI/yvalueNGDP *100 /* NI_Y is Gross Domestic Investment (percent of GDP)*/

gen       yvalueNM_usd = yvalueBMGS
gen       yvalueNX_usd = yvalueBXGS

gen dum_imf_BMGS = 1 if yvalueNM_usd !=.
gen dum_imf_BXGS = 1 if yvalueNX_usd !=.

replace dum_imf_BMGS = 0 if yvalueNM_usd ==.
replace dum_imf_BXGS = 0 if yvalueNX_usd ==.

*fix the unit to be consistent
replace yvalueWB_import = yvalueWB_import/10^9
replace yvalueWB_export = yvalueWB_export/10^9

replace dum_imf_BMGS = 2 if yvalueNM_usd ==. & yvalueWB_import !=.
replace dum_imf_BXGS = 2 if yvalueNX_usd ==. & yvalueWB_export !=.

replace  yvalueNM_usd = yvalueWB_import    if  yvalueNM_usd ==.
replace  yvalueNX_usd = yvalueWB_export    if  yvalueNX_usd ==.

*dummy generated
replace dum_imf_BMGS = 3 if yvalueNM_usd ==. & yvalueNM !=. & yvalueENDA !=.

replace dum_imf_BXGS = 3 if yvalueNX_usd ==. & yvalueNX !=. & yvalueENDA !=.


replace   yvalueNM_usd = yvalueNM / yvalueENDA    if  yvalueNM_usd ==.
replace   yvalueNX_usd = yvalueNX / yvalueENDA    if  yvalueNX_usd ==.

drop yvalueNM yvalueNX
rename yvalueNM_usd  yvalueNM
rename yvalueNX_usd  yvalueNX

*drop dum_imf_BMGS dum_imf_BXGS
rename dum_imf_BMGS yvaluedum_imf_BMGS
rename dum_imf_BXGS yvaluedum_imf_BXGS



*then NM NX here are going to be USD based data
***********************************************************************

reshape   long yvalue, i(countrycode weo_yearid) j(mneumonic, string)
sort      countrycode mneumonic weo_yearid

* rename variables for consistency with old MONA
replace   mneumonic = "PCPIE_rate"   if  mneumonic == "PCPIEPCH"    /* it's the CPI INFLATION for old MONA program (1-433) */
replace   mneumonic = "PCPIE_index"  if  mneumonic == "PCPIE"    /* it's the CPI INFLATION for old MONA program (1-433) */
replace   mneumonic = "RGDP_rate"  	 if  mneumonic == "NGDP_RPCH"   /* it's the real GDP GROWTH for old MONA program (1-433) */
replace   mneumonic = "BMT"        	 if  mneumonic == "BMG" /*Imports of goods (c.i.f) in USD billion */
replace   mneumonic = "BXT"        	 if  mneumonic == "BXG" /*Exports of goods (f.o.b.) in USD billion */
replace   mneumonic = "BMS_O"     	 if  mneumonic == "BMS" /*Imports of services in USD billion */
replace   mneumonic = "BXS_O"      	 if  mneumonic == "BXS" /*Exports of services in USD billion */

keep      if    inlist(mneumonic, "RGDP_rate", "PCPIE_rate", "PCPIE_index", "NGDP", "GCECY", "NI_Y" )  ///
              | inlist(mneumonic, "BMT", "BXT", "BMS_O", "BXS_O", "ENDA","ENDE")  ///
			  | inlist(mneumonic, "NM", "NX", "dum_imf_BMGS", "dum_imf_BXGS") // reina added  "NM1", "NX1", "NM_usd", "NX_usd"
			  
			  			  
reshape   wide yvalue, i(countrycode mneumonic) j(weo_yearid)


save      IMFdata_mergeOLDMONA.dta, replace
 
*************************************************
// (ii) clean old MONA data (keep all reviews)


set more off

// generate ArchMecon_cleaned
use "${MONA_mirror}/ArchMecon", clear
*unique     arrangementnumber    /* 332 programs, 1 to 434 */
sum        programyear          /* 1992-2003    */


// fix different programyear issue (for the same program), based on variable "Duration Of Annual Arrangement From"
replace    programyear = 1993     if arrangementnumber == 15
replace    programyear = 1993     if arrangementnumber == 18
replace    programyear = 1995     if arrangementnumber == 132
replace    programyear = 1996     if arrangementnumber == 143
replace    programyear = 1996     if arrangementnumber == 230
replace    programyear = 1998     if arrangementnumber == 274


// select variables needed
keep       if    inlist(mneumonic, "NGDP", "RGDPC", "NI_Y", "GCECY", "PCPIC")  ///
              |  inlist(mneumonic, "BMT", "BXT", "BXS_O", "BMS_O", "ENDA") ///"BMT", "BXT", "BXS_O", "BMS_O"-$ based data

* rename variables to avoid confusion
replace   mneumonic = "PCPIE_rate"   if  mneumonic == "PCPIC"       /* it's the CPI INFLATION for old MONA program (1-433) */
replace   mneumonic = "RGDP_rate"  	 if  mneumonic == "RGDPC"       /* it's the real GDP GROWTH for old MONA program (1-433) */



// remove white spaces that contaminate mneumonic names from bad xls importing
replace    mneumonic = strtrim(mneumonic)
replace    boarddocno = strtrim(boarddocno)
replace    countryname = strtrim(countryname)
replace    arrangementtype = strtrim(arrangementtype)
replace    reviewsequence = strtrim(reviewsequence)
replace    description = strtrim(description)

* rename
rename 	   t3  tminus3
rename     t2  tminus2
rename     t1  tminus1
rename     v26 tplus1
rename     v27 tplus2
rename     v28 tplus3
rename     t4  tplus4



destring   tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4, replace force


// mark observations with multiple zero entries:
egen    count0 = anycount(tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4), value(0)
*egen    mark_five0  = rowtotal(t tplus1 tplus2 tplus3 tplus4)
	local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	foreach    v in `vars' {
				  replace `v'=.    if `v'== 0  & count0 >0    &  !inlist(mneumonic,"RGDP_rate", "PCPIE_rate") //Exchange rate cannot be zero
	}
drop    count0




// Identify first and last review
tab 	   reviewtype
tab 	   reviewtype reviewsequence

* recode review type
replace    reviewtype="R0"     if reviewtype == "OldBoardApproval"   /* R0 =first review*/
replace    reviewtype="R20"    if reviewtype == "OC"                 /* R20= last review*/

* fix errors of review
replace    reviewtype="R20"    if reviewsequence=="L"  &  arrangementnumber==207       /* fix error of #207 Ethiopia */
drop       if     arrangementnumber==296  & reviewsequence=="L"                        /* fix error of #296 Ghana */
drop       if     arrangementnumber==187  &  reviewtype=="R20"                         /* fix error of #187 UZBEKISTAN */
drop       if     arrangementnumber==195  &  reviewsequence=="L"                        /* fix error of #195 PERU */
drop       if     arrangementnumber==351  &  reviewtype=="R4"                         /* fix error of #351 CAMEROON */


sort       arrangementnumber mneumonic reviewtype
gen        recode_reviewtype = substr(reviewtype, 2,3)
destring   recode_reviewtype, replace

* fix first review ID
by		   arrangementnumber mneumonic (recode_reviewtype), sort: gen byte first_review = (_n == 1)  if t!=.  /* no problem with definition of intial review "E" */
replace    reviewsequence="E"   if  reviewtype=="R0"   &   t!=.
replace    reviewsequence="E"   if  first_review==1    &   reviewsequence=="BLANK"   &    approvalyear<=programyear


* fix last review ID
sort       arrangementnumber mneumonic recode_reviewtype
by         arrangementnumber mneumonic (recode_reviewtype), sort: gen byte last_review = (_n == _N)   if t!=.
replace    reviewsequence="L"   if  reviewtype=="R20"   &   t!=.
replace    reviewsequence="L"   if  last_review==1      &   first_review!=1    &   reviewsequence=="BLANK"

*keep       if inlist(reviewsequence, "E", "L")   /* drop intermediate reviews */

duplicates list arrangementnumber mneumonic recode_reviewtype

// check if all programs have E review?
tab arrangementnumber reviewsequence



// CLEAN UP DATA

	* check if any variable looks odd
	*bys        mneumonic: asdoc tabstat t,     replace stat(N mean sd min p5 p25 p50 p75 p95 max)


	// convert date variables                         
	rename    intialenddate initialenddate
	foreach   var in initialenddate revisedenddate durationofannualarrangementfrom durationofannualarrangementto {
				 replace `var' = "" if `var' == "NULL"
	}
	mdesc *date duration*

	* revisedenddate are all missing
	foreach   var in approvaldate initialenddate durationofannualarrangementfrom durationofannualarrangementto{
				gen t`var' = date(`var', "MDY")
				drop `var'
				rename t`var' `var'
				format `var' %td
		}
	// wrong country name of #117:  should be Albania not Algeria
	replace     countryname = "ALBANIA"     if    arrangementnumber ==117
	replace     countrycode = 914           if    arrangementnumber ==117


	// DATA ENTRY ISSUE 1: negative numbers of imports and exports:
	local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	foreach    v in `vars' {
				  replace `v'=abs(`v') if inlist(mneumonic,"BMT", "BMS_O", "BXT", "BXS_O") //USD based datas
	}


	// DATA ENTRY ISSUE 2: TYPOS


  *9/14/2020 no longer need to fix if convert all to NC
  * #35 CAMEROON: first review data in NC/SDR, change to NC/USD for consistency 
  replace tminus2 = 280.4    if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "ENDA"
  replace tminus1 = 265.4    if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "ENDA"
  replace t = 440.7          if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "ENDA"
  replace tplus1 = 597.7     if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "ENDA"
  replace tplus2 = 605.4     if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "ENDA"
  replace tplus3 = 613.1     if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "ENDA"
  replace tplus3 = 620.1     if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "ENDA"
  replace indicatorcurrency = "USD (millions)"     if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "ENDA"
 
         
  * #75 Turkey: period-avg inflation from EBS entered
  replace tminus2 = 82.6     if arrangementnumber == 75  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tminus1 = 63.5     if arrangementnumber == 75  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace t = 111.3          if arrangementnumber == 75  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tplus1 = 30        if arrangementnumber == 75  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tplus2 = 10        if arrangementnumber == 75  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tplus2 = 8         if arrangementnumber == 75  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  
  
  * #127 GEORGIA
  replace t = 3280000        if arrangementnumber == 127  & reviewsequence == "E" & mneumonic == "NGDP"
   
  * #136 HAITI
  replace t = 17             if arrangementnumber == 136  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  
  * #160 Russia: period-avg inflation from EBS entered
  replace tminus3 = 1353     if arrangementnumber == 160  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tminus2 = 896      if arrangementnumber == 160  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tminus1 = 302      if arrangementnumber == 160  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace t = 143            if arrangementnumber == 160  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tplus1 = 12.3      if arrangementnumber == 160  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  
  
  * 206 Congo, Rep of: data entry person fell into wrong line in report this looks like "current expenditures, interest"
  replace tminus3 = 35.0     if arrangementnumber == 206  & reviewsequence == "E" & mneumonic == "GCECY"
  replace tminus2 = 34.6     if arrangementnumber == 206  & reviewsequence == "E" & mneumonic == "GCECY"
  replace tminus1 = 31.4     if arrangementnumber == 206  & reviewsequence == "E" & mneumonic == "GCECY"
  replace t = 29.5           if arrangementnumber == 206  & reviewsequence == "E" & mneumonic == "GCECY"
  replace tplus1 = 25.3      if arrangementnumber == 206  & reviewsequence == "E" & mneumonic == "GCECY"
  replace tplus2 = 22.4      if arrangementnumber == 206  & reviewsequence == "E" & mneumonic == "GCECY"
  replace tplus3 = 20.4      if arrangementnumber == 206  & reviewsequence == "E" & mneumonic == "GCECY"


	* #212 KYRGYZ REPUBLIC: ENDA for period t-1 121.9 should be 12.91
	replace tminus1=12.91     if arrangementnumber == 212 & reviewsequence == "L" & mneumonic == "ENDA" // CONFIRMED FROM COUNTRY REPORT

  * #242 Bosnia: entry typo of t-3 data for RGDP_rate
  replace tminus3 = 32      if arrangementnumber == 242 & reviewsequence == "E" & mneumonic == "RGDP_rate"
  
  * #250 MAURITANIA: typo of tminus1 (also an error of zero as missing). Use period average
  replace tminus3 = 4.1     if arrangementnumber == 250  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tminus2 = 6.5     if arrangementnumber == 250  & reviewsequence == "E" & mneumonic == "PCPIE_rate"
  replace tminus1 = 4.7      if arrangementnumber == 250  & reviewsequence == "E" & mneumonic == "PCPIE_rate"


	* #274 UKRAINE:
  // fixed in MONA: replace t = 264995        if arrangementnumber == 274 & mneumonic == "NGDP" & reviewsequence == "L"  // typo [growth rates only in EBS[ebs ID has typo] growth > 0] (Theo)
	replace t = 12.9          if arrangementnumber == 274 & reviewsequence == "E" & mneumonic == "PCPIE_rate" // theo clear typo 129 inflation rate though 12.9 not confirmed by EBS EBS states 10.0 but at times EBS is slighly off

	* #295 Yemen: NGDP for period t 7329 should be 732.9
	replace t=732.9           if arrangementnumber == 295 & reviewsequence == "E" & mneumonic == "NGDP"


	* # 296 Ghana: see fix in the reviewsequence below

  * 402 Moldova
  replace tminus3 = 134     if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BXS_O"
  replace tminus2 = 119     if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BXS_O"
  replace tminus1 = 136     if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BXS_O"
  replace t = 158           if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BXS_O"
  replace tplus1 = 158      if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BXS_O"
  replace tplus2 = 189      if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BXS_O"
  replace tplus3 = 225      if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BXS_O"
  replace tplus4 = 264      if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BXS_O"

  
  	// Add typos related to L review. Added by Monica on 11.24.2020

	
	// Program #84, Review:L Mneumonic: D, 29470 vs 2947 
	replace tminus1 = 29470 if arrangementnumber == 84 & mneumonic == "DL" & reviewsequence == "L"
		
	replace t = 85 if arrangementnumber == 156 & mneumonic == "BK_SP" & reviewsequence == "L" // typo, see imf Report No. 98/13 p39
		
	// Add typos related to E review added by Reina 	
	*316 ALBANIA
  	replace tminus3= 729     if arrangementnumber == 316  & reviewsequence == "E" & mneumonic == "BXT"      // #316 ALBANIA
	replace tminus2= 167     if arrangementnumber == 316  & reviewsequence == "E" & mneumonic == "BXT"      // #316 ALBANIA
	replace tminus1= 205     if arrangementnumber == 316  & reviewsequence == "E" & mneumonic == "BXT"      // #316 ALBANIA
	replace t= 318           if arrangementnumber == 316  & reviewsequence == "E" & mneumonic == "BXT"      // #316 ALBANIA
	replace tplus1= 290      if arrangementnumber == 316  & reviewsequence == "E" & mneumonic == "BXT"      // #316 ALBANIA
	replace tplus2= 339      if arrangementnumber == 316  & reviewsequence == "E" & mneumonic == "BXT"      // #316 ALBANIA
	replace tplus3= 390      if arrangementnumber == 316  & reviewsequence == "E" & mneumonic == "BXT"      // #316 ALBANIA
	replace tplus4= 448      if arrangementnumber == 316  & reviewsequence == "E" & mneumonic == "BXT"      // #316 ALBANIA		

    // DATA ENTRY ISSUE 3: MISSING DATA
	
	replace tminus2= 717     if arrangementnumber == 5  & reviewsequence == "L" & mneumonic == "NGDP"      // #5 Czech
	replace tminus1= 803     if arrangementnumber == 5  & reviewsequence == "L" & mneumonic == "NGDP"      // #5 Czech

	
	replace t= 11.5           if arrangementnumber == 35  & reviewsequence == "E" & mneumonic == "GCECY"       // #35 CAMEROON

	replace t= -10            if arrangementnumber == 95  & reviewsequence == "E" & mneumonic == "RGDP_rate"   // #95 UKRAINE

	replace tminus2= 227      if arrangementnumber == 159  & reviewsequence == "E" & mneumonic == "BMS_O"      // #159 AZERBAIJAN
	replace tminus1= 351      if arrangementnumber == 159  & reviewsequence == "E" & mneumonic == "BMS_O"      // #159 AZERBAIJAN
	replace t= 373            if arrangementnumber == 159  & reviewsequence == "E" & mneumonic == "BMS_O"      // #159 AZERBAIJAN

	replace tminus2= 5546     if arrangementnumber == 195  & reviewsequence == "E" & mneumonic == "BMT"      // #195 PERU
	replace tminus1= 7687     if arrangementnumber == 195  & reviewsequence == "E" & mneumonic == "BMT"      // #195 PERU

	replace tminus2= 4570     if arrangementnumber == 195  & reviewsequence == "E" & mneumonic == "BXT"      // #195 PERU
	replace tminus1= 5576     if arrangementnumber == 195  & reviewsequence == "E" & mneumonic == "BXT"      // #195 PERU

	replace tminus3= 2.16     if arrangementnumber == 195  & reviewsequence == "E" & mneumonic == "ENDA"      // #195 PERU
	replace tminus2= 2.14     if arrangementnumber == 195  & reviewsequence == "E" & mneumonic == "ENDA"      // #195 PERU
	replace tminus1= 2.31     if arrangementnumber == 195  & reviewsequence == "E" & mneumonic == "ENDA"      // #195 PERU
	
	replace tminus3= 32.1     if arrangementnumber == 203  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #203 Senegal  (use period avg)
	replace tminus2= 8.1      if arrangementnumber == 203  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #203 Senegal  (use period avg)
	replace tminus1= 2.7      if arrangementnumber == 203  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #203 Senegal  (use period avg)
	replace t= 2.5            if arrangementnumber == 203  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #203 Senegal  (use period avg)
	replace tplus1= 2.5       if arrangementnumber == 203  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #203 Senegal  (use period avg)
	replace tplus2= 2.5       if arrangementnumber == 203  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #203 Senegal  (use period avg)
	
	replace tminus3= 8.5      if arrangementnumber == 277  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #277 Senegal  (use period avg)
	replace tminus2= 2.8      if arrangementnumber == 277  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #277 Senegal  (use period avg)
	replace tminus1= 1.8      if arrangementnumber == 277  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #277 Senegal  (use period avg)
	replace t= 2.4            if arrangementnumber == 277  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #277 Senegal  (use period avg)
	replace tplus1= 2         if arrangementnumber == 277  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #277 Senegal  (use period avg)
	replace tplus2= 2         if arrangementnumber == 277  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #277 Senegal  (use period avg)
	
	replace tminus3= 2.8     if arrangementnumber == 327  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #327 Senegal  (use period avg)
	replace tminus2= 1.8      if arrangementnumber == 327  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #327 Senegal  (use period avg)
	replace tminus1= 1.1      if arrangementnumber == 327  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #327 Senegal  (use period avg)
	replace t= 2            if arrangementnumber == 327  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #327 Senegal  (use period avg)
	replace tplus1= 2         if arrangementnumber == 327  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #327 Senegal  (use period avg)
	replace tplus2= 2         if arrangementnumber == 327  & reviewsequence == "E" & mneumonic == "PCPIE_rate"   // #327 Senegal  (use period avg)
	
	
	
	replace tminus1= 1.16     if arrangementnumber == 320  & reviewsequence == "E" & mneumonic == "ENDA"      // #320 ROMANIA
    replace t= 1.81           if arrangementnumber == 320  & reviewsequence == "E" & mneumonic == "ENDA"      // #320 ROMANIA
	replace tplus1= 1.84      if arrangementnumber == 320  & reviewsequence == "E" & mneumonic == "ENDA"      // #320 ROMANIA
	replace tplus2= 2.29      if arrangementnumber == 320  & reviewsequence == "E" & mneumonic == "ENDA"      // #320 ROMANIA

    replace tminus3= 18.7     if arrangementnumber == 401  & reviewsequence == "E" & mneumonic == "GCECY"      // #401 Brazil
	replace tminus2= 19.1     if arrangementnumber == 401  & reviewsequence == "E" & mneumonic == "GCECY"      // #401 Brazil
	replace tminus1= 19.0     if arrangementnumber == 401  & reviewsequence == "E" & mneumonic == "GCECY"      // #401 Brazil
	replace t= 20.20          if arrangementnumber == 401  & reviewsequence == "E" & mneumonic == "GCECY"      // #401 Brazil
	replace tplus1= 20.20     if arrangementnumber == 401  & reviewsequence == "E" & mneumonic == "GCECY"      // #401 Brazil

	replace tminus3= 186      if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BMS_O"      // #402 Moldova
	replace tminus2= 192      if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BMS_O"      // #402 Moldova
	replace tminus1= 159      if arrangementnumber == 402  & reviewsequence == "E" & mneumonic == "BMS_O"      // #402 Moldova
	
	replace tminus2= 125596   if arrangementnumber == 418  & reviewsequence == "E" & mneumonic == "NGDP"      // #418 Turkey
	replace tminus1= 184667   if arrangementnumber == 418  & reviewsequence == "E" & mneumonic == "NGDP"      // #418 Turkey
	replace t= 283241   if arrangementnumber == 418  & reviewsequence == "E" & mneumonic == "NGDP"      // #418 Turkey

	
	replace tminus3= 19.0     if arrangementnumber == 433  & reviewsequence == "E" & mneumonic == "GCECY"      // #433 MACEDONIA
    replace tminus2= 24.2     if arrangementnumber == 433  & reviewsequence == "E" & mneumonic == "GCECY"      // #433 MACEDONIA
	replace tminus1= 24.7     if arrangementnumber == 433  & reviewsequence == "E" & mneumonic == "GCECY"      // #433 MACEDONIA
	replace t= 20.2           if arrangementnumber == 433  & reviewsequence == "E" & mneumonic == "GCECY"      // #433 MACEDONIA
	replace tplus1= 219.6    if arrangementnumber == 433  & reviewsequence == "E" & mneumonic == "GCECY"      // #433 MACEDONIA
	
	
	
	//Reina added from here for Missing data in OLD MONA ENDA on March 4, 2021:
	
	replace tminus1= 128000     if arrangementnumber == 95  & reviewsequence == "E" & mneumonic == "ENDA"      // #95 UKRAINE: END OF PERIOD HERE
	replace t= 170000           if arrangementnumber == 95  & reviewsequence == "E" & mneumonic == "ENDA"      // #95 UKRAINE: END OF PERIOD HERE
	
	replace tminus1= 36.07     if arrangementnumber == 153  & reviewsequence == "E" & mneumonic == "ENDA"      // #153 KAZAKHSTAN
	replace t= 69.42           if arrangementnumber == 153  & reviewsequence == "E" & mneumonic == "ENDA"      // #153 KAZAKHSTAN
	
	/* can't generate growth rate
	replace tminus3= 1     if arrangementnumber == 242  & reviewsequence == "E" & mneumonic == "ENDA"      // #242 BOSNIA AND HERZEGOVINA
	replace tminus2= 1     if arrangementnumber == 242  & reviewsequence == "E" & mneumonic == "ENDA"      // #242 BOSNIA AND HERZEGOVINA
	replace tminus1= 1     if arrangementnumber == 242  & reviewsequence == "E" & mneumonic == "ENDA"      // #242 BOSNIA AND HERZEGOVINA
	*/
	replace t= 11493           if arrangementnumber == 261  & reviewsequence == "E" & mneumonic == "ENDA"      // #261 MOZAMBIQUE
	
	replace t= 2               if arrangementnumber == 273  & reviewsequence == "E" & mneumonic == "ENDA"      // #273 UKRAINE
	
	replace t= 63.98               if arrangementnumber == 377  & reviewsequence == "E" & mneumonic == "ENDA"      // #377 PAKISTAN
	
	replace t= 313.6               if arrangementnumber == 419  & reviewsequence == "E" & mneumonic == "ENDA"      // #419 CONGO, DEMOCRATIC REPUBLIC OF
	
	replace tminus1= 411     if arrangementnumber == 421  & reviewsequence == "E" & mneumonic == "ENDA"      // #421 RWANDA
	replace t= 415.5          if arrangementnumber == 421  & reviewsequence == "E" & mneumonic == "ENDA"      // #421 RWANDA
	
	//Reina added on March 9th, 2021: 3stdev outliers R1 of ENDA;
	
	replace t= 2.070007659           if arrangementnumber == 10  & reviewsequence == "E" & mneumonic == "ENDA"      // #10 ETHIOPIA

	replace t= 4           if arrangementnumber == 19  & reviewsequence == "E" & mneumonic == "ENDA"      // #19 LITHUANIA
	
	replace tminus1= 1.409     if arrangementnumber == 82  & reviewsequence == "E" & mneumonic == "ENDA"      // #82 MOLDOVA
	replace t= 3.101           if arrangementnumber == 82  & reviewsequence == "E" & mneumonic == "ENDA"      // #82 MOLDOVA
	
	replace t= 5454           if arrangementnumber == 114  & reviewsequence == "E" & mneumonic == "ENDA"      // #114 MOZAMBIQUE
	
	replace tminus1= 1.18     if arrangementnumber == 129  & reviewsequence == "E" & mneumonic == "ENDA"      // #129 PAPUA NEW GUINEA
	replace t= 1.28           if arrangementnumber == 129  & reviewsequence == "E" & mneumonic == "ENDA"      // #129 PAPUA NEW GUINEA
	


  // DATA ENTRY ISSUE 4: Temporal error

    
  	// #7 Estonia. Monica: updated my code. no WEO data available in t
	replace tplus4 = tplus3   if arrangementnumber == 7 & reviewsequence == "L"
	replace tplus3 = tplus2   if arrangementnumber == 7 & reviewsequence == "L"
	replace tplus2 = tplus1   if arrangementnumber == 7 & reviewsequence == "L"
	replace tplus1 = t        if arrangementnumber == 7 & reviewsequence == "L"
	replace t = tminus1       if arrangementnumber == 7 & reviewsequence == "L"
	replace tminus1 = tminus2 if arrangementnumber == 7 & reviewsequence == "L"
	replace tminus2 = tminus3 if arrangementnumber == 7 & reviewsequence == "L"
	replace tminus3 = .       if arrangementnumber == 7 & reviewsequence == "L"
	
	
  * #15 EL Salvador: move all L observations one period over
	replace tplus4 = tplus3   if arrangementnumber == 15 & reviewsequence == "L"
	replace tplus3 = tplus2   if arrangementnumber == 15 & reviewsequence == "L"
	replace tplus2 = tplus1   if arrangementnumber == 15 & reviewsequence == "L"
	replace tplus1 = t        if arrangementnumber == 15 & reviewsequence == "L"
	replace t = tminus1       if arrangementnumber == 15 & reviewsequence == "L"
	replace tminus1 = tminus2 if arrangementnumber == 15 & reviewsequence == "L"
	replace tminus2 = tminus3 if arrangementnumber == 15 & reviewsequence == "L"
	replace tminus3 = .       if arrangementnumber == 15 & reviewsequence == "L"

	* #132 Sierra Leone: move one cell to the right for "E" review
	replace tplus4 = tplus3   if arrangementnumber == 132 & reviewsequence == "E" & inlist(mneumonic, "NI_Y", "RGDP_rate")
	replace tplus3 = tplus2   if arrangementnumber == 132 & reviewsequence == "E" & inlist(mneumonic, "NI_Y", "RGDP_rate")
	replace tplus2 = tplus1   if arrangementnumber == 132 & reviewsequence == "E" & inlist(mneumonic, "NI_Y", "RGDP_rate")
	replace tplus1 = t        if arrangementnumber == 132 & reviewsequence == "E" & inlist(mneumonic, "NI_Y", "RGDP_rate")
	replace t = tminus1       if arrangementnumber == 132 & reviewsequence == "E" & inlist(mneumonic, "NI_Y", "RGDP_rate")
	replace tminus1 = tminus2 if arrangementnumber == 132 & reviewsequence == "E" & inlist(mneumonic, "NI_Y", "RGDP_rate")
	replace tminus2 = tminus3 if arrangementnumber == 132 & reviewsequence == "E" & inlist(mneumonic, "NI_Y", "RGDP_rate")
	replace tminus3 = .       if arrangementnumber == 132 & reviewsequence == "E" & inlist(mneumonic, "NI_Y", "RGDP_rate")

  * #256 INDONESIA: NI_Y, PCPIE_rate and RGDP_rate temporal errors. move one cell to the left for all reviews
  replace tminus3 = tminus2      if arrangementnumber == 256  &  inlist(mneumonic, "NI_Y", "PCPIE_rate", "RGDP_rate")
  replace tminus2 = tminus1      if arrangementnumber == 256  &  inlist(mneumonic, "NI_Y", "PCPIE_rate", "RGDP_rate")
  replace tminus1 = t            if arrangementnumber == 256  &  inlist(mneumonic, "NI_Y", "PCPIE_rate", "RGDP_rate")
  replace t = tplus1             if arrangementnumber == 256  &  inlist(mneumonic, "NI_Y", "PCPIE_rate", "RGDP_rate")

  * #275 Indonesia, temporal error, move one cell to the left for all reviews
  replace tminus3 = tminus2      if arrangementnumber == 275  &  inlist(mneumonic, "ENDA", "NGDP", "PCPIE_rate", "RGDP_rate")
  replace tminus2 = tminus1      if arrangementnumber == 275  &  inlist(mneumonic, "ENDA", "NGDP", "PCPIE_rate", "RGDP_rate")
  replace tminus1 = t            if arrangementnumber == 275  &  inlist(mneumonic, "ENDA", "NGDP", "PCPIE_rate", "RGDP_rate")
  replace t = tplus1             if arrangementnumber == 275  &  inlist(mneumonic, "ENDA", "NGDP", "PCPIE_rate", "RGDP_rate")

    // FIX LABEL OF "indicatorcurrency"
	replace indicatorcurrency = strtrim(indicatorcurrency)
	replace indicatorcurrency = "NCU (billions)" if indicatorcurrency == "UGSH"     // Uganda 1994 #62 has last review all in UGSH, First review in $
	replace indicatorcurrency = "NCU (billions)" if indicatorcurrency == "CFA b."   // burkina faso
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "\$US mn"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US\$m"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US\$mn"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US $ m"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US$ Mn"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US$ m"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US$ mn"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US$, m"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US$,mi"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "us$ MN"
	replace indicatorcurrency = "USD (millions)" if indicatorcurrency == "US$ (millions)"

	replace indicatorcurrency = "SDR (millions)" if indicatorcurrency == "SDR Mn"
	replace indicatorcurrency = "SDR (millions)" if indicatorcurrency == "SDR mn"
	replace indicatorcurrency = "SDR (millions)" if indicatorcurrency == "SDRs m"
	replace indicatorcurrency = "SDR (millions)" if indicatorcurrency == "milSDR"

	replace indicatorcurrency = "USD (billions)" if indicatorcurrency == "US $ b"
	replace indicatorcurrency = "USD (billions)" if indicatorcurrency == "US$ bi"
	replace indicatorcurrency = "USD (billions)" if indicatorcurrency == "US$ bn"
	replace indicatorcurrency = "USD (billions)" if indicatorcurrency == "US$ (billions"
	replace indicatorcurrency = "USD" if indicatorcurrency == "US$"
	replace indicatorcurrency = "USD" if indicatorcurrency == "U.S.$"
	replace indicatorcurrency = "USD" if indicatorcurrency == "US $,"
	replace indicatorcurrency = "USD" if indicatorcurrency == "Dollar"
	replace indicatorcurrency = "NCU/USD" if indicatorcurrency == "NCU/US$"
	replace indicatorcurrency = "SDR" if indicatorcurrency == "SDRs"
	replace indicatorcurrency = "SDR" if indicatorcurrency == "SDRs,"

	// Drop problematic programs

	* delete #108 Kazakhstan due to currency reform
	drop     if  arrangementnumber == 108

	* DROP KYRGYZ REPUBLIC#16: Undocumented differences in base years, exchange rates, incompatible units magnitudes for E and L comparison
	* boarddocno EBS /93/146, boarddocno EBS /94/127
    * Theo checked kyrgyz had a currency reform 1 soms = 200 rubles, E data is in rubles L data is in soms but unclear what is local currency
	drop if arrangementnumber == 16
	
	
// create dummy "tminus1_is_forecast"
split boarddocno, parse("//", "/")  gen(parse)
rename parse2 boarddocno_parse
replace  boarddocno_parse = parse3   if parse4!=""  |  parse5!=""
drop parse*
gen boarddocno_year="19"+boarddocno_parse if substr(boarddocno_parse, 1, 1)=="9"
replace boarddocno_year="20"+boarddocno_parse if substr(boarddocno_parse, 1, 1)=="0"
destring boarddocno_year, replace

*gen dummy_tminus1_is_forecast  = 1  if   boarddocno_year == programyear - 1


// create SDR dummy. (1= trade data are in SDR, need to * ENSA)
gen       dummy_SDR_tradedata =strpos(indicatorcurrency, "SDR")    if inlist(mneumonic,"BMT", "BMS_O", "BXT", "BXS_O")
gen       dummy_SDR           =strpos(indicatorcurrency, "SDR")    if inlist(mneumonic,"BMT", "BMS_O", "BXT", "BXS_O", "ENDA")
* check consistency
gen       error_unit = 1     if dummy_SDR_tradedata!=dummy_SDR  &  mneumonic=="EDNA"   & reviewsequence=="E"  // at least from the labels they're consistent
drop      dummy_SDR  error_unit	

* create data frame for NMG, NMS, NXG, NXS
sort      arrangementnumber mneumonic recode_reviewtype

expand 2  if (mneumonic == "BMT"), generate (dup_old)
replace   mneumonic = "NM"                                                       if  mneumonic == "BMT" & dup_old==1
replace   description="Imports of goods and services in USD. constructed"    if  mneumonic == "NM"
drop      dup_old

expand 2  if (mneumonic == "BXT"), generate (dup_old)
replace   mneumonic = "NX"                                                       if  mneumonic == "BXT" & dup_old==1
replace   description="Exports of goods and serivices in USD. constructed"   if  mneumonic == "NX"
drop      dup_old



////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
* remove all the data, and construct later

	      local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	          foreach    v in `vars' {
				  replace `v'=.     if  inlist(mneumonic,"NM", "NX")
	          }



* fix the "E" and "L" error after multiple reshape
tab       reviewtype reviewsequence
drop      first_review  last_review


sort      arrangementnumber mneumonic  recode_reviewtype
drop      approvalyear  fystartmonth fyendmonth initialendyear
order     arrangementnumber   arrangementtype programtype countryname countrycode initialenddate revisedenddate reviewtype recode_reviewtype ///
          reviewsequence boarddocno  approvaldate durationofannualarrangementfrom durationofannualarrangementto  ///
		  indicatorcurrency mneumonic programyear  tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4

		  
//forecastdate
gen       forecastdate = approvaldate	  
format    forecastdate %td
replace   forecastdate = durationofannualarrangementfrom   if durationofannualarrangementfrom!=.  

//revisedenddate
drop      revisedenddate // all NULL info
gen       revisedenddate = initialenddate
replace   revisedenddate = durationofannualarrangementto   if durationofannualarrangementto!=. 


gen       label = "oldMONA_" + reviewtype


save      ArchMecon_cleaned_forerrorcheck, replace
*erase     temp_formerge.dta




********************************************
// (iii) merge IMF and old MONA data


use       ArchMecon_cleaned_forerrorcheck, clear


keep      arrangementnumber countrycode programyear  mneumonic      /* use progream year to defint t obs, not startyear */
order     arrangementnumber countrycode programyear  mneumonic
tab       mneumonic
sort      arrangementnumber countrycode programyear  mneumonic
duplicates drop


merge m:1 countrycode mneumonic using IMFdata_mergeOLDMONA
drop      if _m==2 | _m==1
drop      _m
tab       mneumonic

sort      countrycode programyear mneumonic
drop      if   arrangementnumber==. //& !inlist(mneumonic,"dum_imf_BMGS","dum_imf_BXGS") 


reshape   long yvalue, i(arrangementnumber mneumonic countrycode) j(weo_yearid)

sort      arrangementnumber mneumonic weo_yearid
order     arrangementnumber mneumonic weo_yearid

* declear panel data
egen      group_id=group(arrangementnumber mneumonic)
xtset     group_id weo_yearid, yearly
sort      group_id weo_yearid

gen       diff_t = weo_yearid - programyear 


* now the _imf notation includes data from IMF WEO/BOP/IFS/GFS
sort      group_id weo_yearid
bysort    group_id:    gen tminus3 = l3.yvalue     if diff_t==0
bysort    group_id:    gen tminus2 = l2.yvalue     if diff_t==0
bysort    group_id:    gen tminus1 = l.yvalue      if diff_t==0
bysort    group_id:    gen t = yvalue              if diff_t==0
bysort    group_id:    gen tplus1 = f.yvalue       if diff_t==0
bysort    group_id:    gen tplus2 = f2.yvalue      if diff_t==0
bysort    group_id:    gen tplus3 = f3.yvalue      if diff_t==0
bysort    group_id:    gen tplus4 = f4.yvalue      if diff_t==0

keep      if diff_t==0     /*keep  if diff_t==0 | diff_t==. keep observations coming from MONA only */
keep      arrangementnumber mneumonic  countrycode t*

gen       label = "x_IMF"

append    using ArchMecon_cleaned_forerrorcheck
order     arrangementnumber countryname mneumonic description label reviewtype reviewsequence boarddocno programyear
sort      arrangementnumber mneumonic label reviewtype reviewsequence programyear

replace   label = "First"                     if reviewsequence == "E"
replace   label = "Last"                     if reviewsequence == "L"
replace   label = "Intermed"                  if reviewsequence == "BLANK"
replace   reviewsequence = "x_IMF"            if label == "x_IMF"
replace   reviewtype = "x_IMF"                if label == "x_IMF" 

* generate growth rates:
gen       tminus2_gr = tminus2/tminus3 - 1
gen       tminus1_gr = tminus1/tminus2 - 1
gen       t_gr       = t/tminus1 - 1
gen       tplus1_gr  = tplus1/t - 1
gen       tplus2_gr  = tplus2/tplus1 - 1
gen       tplus3_gr  = tplus3/tplus2 - 1
gen       tplus4_gr  = tplus4/tplus3 - 1


* fix growth for variables in growth rates or ratio (RGDP_rate, PCPIE_rate)
replace       tminus2_gr = tminus2/100     if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tminus1_gr = tminus1/100     if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       t_gr       = t/100           if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tplus1_gr  = tplus1/100      if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tplus2_gr  = tplus2/100      if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tplus3_gr  = tplus3/100      if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tplus4_gr  = tplus4/100      if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")

* fix rate variables
replace       tminus3 = tminus3/100     if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tminus2 = tminus2/100     if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tminus1 = tminus1/100     if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       t       = t/100           if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tplus1  = tplus1/100      if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tplus2  = tplus2/100      if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tplus3  = tplus3/100      if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")
replace       tplus4  = tplus4/100      if inlist(mneumonic, "RGDP_rate", "PCPIE_rate")

*bro mneumonic reviewsequence if arrangementnumber ==1 & inlist(mneumonic,"NM","NX") 
// mark observations with multiple zero entries in IMF
egen    count0 = anycount(tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4), value(0)
*egen    mark_five0  = rowtotal(t tplus1 tplus2 tplus3 tplus4)
	local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	foreach    v in `vars' {
				  replace `v'=.    if `v'== 0  & count0 >0    &  !inlist(mneumonic,"RGDP_rate", "PCPIE_rate")  &  reviewsequence == "x_IMF"
	}
drop    count0



replace   reviewtype = "x_IMF"            if label == "x_IMF"
sort      arrangementnumber reviewtype  mneumonic


// create dummy to indicate meaning of trade data (goods & service & goods only)
* based on data availability in t and E review only
gen       dummy_trade_goods_only = .


// calculate NM, imports of goods and services
by        arrangementnumber reviewtype:     egen import_good_t    = max( t * (mneumonic=="BMT"))
by        arrangementnumber reviewtype:     egen import_service_t = max( t * (mneumonic=="BMS_O"))
replace   dummy_trade_goods_only = 1        if   mneumonic=="NM"  &  import_good_t!=0   &  import_service_t==0	// service data missing
replace   dummy_trade_goods_only = 0        if   mneumonic=="NM"  &  import_good_t!=0   &  import_service_t!=0  // goods and services available

* make sure one value of dummy_trade_goods_only across all reviews and x_IMF
sort      arrangementnumber mneumonic recode_reviewtype
by        arrangementnumber mneumonic:      replace  dummy_trade_goods_only=dummy_trade_goods_only[_n-1]   if  mneumonic=="NM"  & reviewsequence!="E"
sort      arrangementnumber reviewtype  mneumonic
	local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	foreach    v in `vars' {
		by        arrangementnumber reviewtype:  egen ref_import_GS`v'   = sum(`v'*inlist(mneumonic, "BMT", "BMS_O"))
		by        arrangementnumber reviewtype:  egen ref_import_good`v' = sum(`v'*inlist(mneumonic, "BMT"))

		replace   `v' = ref_import_GS`v'    if  dummy_trade_goods_only == 0  & mneumonic == "NM"
		replace   `v' = ref_import_good`v'  if  dummy_trade_goods_only == 1  & mneumonic == "NM"
		replace   `v' = .                   if  `v' == 0  & mneumonic == "NM"
		drop       ref_*
}
drop      import_*


// calculate NX, exports of goods and services
by        arrangementnumber reviewtype:     egen export_good_t    = max( t * (mneumonic=="BXT"))
by        arrangementnumber reviewtype:     egen export_service_t = max( t * (mneumonic=="BXS_O"))
replace   dummy_trade_goods_only = 1        if   mneumonic == "NX"  &  export_good_t!=0   &  export_service_t==0	// service data missing
replace   dummy_trade_goods_only = 0        if   mneumonic == "NX"  &  export_good_t!=0   &  export_service_t!=0

* make sure one value of dummy_trade_goods_only across all reviews and x_IMF
sort      arrangementnumber mneumonic recode_reviewtype
by        arrangementnumber mneumonic:      replace  dummy_trade_goods_only=dummy_trade_goods_only[_n-1]   if  mneumonic=="NX"  & reviewsequence!="E"
sort      arrangementnumber reviewtype  mneumonic
	local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	foreach    v in `vars' {
		by        arrangementnumber reviewtype:  egen ref_export_GS`v'   = sum(`v'*inlist(mneumonic, "BXT", "BXS_O"))
		by        arrangementnumber reviewtype:  egen ref_export_good`v' = sum(`v'*inlist(mneumonic, "BXT"))

		replace   `v' = ref_export_GS`v'    if  dummy_trade_goods_only == 0  & mneumonic == "NX"
		replace   `v' = ref_export_good`v'  if  dummy_trade_goods_only == 1  & mneumonic == "NX"
		replace   `v' = .                   if  `v' == 0    & mneumonic == "NX"
		drop       ref_*
}
drop      export_*

// replace NM and NX with EBS data found

	replace tminus3= 290.1     if arrangementnumber == 248  & reviewsequence == "E" & mneumonic == "NM"      // #248 Cape Verde
	replace tminus2= 273.1     if arrangementnumber == 248  & reviewsequence == "E" & mneumonic == "NM"      // #248 Cape Verde
	replace tminus1= 272.4     if arrangementnumber == 248  & reviewsequence == "E" & mneumonic == "NM"      // #248 Cape Verde
	replace t= 305.5           if arrangementnumber == 248  & reviewsequence == "E" & mneumonic == "NM"      // #248 Cape Verde
	replace tplus1= 327.0      if arrangementnumber == 248  & reviewsequence == "E" & mneumonic == "NM"      // #248 Cape Verde
	replace tplus2= 355.7      if arrangementnumber == 248  & reviewsequence == "E" & mneumonic == "NM"      // #248 Cape Verde
    replace dummy_trade_goods_only = 0              if  arrangementnumber == 248   & mneumonic == "NM"
	
// Reina added on March 9th: replace NM and NX with EBS data found

	replace tminus1= 524     if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NM"      // #1 ALBANIA
	replace t= 550           if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NM"      // #1 ALBANIA
	replace tplus1= 533      if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NM"      // #1 ALBANIA
	
	*this one was added on June 18 by Reina
	replace tminus2= 73      if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace tminus1= 70     if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace t= 91           if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	
	*June 20 Ethiopia SDR->USD value. Program year 1992
	*list if arrangementnumber == 10  & reviewsequence == "E" & mneumonic == "NM"
	replace t= 1116.7*0.727271      if arrangementnumber == 10  & reviewsequence == "E" & mneumonic == "NM"      // #10 Ethiopia
	replace tminus1= 919.3*0.699093      if arrangementnumber == 10  & reviewsequence == "E" & mneumonic == "NM"      // #10 Ethiopia
	*list if arrangementnumber == 10  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 698.7*0.727271      if arrangementnumber == 10  & reviewsequence == "E" & mneumonic == "NX"      // #10 Ethiopia
	replace tminus1= 595.2*0.699093      if arrangementnumber == 10  & reviewsequence == "E" & mneumonic == "NX"      // #10 Ethiopia	
	
	*************CONVERT SDR TO USD VALUES******************
	*22 Mauritania SDR->USD value.  program year 1992
	//local x = 470*0.727271 431.5*0.699093
	*list if arrangementnumber == 22  & reviewsequence == "E" & mneumonic == "NM"
	replace t= 470*0.727271      if arrangementnumber == 22  & reviewsequence == "E" & mneumonic == "NM"      // #22 Mauritania
	replace tminus1= 431.5*0.699093      if arrangementnumber == 22  & reviewsequence == "E" & mneumonic == "NM"      // #22 Mauritania
	*list if arrangementnumber == 22  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 363.9*0.727271      if arrangementnumber == 22  & reviewsequence == "E" & mneumonic == "NX"      // #22 Mauritania
	replace tminus1= 357.2*0.699093      if arrangementnumber == 22  & reviewsequence == "E" & mneumonic == "NX"      // #22 Mauritania	
	
	*65 MALAWI SDR->USD value. program year 1994	
	replace t= 440.4*0.685003      if arrangementnumber == 65  & reviewsequence == "E" & mneumonic == "NM"      // #65 MALAWI
	replace tminus1= 408.6*0.728036      if arrangementnumber == 65  & reviewsequence == "E" & mneumonic == "NM"      // #65 MALAWI
	*list if arrangementnumber == 65  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 289.1*0.685003      if arrangementnumber == 65  & reviewsequence == "E" & mneumonic == "NX"      // #65 MALAWI
	replace tminus1= 273.8*0.728036      if arrangementnumber == 65  & reviewsequence == "E" & mneumonic == "NX"      // #65 MALAWI		
	
	*103 ETHIOPIA SDR->USD value. program year 1993 	
	replace t= 1140.1*0.728036      if arrangementnumber == 103  & reviewsequence == "E" & mneumonic == "NM"      // #103 ETHIOPIA
	replace tminus1= 982.7*0.727271      if arrangementnumber == 103  & reviewsequence == "E" & mneumonic == "NM"      // #103 ETHIOPIA
	*list if arrangementnumber == 103  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 711.9*0.728036      if arrangementnumber == 103  & reviewsequence == "E" & mneumonic == "NX"      // #103 ETHIOPIA
	replace tminus1= 659.8*0.727271      if arrangementnumber == 103  & reviewsequence == "E" & mneumonic == "NX"      // #103 ETHIOPIA		
	
	*113 ETHIOPIA SDR->USD value. program year 1994 	
	replace t= 1101.5*0.685003      if arrangementnumber == 113  & reviewsequence == "E" & mneumonic == "NM"      // #113 ETHIOPIA
	replace tminus1= 885.4*0.728036      if arrangementnumber == 113  & reviewsequence == "E" & mneumonic == "NM"      // #113 ETHIOPIA
	*list if arrangementnumber == 113  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 711.5*0.685003      if arrangementnumber == 113  & reviewsequence == "E" & mneumonic == "NX"      // #113 ETHIOPIA
	replace tminus1= 561.1*0.728036      if arrangementnumber == 113  & reviewsequence == "E" & mneumonic == "NX"      // #113 ETHIOPIA		
	
	*131 MALAWI SDR->USD value. program year 1995 	
	replace t= 389.7*0.672728      if arrangementnumber == 131  & reviewsequence == "E" & mneumonic == "NM"      // #131 MALAWI
	replace tminus1= 419.5*0.685003      if arrangementnumber == 131  & reviewsequence == "E" & mneumonic == "NM"      // #131 MALAWI
	*list if arrangementnumber == 131  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 291.8*0.672728      if arrangementnumber == 131  & reviewsequence == "E" & mneumonic == "NX"      // #131 MALAWI
	replace tminus1= 278.1*0.685003      if arrangementnumber == 131  & reviewsequence == "E" & mneumonic == "NX"      // #131 MALAWI	
	
	*167 MAURITANIA SDR->USD value. program year 1994	
	replace t= 387.2*0.685003       if arrangementnumber == 167  & reviewsequence == "E" & mneumonic == "NM"      // #167 MAURITANIA
	replace tminus1= 407.9*0.728036      if arrangementnumber == 167  & reviewsequence == "E" & mneumonic == "NM"      // #167 MAURITANIA
	*list if arrangementnumber == 167  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 333*0.685003      if arrangementnumber == 167  & reviewsequence == "E" & mneumonic == "NX"      // #167 MAURITANIA
	replace tminus1= 318.2*0.728036      if arrangementnumber == 167  & reviewsequence == "E" & mneumonic == "NX"      // #167 MAURITANIA	
	
	*168 MAURITANIA SDR->USD value. program year 1995	
	replace t= 367*0.672728      if arrangementnumber == 168  & reviewsequence == "E" & mneumonic == "NM"      // #168 MAURITANIA
	replace tminus1= 369.9*0.685003      if arrangementnumber == 168  & reviewsequence == "E" & mneumonic == "NM"      // #168 MAURITANIA
	*list if arrangementnumber == 168  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 337.8*0.672728      if arrangementnumber == 168  & reviewsequence == "E" & mneumonic == "NX"      // #168 MAURITANIA
	replace tminus1= 310.4*0.685003      if arrangementnumber == 168  & reviewsequence == "E" & mneumonic == "NX"      // #168 MAURITANIA		
	
	*169 MAURITANIA SDR->USD value. program year 1996	
	replace t= 378.2*0.695432      if arrangementnumber == 169  & reviewsequence == "E" & mneumonic == "NM"      // #169 MAURITANIA
	replace tminus1= 381.6*0.672728      if arrangementnumber == 169  & reviewsequence == "E" & mneumonic == "NM"      // #169 MAURITANIA
	*list if arrangementnumber == 169  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 367.7*0.695432      if arrangementnumber == 169  & reviewsequence == "E" & mneumonic == "NX"      // #169 MAURITANIA
	replace tminus1= 358.1*0.672728      if arrangementnumber == 169  & reviewsequence == "E" & mneumonic == "NX"      // #169 MAURITANIA	
	
	*207 ETHIOPIA SDR->USD value. program year 1997	
	replace t= 1160.4*0.741152      if arrangementnumber == 207  & reviewsequence == "E" & mneumonic == "NM"      // #207 ETHIOPIA
	replace tminus1= 1050.5*0.695432      if arrangementnumber == 207  & reviewsequence == "E" & mneumonic == "NM"      // #207 ETHIOPIA
	*list if arrangementnumber == 207  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 777.2*0.741152      if arrangementnumber == 207  & reviewsequence == "E" & mneumonic == "NX"      // #207 ETHIOPIA
	replace tminus1= 710.1*0.695432      if arrangementnumber == 207  & reviewsequence == "E" & mneumonic == "NX"      // #207 ETHIOPIA	
	
	*209 MADAGASCAR SDR->USD value. program year 1996	
	replace t= 688.121*0.695432      if arrangementnumber == 209  & reviewsequence == "E" & mneumonic == "NM"      // #209 MADAGASCAR
	replace tminus1= 656.83*0.672728      if arrangementnumber == 209  & reviewsequence == "E" & mneumonic == "NM"      // #209 MADAGASCAR
	*list if arrangementnumber == 209  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 577.9588*0.695432      if arrangementnumber == 209  & reviewsequence == "E" & mneumonic == "NX"      // #209 MADAGASCAR
	replace tminus1= 545.88*0.672728      if arrangementnumber == 209  & reviewsequence == "E" & mneumonic == "NX"      // #209 MADAGASCAR	
	
	*234 UGANDA SDR->USD value. program year 1998	
	replace t= 1799.7*0.710846      if arrangementnumber == 234  & reviewsequence == "E" & mneumonic == "NM"      // #234 UGANDA
	replace tminus1= 1654.4*0.741152      if arrangementnumber == 234  & reviewsequence == "E" & mneumonic == "NM"      // #234 UGANDA
	*list if arrangementnumber == 234  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 1340.6*0.710846      if arrangementnumber == 234  & reviewsequence == "E" & mneumonic == "NX"      // #234 UGANDA
	replace tminus1= 1305.1*0.741152      if arrangementnumber == 234  & reviewsequence == "E" & mneumonic == "NX"      // #234 UGANDA	
	
	*250 MAURITANIA SDR->USD value. program year 1997	
	replace t= 310*0.741152      if arrangementnumber == 250  & reviewsequence == "E" & mneumonic == "NM"      // #250 MAURITANIA
	replace tminus1= 324*0.695432      if arrangementnumber == 250  & reviewsequence == "E" & mneumonic == "NM"      // #250 MAURITANIA
	*list if arrangementnumber == 250  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 391*0.741152      if arrangementnumber == 250  & reviewsequence == "E" & mneumonic == "NX"      // #250 MAURITANIA
	replace tminus1= 383*0.695432      if arrangementnumber == 250  & reviewsequence == "E" & mneumonic == "NX"      // #250 MAURITANIA	
	
	*270 GAMBIA, THE SDR->USD value. program year 1998	
	replace t= 192.2*0.710846      if arrangementnumber == 270  & reviewsequence == "E" & mneumonic == "NM"      // #270 GAMBIA, THE
	replace tminus1= 180.7*0.741152      if arrangementnumber == 270  & reviewsequence == "E" & mneumonic == "NM"      // #270 GAMBIA, THE
	*list if arrangementnumber == 270  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 165.3*0.710846      if arrangementnumber == 270  & reviewsequence == "E" & mneumonic == "NX"      // #270 GAMBIA, THE
	replace tminus1= 151.8*0.741152      if arrangementnumber == 270  & reviewsequence == "E" & mneumonic == "NX"      // #270 GAMBIA, THE	

	*310 MADAGASCAR SDR->USD value. program year 1999	
	replace t= 863.2*0.728591      if arrangementnumber == 310  & reviewsequence == "E" & mneumonic == "NM"      // #310 MADAGASCAR
	replace tminus1= 813.5*0.710846      if arrangementnumber == 310  & reviewsequence == "E" & mneumonic == "NM"      // #310 MADAGASCAR
	*list if arrangementnumber == 310  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 716.8*0.728591      if arrangementnumber == 310  & reviewsequence == "E" & mneumonic == "NX"      // #310 MADAGASCAR
	replace tminus1= 661.1*0.710846      if arrangementnumber == 310  & reviewsequence == "E" & mneumonic == "NX"      // #310 MADAGASCAR	
	
	*343 GAMBIA, THE SDR->USD value. program year 1999	
	replace t= 222.1*0.728591      if arrangementnumber == 343  & reviewsequence == "E" & mneumonic == "NM"      // #343 GAMBIA, THE
	replace tminus1= 205.2*0.710846      if arrangementnumber == 343  & reviewsequence == "E" & mneumonic == "NM"      // #343 GAMBIA, THE
	*list if arrangementnumber == 343  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 195.2*0.728591      if arrangementnumber == 343  & reviewsequence == "E" & mneumonic == "NX"      // #343 GAMBIA, THE
	replace tminus1=  174.8*0.710846      if arrangementnumber == 343  & reviewsequence == "E" & mneumonic == "NX"      // #343 GAMBIA, THE	

	*359 MADAGASCAR, THE SDR->USD value. program year 2001	
	replace t= 1154*0.795716      if arrangementnumber == 359  & reviewsequence == "E" & mneumonic == "NM"      // #359 MADAGASCAR
	replace tminus1= 1047.5*0.767514      if arrangementnumber == 359  & reviewsequence == "E" & mneumonic == "NM"      // #359 MADAGASCAR
	*list if arrangementnumber == 359  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 901.36*0.795716      if arrangementnumber == 359  & reviewsequence == "E" & mneumonic == "NX"      // #359 MADAGASCAR
	replace tminus1=830.4*0.767514      if arrangementnumber == 359  & reviewsequence == "E" & mneumonic == "NX"      // #359 MADAGASCAR	

	*405 GAMBIA, THE SDR->USD value. program year 1999	
	replace t= 201.7*0.728591      if arrangementnumber == 405  & reviewsequence == "E" & mneumonic == "NM"      // #405 GAMBIA, THE
	replace tminus1= 205.2*0.710846      if arrangementnumber == 405  & reviewsequence == "E" & mneumonic == "NM"      // #405 GAMBIA, THE
	*list if arrangementnumber == 405  & reviewsequence == "E" & mneumonic == "NX"
	replace t= 175.6*0.728591      if arrangementnumber == 405  & reviewsequence == "E" & mneumonic == "NX"      // #405 GAMBIA, THE
	replace tminus1=  174.8*0.710846      if arrangementnumber == 405  & reviewsequence == "E" & mneumonic == "NX"      // #405 GAMBIA, THE	
	
	
	***********************************************************************************************************************************************

	replace tminus3= 78.7    if arrangementnumber == 17  & reviewsequence == "E" & mneumonic == "NX"      // #17 LAO PEOPLE'S DEM. REP.
	replace tminus2= 96.6     if arrangementnumber == 17  & reviewsequence == "E" & mneumonic == "NX"      // #17 LAO PEOPLE'S DEM. REP.
	replace tminus1= 132.6     if arrangementnumber == 17  & reviewsequence == "E" & mneumonic == "NX"      // #17 LAO PEOPLE'S DEM. REP.
	replace t= 146.7           if arrangementnumber == 17  & reviewsequence == "E" & mneumonic == "NX"      // #17 LAO PEOPLE'S DEM. REP.
	replace tplus1= 156.6      if arrangementnumber == 17  & reviewsequence == "E" & mneumonic == "NX"      // #17 LAO PEOPLE'S DEM. REP.
	replace tplus2= 164.4      if arrangementnumber == 17  & reviewsequence == "E" & mneumonic == "NX"      // #17 LAO PEOPLE'S DEM. REP.
	replace tplus3= 178.9      if arrangementnumber == 17  & reviewsequence == "E" & mneumonic == "NX"      // #17 LAO PEOPLE'S DEM. REP.
	replace tplus4= 196      if arrangementnumber == 17  & reviewsequence == "E" & mneumonic == "NX"      // #17 LAO PEOPLE'S DEM. REP.

	replace tminus2= 264.5     if arrangementnumber == 93  & reviewsequence == "E" & mneumonic == "NX"      // #93 CAMBODIA
	replace tminus1= 219.1     if arrangementnumber == 93  & reviewsequence == "E" & mneumonic == "NX"      // #93 CAMBODIA
	replace t= 212.9          if arrangementnumber == 93  & reviewsequence == "E" & mneumonic == "NX"      // #93 CAMBODIA
	replace tplus1= 199.8      if arrangementnumber == 93  & reviewsequence == "E" & mneumonic == "NX"      // #93 CAMBODIA
	replace tplus2= 193.2      if arrangementnumber == 93  & reviewsequence == "E" & mneumonic == "NX"      // #93 CAMBODIA

	replace tminus2= 285     if arrangementnumber == 170  & reviewsequence == "E" & mneumonic == "NX"      // #170 CAMBODIA
	replace tminus1= 517    if arrangementnumber == 170  & reviewsequence == "E" & mneumonic == "NX"      // #170 CAMBODIA
	replace t= 440           if arrangementnumber == 170  & reviewsequence == "E" & mneumonic == "NX"      // #170 CAMBODIA
	replace tplus1= 423      if arrangementnumber == 170  & reviewsequence == "E" & mneumonic == "NX"      // #170 CAMBODIA
	replace tplus2= 467      if arrangementnumber == 170  & reviewsequence == "E" & mneumonic == "NX"      // #170 CAMBODIA
	replace tplus3= 442      if arrangementnumber == 170  & reviewsequence == "E" & mneumonic == "NX"      // #170 CAMBODIA

	replace tminus2= 1183     if arrangementnumber == 307  & reviewsequence == "E" & mneumonic == "NM"      // #307 MOZAMBIQUE
	replace tminus1= 1377.1     if arrangementnumber == 307  & reviewsequence == "E" & mneumonic == "NM"      // #307 MOZAMBIQUE
	replace t= 2056.7           if arrangementnumber == 307  & reviewsequence == "E" & mneumonic == "NM"      // #307 MOZAMBIQUE
	replace tplus1= 1763.5      if arrangementnumber == 307  & reviewsequence == "E" & mneumonic == "NM"      // #307 MOZAMBIQUE
	
	*"goods only data" added to 1 ALBANIA on June 19 checked with EBS
	replace tminus3=123      if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace tminus2=73      if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace tminus1=70      if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace t=91        if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace tplus1=114    if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace tplus2=136       if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace tplus3=154       if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA
	replace tplus4=172       if arrangementnumber == 1  & reviewsequence == "E" & mneumonic == "NX"      // #1 ALBANIA	
	
	
//  encode reviewsequence (for consistent sort of new and old MONA)
bysort    arrangementnumber mneumonic (reviewtype):     gen  n_review = sum(reviewtype != reviewtype[_n-1])
sort      arrangementnumber mneumonic n_review


duplicates drop
*preserve
save      oldMONA_errorcheck, replace
// NM/NX in this file are all converted to USD 
* => need to convert to national currency later for merging with the new MONA (which report trade data in national currency)
keep if inlist(mneumonic, "NM","NX", "ENDA")
keep if label == "x_IMF"
keep arrangementnumber mneumonic countryname label tminus2_gr-tplus4_gr dummy_trade_goods_only
save oldMONA_reina_forappend1,replace

use oldMONA_reina_forappend1, clear
keep if inlist(mneumonic ,"NM")
keep arrangementnumber mneumonic label t_gr dummy_trade_goods_only
rename t_gr actual_NM
rename dummy_trade_goods_only M_dummy_trade_goods_only
save oldMONA_reina_forappend_NM,replace

use oldMONA_reina_forappend1, clear
keep if inlist(mneumonic ,"NX")
keep arrangementnumber mneumonic label t_gr dummy_trade_goods_only
rename t_gr actual_NX
rename dummy_trade_goods_only X_dummy_trade_goods_only
save oldMONA_reina_forappend_NX, replace

use oldMONA_reina_forappend_NM, clear
merge 1:1 arrangementnumber using oldMONA_reina_forappend_NX
drop _m
save reina_NM_NX_forappend, replace

use oldMONA_errorcheck, clear
keep if inlist(mneumonic, "BMT","BXT")
keep if label == "x_IMF"
keep arrangementnumber mneumonic countryname label tminus2_gr-tplus4_gr dummy_trade_goods_only
keep if mneumonic=="BMT"&inlist(arrangementnumber, 11, 82, 89, 98, 134, 146, 154, 163, 165, 187, 221, 229, 239, 246, 250, 252, 256, 275, 276, 282, 283, 290, 295, 313, 401, 421, 426, 433)  ///
		|mneumonic=="BXT"&inlist(arrangementnumber, 139, 153, 239, 256, 275, 283, 290, 295, 313, 401, 419, 421, 426, 433)
save oldMONA_reina_forappend_2,replace


keep if inlist(mneumonic ,"BMT")
keep arrangementnumber mneumonic label t_gr
rename t_gr actual_BMT
save oldMONA_reina_forappend_BMT,replace

use oldMONA_reina_forappend_2, clear
keep if inlist(mneumonic ,"BXT")
keep arrangementnumber mneumonic label t_gr
rename t_gr actual_BXT
save oldMONA_reina_forappend_BXT,replace

use reina_NM_NX_forappend, clear

merge 1:1 arrangementnumber using oldMONA_reina_forappend_BMT
drop _m
merge 1:1 arrangementnumber using oldMONA_reina_forappend_BXT
drop _m
*replace goods only data here:
replace actual_NM = actual_BMT if M_dummy_trade_goods_only ==1
replace actual_NX = actual_BXT if X_dummy_trade_goods_only ==1
drop actual_BMT actual_BXT

save reina_NM_NX_forappend_final, replace




********************************************
// (iv) get ready of old MONA for append new MONA

use     oldMONA_errorcheck, clear

// keep program info for merging later
keep      if   reviewsequence == "E"
keep      arrangementnumber mneumonic countrycode dummy_SDR_tradedata  boarddocno_year programyear  ///
          approvaldate initialenddate revisedenddate forecastdate arrangementtype

expand 2  if (mneumonic == "NI_Y"), generate (dup_old)
replace   mneumonic = "NI"                                                       if  mneumonic == "NI_Y" & dup_old==1
drop      dup_old

expand 2  if (mneumonic == "GCECY"), generate (dup_old)
replace   mneumonic = "NCG"                                                       if  mneumonic == "GCECY" & dup_old==1
drop      dup_old

expand 2  if (mneumonic == "GCECY"), generate (dup_old)
replace   mneumonic = "NCP"                                                       if  mneumonic == "GCECY" & dup_old==1
drop      dup_old

sort      arrangementnumber mneumonic
duplicates drop
save      oldMONA_info, replace


use       oldMONA_errorcheck, clear //this has IMF data already merged

// create t_end and t_imf variables
drop      if reviewsequence=="BLANK"
drop      t*_gr

keep      arrangementnumber mneumonic reviewsequence t*
rename    t  tplus0
duplicates drop //to reshape data Reina

reshape   long t, i(arrangementnumber mneumonic reviewsequence) j(t_id, string)


* now variable y refers to variable values in the long table
rename     t  y_

reshape    wide y_, i(arrangementnumber reviewsequence t_id) j(mneumonic, string)



// create new variables
gen       y_NI = y_NI_Y * y_NGDP /100
gen       y_NCG = y_GCECY* y_NGDP /100
gen       y_NCP = y_NGDP - y_NI - y_NX + y_NM
*bro if t_id == "plus0"& reviewsequence =="E" 

replace   y_NCP =.   if   y_NCP<0

reshape   long y_, i(arrangementnumber reviewsequence t_id) j(mneumonic, string)

rename    y_  t
reshape   wide t, i(arrangementnumber mneumonic reviewsequence) j(t_id, string)
rename    tplus0  t

// reshape twice to create rows for the missing variables in each program

sort      arrangementnumber mneumonic reviewsequence
replace   reviewsequence = "_imf"            if reviewsequence == "x_IMF"
replace   reviewsequence = "_first"          if reviewsequence == "E"
replace   reviewsequence = "_end"            if reviewsequence == "L"
keep      t*  arrangementnumber mneumonic reviewsequence
reshape   wide tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4, i(arrangementnumber mneumonic) j(reviewsequence, string)

rename 	  tminus3_first  tminus3
rename    tminus2_first  tminus2
rename    tminus1_first  tminus1
rename    t_first        t
rename 	  tplus1_first   tplus1
rename 	  tplus2_first   tplus2
rename 	  tplus3_first   tplus3
rename 	  tplus4_first   tplus4


sort      arrangementnumber mneumonic
merge     1:1  arrangementnumber mneumonic using oldMONA_info

drop      _m


drop      if inlist(mneumonic,"NI_Y", "GCECY")    // keep them for error checking, but not use for regression

// drop trade data no longer needed (only for compileing NM and NX)
drop      if inlist(mneumonic,"BMT", "BMS_O", "BXT", "BXS_O")
drop      if inlist(mneumonic,"NMG", "NMS", "NXG", "NXS")

	
save      oldMONA_forappend, replace

*erase     IMFdata_mergeOLDMONA.dta
*erase     ArchMecon_cleaned_forerrorcheck.dta
erase     oldMONA_info.dta







********************************************************************************
*   3. Compile NEW MONA data (including mapping final offical data from WEO)
*      (i) prepare IMF data for merging NEW MONA
*      (ii) clean NEW MONA data (keep all reviews)
*      (iii) merge IMF and NEW MONA data
********************************************************************************


/*
// setup root directory
cd "/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina"
clear
set more off

* directory of MONA mirror files 
local MONA_mirror="/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/MONA_mirror_Nov19"
* directory of other input files 
local inputfiles="/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/input files_non-MONA"
*/



*************************************************
// (i) prepare IMF data for merging NEW MONA


// prepare IMF data (WEO/BOP/IFS/GFS) to merge 29 variables from MONA paper1

use WEO_export_Oct2020, clear

* Fixed bug of code for Serbia, Kosovo
replace   iso2="RS"       if iso3 == "SRB"     /*Serbia*/
replace   iso2="XK"       if iso3 == "UVK"     /*Kosovo*/

// ERROR FIX of IMF data
* fix the unit issue of Senegal's NGDP
replace   yvalue = yvalue*1000    if iso3=="SEN" & mneumonic=="NGDP"

* append BOP and IFS data (Bil of USD)
*cd "/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/input files_non-MONA"
append    using USD2_BOPIFS_export, force
append using NEW_WB_USD2_export.dta, force //WB data 


kountry   iso2, from(iso2c) to(imfn)
rename    _IMFN_ countrycode    /* (PRI, SSD, TUV, UVK) can't be found */

kountry   iso3, from(iso3c) to(imfn)
drop _IMFN_

kountry   iso2c, from(iso2c) to(imfn)


rename _IMFN_ countrycode2
replace countrycode = countrycode2 if countrycode ==.
drop countrycode2
replace iso2 = iso2c if iso2 ==""
replace weo_yearid = year if weo_yearid ==.


replace   countrycode=942 if iso2 == "RS"     /* Servia */
replace   countrycode=967 if iso2 == "XK"     /* Kosovo */
drop      if countrycode==.  | countrycode==728    // dupliate data of Namibia. not in MONA

*set up mneumonic name:

replace mneumonic = "BCA"  if INDICATOR =="BCA_BP6_USD"
replace mneumonic = "BFD"  if INDICATOR =="BFD_BP6_USD"
replace mneumonic = "BFO"  if INDICATOR =="BFO_BP6_USD"
replace mneumonic = "BFP"  if INDICATOR =="BFP_BP6_USD"
replace mneumonic = "BFRA"  if INDICATOR =="BFRA_BP6_USD"
replace mneumonic = "BF"  if INDICATOR =="BF_BP6_USD"
replace mneumonic = "BI"  if INDICATOR =="BIP_BP6_USD"
replace mneumonic = "BTR"  if INDICATOR =="BIS_BP6_USD"
replace mneumonic = "BMGS"  if INDICATOR =="BMGS_BP6_USD"
replace mneumonic = "BMG"  if INDICATOR =="BMG_BP6_USD"
replace mneumonic = "BMS"  if INDICATOR =="BMS_BP6_USD"
replace mneumonic = "BXGS"  if INDICATOR =="BXGS_BP6_USD"
replace mneumonic = "BXG"  if INDICATOR =="BXG_BP6_USD"
replace mneumonic = "BXS"  if INDICATOR =="BXS_BP6_USD"
replace mneumonic = "ENDA"  if INDICATOR =="ENDA_XDC_USD_RATE"
replace mneumonic = "ENDE"  if INDICATOR =="ENDE_XDC_USD_RATE"
replace mneumonic = "ENSA"  if INDICATOR =="ENSA_XDC_XDR_RATE"
replace mneumonic = "NCG"  if INDICATOR =="NCGG_XDC"
replace mneumonic = "NCP"  if INDICATOR =="NCP_XDC"
replace mneumonic = "NFIP"  if INDICATOR =="NFIAXD_XDC"
replace mneumonic = "NFI"  if INDICATOR =="NFI_XDC"
replace mneumonic = "NI"  if INDICATOR =="NI_XDC"
replace mneumonic = "NMG"  if INDICATOR =="NMG_XDC"
replace mneumonic = "NMS"  if INDICATOR =="NMS_XDC"
replace mneumonic = "NM"  if INDICATOR =="NM_XDC"
replace mneumonic = "NXG"  if INDICATOR =="NXG_XDC"
replace mneumonic = "NXS"  if INDICATOR =="NXS_XDC"
replace mneumonic = "NX"  if INDICATOR =="NX_XDC"
replace mneumonic = "NM1"  if INDICATOR =="TMG_FOB_USD"
replace mneumonic = "NX1"  if INDICATOR =="TXG_FOB_USD"
*NFIAXD: National Accounts, Expenditure, Gross Domestic Product, Gross Capital Formation, Private Sector (Corporations, Households, and Non-profit Institutions Serving Households), Acquisitions less Disposals of Valuables, Nominal, Domestic Currency
*NFI:National Accounts, Expenditure, Gross Domestic Product, Gross Capital Formation, Gross Fixed Capital Formation, Nominal, Domestic Currency


keep      countrycode mneumonic weo_yearid yvalue
sort      countrycode mneumonic weo_yearid


// for MONA programs labeled as "FY", map with NGDP_FY instead
drop if   mneumonic == "NGDP"  &  inlist(countrycode, 263,316,343,469,512,513,536,558,564,622,638,644,664,666,668,724,738,746)
replace   mneumonic = "NGDP"  if mneumonic == "NGDP_FY" &  inlist(countrycode, 263,316,343,469,512,513,536,558,564,622,638,644,664,666,668,724,738,746)
drop if   mneumonic == "NGDP_FY"

keep      countrycode mneumonic weo_yearid yvalue
sort      countrycode mneumonic weo_yearid

duplicates drop
reshape   wide yvalue, i(countrycode weo_yearid) j(mneumonic, string)

*reina added: new variable ********************************************
*keep countrycode weo_yearid yvalueBMG yvalueBMS yvalueBXG yvalueBXS yvalueNM yvalueNM1 yvalueNX yvalueNX1 yvalueENDA  

*collapse (mean) yvalueBCA-yvaluePCPIEPCH, by (weo_yearid countrycode)

gen       yvalueNM_usd = yvalueBMGS
gen       yvalueNX_usd = yvalueBXGS
*4059 missing,
gen dum_imf_BMGS = 1 if yvalueNM_usd !=.
gen dum_imf_BXGS = 1 if yvalueNX_usd !=.

replace dum_imf_BMGS = 0 if yvalueNM_usd ==.
replace dum_imf_BXGS = 0 if yvalueNX_usd ==.

*fix the unit to be consistent
replace yvalueWB_import = yvalueWB_import/10^9
replace yvalueWB_export = yvalueWB_export/10^9
*dummy generated 2,849 real change, and 2,123 real changes made respectively
replace dum_imf_BMGS = 2 if yvalueNM_usd ==. & yvalueWB_import !=.

replace dum_imf_BXGS = 2 if yvalueNX_usd ==. & yvalueWB_export !=.

replace  yvalueNM_usd = yvalueWB_import    if  yvalueNM_usd ==.
replace  yvalueNX_usd = yvalueWB_export    if  yvalueNX_usd ==.
*dummy generated
replace dum_imf_BMGS = 3 if yvalueNM_usd ==. & yvalueNM !=. & yvalueENDA !=.

replace dum_imf_BXGS = 3 if yvalueNX_usd ==. & yvalueNX !=. & yvalueENDA !=.



replace   yvalueNM_usd = yvalueNM / yvalueENDA    if  yvalueNM_usd ==.
replace   yvalueNX_usd = yvalueNX / yvalueENDA    if  yvalueNX_usd ==.

drop yvalueNM yvalueNX
rename yvalueNM_usd  yvalueNM
rename yvalueNX_usd  yvalueNX

*drop dum_imf_BMGS dum_imf_BXGS
rename dum_imf_BMGS yvaluedum_imf_BMGS
rename dum_imf_BXGS yvaluedum_imf_BXGS

*then NM NX here are going to be USD based data
***********************************************************************
reshape   long yvalue, i(countrycode weo_yearid) j(mneumonic, string)
sort      countrycode mneumonic weo_yearid

* rename variables for consistency with new MONA
replace   mneumonic = "PCPI_index"   if  mneumonic == "PCPI"        /* it's the CPI INFLATION, period average */
replace   mneumonic = "PCPIE_rate"   if  mneumonic == "PCPIEPCH"    /* it's the CPI INFLATION for old MONA program (1-433) */
replace   mneumonic = "PCPIE_index"  if  mneumonic == "PCPIE"       /* it's the CPI INFLATION for old MONA program (1-433) */
replace   mneumonic = "RGDP_rate"  	 if  mneumonic == "NGDP_RPCH"   /* it's the real GDP GROWTH for old MONA program (1-433) */
replace   mneumonic = "RGDP_level"   if  mneumonic == "NGDP_R"     /* it's the real GDP level for the new MONA program  */


* national account variables only
keep      if    inlist(mneumonic, "NGDP", "NCP", "NCG", "NM", "NX", "NI", "RGDP_level", "PCPIE_index") ///
                |inlist(mneumonic, "ENDA", "NFI", "dum_imf_BXGS", "dum_imf_BMGS", "BMG", "BMS", "BXG", "BXS") 
*here NM NX are converted to USD already 
*Convert trade data to USD:
reshape   wide yvalue, i(countrycode mneumonic) j(weo_yearid)

save      IMFdata_mergeNEWMONA.dta, replace


****************************************************
// (ii) clean NEW MONA data (keep all reviews)


set more off

// No boarddocno in the Mecon file. Need to generate from QPC file
use       "${MONA_mirror}/Mecon", clear 

replace    reviewtype = strtrim(reviewtype)
merge m:1  arrangementnumber reviewtype  using  newMONA_boarddocno

drop       if _m==2
drop       _m
drop       if programyear==2020 


* fix programyear issue
replace    programyear = 2018     if arrangementnumber == 764


* rename variables for consistency with old MONA & avoid confusion
replace    mneumonic = "PCPI_index"   if  mneumonic == "PCPI"        /* it's the CPI INFLATION, period average */
replace    mneumonic = "PCPIE_index"  if  mneumonic == "PCPIE"       /* it's the CPI INFLATION for old MONA program (1-433) */
replace    mneumonic = "RGDP_level"   if  mneumonic == "NGDP_R"     /* it's the real GDP level for the new MONA program  */

* national account variables only
keep      if    inlist(mneumonic, "NGDP", "NCP", "NCG", "NM", "NX", "NI", "RGDP_level", "PCPIE_index")  ///Reina added "BMG", "BXG", "BMS", "BXS"
             |  inlist(mneumonic, "NFI", "ENDA", "BMG", "BXG", "BMS", "BXS", "BMGS", "BXGS") ///
			 		 
			 

// remove white spaces that contaminate mneumonic names from bad xls importing
replace    mneumonic = strtrim(mneumonic)
replace    boarddocno = strtrim(boarddocno)         /* boarddocno is in qpc file, for new MONA*/
replace    countryname = strtrim(countryname)
replace    arrangementtype = strtrim(arrangementtype)
replace    reviewsequence = strtrim(reviewsequence)
replace    description = strtrim(description)
destring   countrycode, replace

gen        double  boarddocno_year = yofd(boardactiondate)
gen        double  boarddocno_month = mofd(boardactiondate)

* fix errors of boarddocno_year

* Renaming
rename     t3 tminus3
rename     t2 tminus2
rename     t1 tminus1
rename     z tplus1
rename     aa tplus2
rename     ab tplus3
rename     t4 tplus4

* zero entries are all missing data in new MONA
egen    count0 = anycount(tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4), value(0)

	local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	foreach    v in `vars' {
	              *replace `v'=.    if `v'== 0  & count0 >0    &  !inlist(mneumonic,"RGDP_rate", "PCPIE_rate")
				  replace `v'=.    if `v'== 0  & count0 >0   // &  mneumonic != "ENDA"
	}
drop    count0

			 

// Identify first and last review
tab 	   reviewtype
tab 	   reviewtype reviewsequence

* fix first review ID
replace    reviewsequence="E"    if  reviewtype=="R0"       &   t!=.
replace    reviewsequence="E"    if  reviewsequence=="EL"
by		   arrangementnumber mneumonic (boardactiondate), sort: gen byte first_review = (_n == 1)  if t!=.  /* no problem with definition of intial review "E" */
replace    reviewsequence="E"   if  first_review==1     &   approvalyear<=programyear  &   (reviewsequence=="BLANK" | reviewsequence=="EL")


* fix last review ID
by         arrangementnumber mneumonic (boardactiondate), sort: gen byte last_review = (_n == _N)   if t!=.
replace    reviewsequence="L"   if  last_review==1   & reviewsequence=="BLANK"

drop       first_review  last_review




// CLEAN UP DATA

	* check if any variable looks odd
	*bys        mneumonic: asdoc tabstat t,     replace stat(N mean sd min p5 p25 p50 p75 p95 max)


	// convert date variables  (no issue with NEW MONA)
	rename    intialenddate initialenddate


	// DATA ENTRY ISSUE 1: negative numbers of imports, exports, and NCP:
	local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	foreach    v in `vars' {
				  replace `v'=abs(`v') if inlist(mneumonic,"NM", "NX", "NCP", "BMG", "BXG", "BMS", "BXS", "BMGS", "BXGS")
	}


	// DATA ENTRY ISSUE 2: TYPOS

	* #506 BOSNIA AND HERZEGOVINA: suspicious E review data of NGDP. use EBS instead. Below is level data
	replace    tminus3 = 8.604      if arrangementnumber == 506   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tminus2 = 9.4334     if arrangementnumber == 506   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tminus1 = 9.9404     if arrangementnumber == 506   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    t = 10.4024          if arrangementnumber == 506   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus1 = 11.0337     if arrangementnumber == 506   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus2 = 11.848      if arrangementnumber == 506   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus3 = 12.837      if arrangementnumber == 506   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus4 = 13.926      if arrangementnumber == 506   & mneumonic == "NGDP"        &  reviewsequence == "E"

	
    * #510 Argentina: growth rates and inflation from EBS entered below
	replace    tminus3 = 0.2      if arrangementnumber == 510   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tminus2 = -5.5     if arrangementnumber == 510   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tminus1 = 26.1     if arrangementnumber == 510   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    t = 45.8           if arrangementnumber == 510   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus1 = .         if arrangementnumber == 510   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus2 = .         if arrangementnumber == 510   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus3 = .         if arrangementnumber == 510   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus4 = .         if arrangementnumber == 510   & mneumonic == "NGDP"        &  reviewsequence == "E"

	replace    tminus3 = -0.8     if arrangementnumber == 510   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tminus2 = -4.4     if arrangementnumber == 510   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tminus1 = -11      if arrangementnumber == 510   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    t = 2              if arrangementnumber == 510   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tplus1 = .         if arrangementnumber == 510   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tplus2 = .         if arrangementnumber == 510   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tplus3 = .         if arrangementnumber == 510   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tplus4 = .         if arrangementnumber == 510   & mneumonic == "RGDP_level"        &  reviewsequence == "E"

	replace    tminus3 = -0.7     if arrangementnumber == 510   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = -1.5     if arrangementnumber == 510   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 41       if arrangementnumber == 510   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 35             if arrangementnumber == 510   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = .         if arrangementnumber == 510   & mneumonic == "PCPIE_index"        &  reviewsequence == "E"
	replace    tplus2 = .         if arrangementnumber == 510   & mneumonic == "PCPIE_index"        &  reviewsequence == "E"
	replace    tplus3 = .         if arrangementnumber == 510   & mneumonic == "PCPIE_index"        &  reviewsequence == "E"
	replace    tplus4 = .         if arrangementnumber == 510   & mneumonic == "PCPIE_index"        &  reviewsequence == "E"
	
	
	* #521 Ghana: inflation from EBS entered below
	replace    tminus3 = 40.5     if arrangementnumber == 521   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 21.3     if arrangementnumber == 521   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 15.2     if arrangementnumber == 521   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 9              if arrangementnumber == 521   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 7         if arrangementnumber == 521   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 5         if arrangementnumber == 521   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = 5         if arrangementnumber == 521   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus4 = 5         if arrangementnumber == 521   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	
	* #535 Uruguay: inflation and RGDP growth rate entered below
	replace    tminus3 = 4.2      if arrangementnumber == 535   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 5.1      if arrangementnumber == 535   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 6.1      if arrangementnumber == 535   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 10.1           if arrangementnumber == 535   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 8.1       if arrangementnumber == 535   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	
	replace    tminus3 = -2.8     if arrangementnumber == 535   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tminus2 = -1.3     if arrangementnumber == 535   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tminus1 = -1       if arrangementnumber == 535   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    t = -1.7           if arrangementnumber == 535   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	replace    tplus1 = 3         if arrangementnumber == 535   & mneumonic == "RGDP_level"        &  reviewsequence == "E"
	
	
	* #527 NICARAGUA and #628 NIGER has wrong program years for some obs
	replace    programyear=2002     if  arrangementnumber==527
	replace    programyear=2012     if  arrangementnumber==681

	
	
	
	* #539 Dominican Rep: inflation and growth rates from EBS entered below
	replace    tminus3 = 15       if arrangementnumber == 539   & mneumonic == "NGDP" &  reviewsequence == "E"
	replace    tminus2 = 11.8     if arrangementnumber == 539   & mneumonic == "NGDP" &  reviewsequence == "E"
	replace    tminus1 = 10.1     if arrangementnumber == 539   & mneumonic == "NGDP" &  reviewsequence == "E"
	replace    t = 25             if arrangementnumber == 539   & mneumonic == "NGDP" &  reviewsequence == "E"
	replace    tplus1 = 20.8      if arrangementnumber == 539   & mneumonic == "NGDP" &  reviewsequence == "E"
	replace    tplus2 = 9.5       if arrangementnumber == 539   & mneumonic == "NGDP" &  reviewsequence == "E"
	
	replace    tminus3 = 7.3      if arrangementnumber == 539   & mneumonic == "RGDP_level" &  reviewsequence == "E"
	replace    tminus2 = 2.9      if arrangementnumber == 539   & mneumonic == "RGDP_level" &  reviewsequence == "E"
	replace    tminus1 = 4.1      if arrangementnumber == 539   & mneumonic == "RGDP_level" &  reviewsequence == "E"
	replace    t = -3             if arrangementnumber == 539   & mneumonic == "RGDP_level" &  reviewsequence == "E"
	replace    tplus1 = 0.5       if arrangementnumber == 539   & mneumonic == "RGDP_level" &  reviewsequence == "E"
	replace    tplus2 = 5         if arrangementnumber == 539   & mneumonic == "RGDP_level" &  reviewsequence == "E"

	replace    tminus3 = 9        if arrangementnumber == 539   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 4.4      if arrangementnumber == 539   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 10.5     if arrangementnumber == 539   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 35             if arrangementnumber == 539   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 9         if arrangementnumber == 539   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 5         if arrangementnumber == 539   & mneumonic == "PCPIE_index" &  reviewsequence == "E"

		
	
	
	
	* #545 Peru:
	expand 2   if (arrangementnumber == 545   & mneumonic == "PCPIE_index" ), generate (dup_old)
	replace    reviewsequence = "E"                         if  	mneumonic == "PCPIE_index" &  dup_old==1
	replace    boarddocno = "EBS/04/67"                     if  	mneumonic == "PCPIE_index" &  dup_old==1
	drop       dup_old
	
	replace    tminus3 = -0.1       if arrangementnumber == 545   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 1.5        if arrangementnumber == 545   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 2.5        if arrangementnumber == 545   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 2.5              if arrangementnumber == 545   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 2.5         if arrangementnumber == 545   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 2.5         if arrangementnumber == 545   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = .           if arrangementnumber == 545   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus4 = .           if arrangementnumber == 545   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	
	* #560 Benin. Enter wrong line (period-avg inflation) and zero as missing
	replace    tminus3 = 1.2        if arrangementnumber == 560   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 0.8        if arrangementnumber == 560   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 2.6        if arrangementnumber == 560   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 2.5              if arrangementnumber == 560   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 2.5         if arrangementnumber == 560   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 2.5         if arrangementnumber == 560   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = 2.5         if arrangementnumber == 560   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus4 = .           if arrangementnumber == 560   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	
	

	* #564 Iraq: constructed NI entered (using NI/NGDP ratio from EBS)
	replace    tminus1 = 9952.43    if arrangementnumber == 564   & mneumonic == "NI"          &  reviewsequence == "E"
	replace    t = 14145.91         if arrangementnumber == 564   & mneumonic == "NI"          &  reviewsequence == "E"
	replace    tplus1 = 18157.19    if arrangementnumber == 564   & mneumonic == "NI"          &  reviewsequence == "E"
	replace    tplus2 = 21363.90    if arrangementnumber == 564   & mneumonic == "NI"          &  reviewsequence == "E"
	replace    tplus3 = 26918.23    if arrangementnumber == 564   & mneumonic == "NI"          &  reviewsequence == "E"
	replace    tplus4 = 32495.99    if arrangementnumber == 564   & mneumonic == "NI"          &  reviewsequence == "E"




	* #598  DJIBOUTI: RGDP growth rates from EBS entered
	replace    tminus3 = 3.2        if arrangementnumber == 598   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tminus2 = 4.8        if arrangementnumber == 598   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tminus1 = 5.3        if arrangementnumber == 598   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    t = 5.9              if arrangementnumber == 598   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tplus1 = 6.9         if arrangementnumber == 598   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tplus2 = 7.3         if arrangementnumber == 598   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tplus3 = 7.9         if arrangementnumber == 598   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tplus4 = 7.7         if arrangementnumber == 598   & mneumonic == "RGDP_level"  &  reviewsequence == "E"


	* #607 Congo rep: NGDP growth from EBS entered
	replace    tminus2 = 25.9      if arrangementnumber == 607   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tminus1 = -9.4      if arrangementnumber == 607   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    t = 35.2            if arrangementnumber == 607   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus1 = -5.1       if arrangementnumber == 607   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus2 = 27.1       if arrangementnumber == 607   & mneumonic == "NGDP"        &  reviewsequence == "E"
	replace    tplus3 = 0.1        if arrangementnumber == 607   & mneumonic == "NGDP"        &  reviewsequence == "E"

	
	* #610  San Tome: RGDP growth rates from EBS entered
	replace    tminus3 = 6.7       if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tminus2 = 6         if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tminus1 = 5.8       if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    t = 5.5             if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tplus1 = 6.5        if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tplus2 = 7          if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tplus3 = 7.5        if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	replace    tplus4 = 8          if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "E"
	
	replace    tminus3 = 6.7       if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "L"
	replace    tminus2 = 6         if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "L"
	replace    tminus1 = 5.8       if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "L"
	replace    t = 4               if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "L"
	replace    tplus1 = 6          if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "L"
	replace    tplus2 = 6.5          if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "L"
	replace    tplus3 = 6.5        if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "L"
	replace    tplus4 = 6.5          if arrangementnumber == 610   & mneumonic == "RGDP_level"  &  reviewsequence == "L"
	

    * #707 Mali: updated by EBS/13/155
	replace    tminus2 = 1144.7     if arrangementnumber == 707   & mneumonic == "NCG"         &  reviewsequence == "E"
	replace    tminus1 = 889.3      if arrangementnumber == 707   & mneumonic == "NCG"         &  reviewsequence == "E"
	replace    t = 1284.9           if arrangementnumber == 707   & mneumonic == "NCG"         &  reviewsequence == "E"
	replace    tplus1 = 1498        if arrangementnumber == 707   & mneumonic == "NCG"         &  reviewsequence == "E"
	replace    tplus2 = 1548.2      if arrangementnumber == 707   & mneumonic == "NCG"         &  reviewsequence == "E"
	replace    tplus3 = 1667.9      if arrangementnumber == 707   & mneumonic == "NCG"         &  reviewsequence == "E"


	// Add typos related to L review. Added by Monica on 11.24.2020
	
		// # MADAGASCAR. Monica: updated my code. bit no impact on output becase there's WEO data available
	replace reviewsequence = strtrim(reviewsequence)
	replace tplus4 = tplus3 if arrangementnumber == 571 & reviewsequence == "L"
	replace tplus3 = tplus2 if arrangementnumber == 571 & reviewsequence == "L"
	replace tplus2 = tplus1 if arrangementnumber == 571 & reviewsequence == "L"
	replace tplus1 = t if arrangementnumber == 571 & reviewsequence == "L"
	replace t = tminus1 if arrangementnumber == 571 & reviewsequence == "L"
	replace tminus1 = tminus2 if arrangementnumber == 571 & reviewsequence == "L"
	replace tminus2 = tminus3 if arrangementnumber == 571 & reviewsequence == "L"
	replace tminus3 = . if arrangementnumber == 571 & reviewsequence == "L"
	
		
	// #579 Gabon. Monica: updated my code. bit no impact on output becase there's WEO data available
	replace tplus4 = tplus3 if arrangementnumber == 579 & reviewsequence  != "E"
	replace tplus3 = tplus2 if arrangementnumber == 579 & reviewsequence  != "E"
	replace tplus2 = tplus1 if arrangementnumber == 579 & reviewsequence != "E"
	replace tplus1 = t if arrangementnumber == 579 & reviewsequence != "E"
	replace t = tminus1 if arrangementnumber == 579 & reviewsequence != "E"
	replace tminus1 = tminus2 if arrangementnumber == 579 & reviewsequence != "E"
	replace tminus2 = tminus3 if arrangementnumber == 579 & reviewsequence != "E"
	replace tminus3 = . if arrangementnumber == 579 & reviewsequence != "E"
	
		// # 695 SOLOMON ISLANDS. move all L observations one period over for some mneumonics in arrangementnumber 695
	foreach mneumonic in FMB FBA FCG FDS FGS FFS{
		replace tplus4 = tplus3 if arrangementnumber == 695 & reviewsequence != "E" & mneumonic == "`mne'"
		replace tplus3 = tplus2 if arrangementnumber == 695 & reviewsequence != "E" & mneumonic == "`mne'"
		replace tplus2 = tplus1 if arrangementnumber == 695 & reviewsequence != "E" & mneumonic == "`mne'"
		replace tplus1 = t if arrangementnumber == 695 & reviewsequence != "E" & mneumonic == "`mne'"
		replace t = tminus1 if arrangementnumber == 695 & reviewsequence != "E" & mneumonic == "`mne'"
		replace tminus1 = tminus2 if arrangementnumber == 695 & reviewsequence != "E" & mneumonic == "`mne'"
		replace tminus2 = tminus3 if arrangementnumber == 695 & reviewsequence != "E" & mneumonic == "`mne'"
		replace tminus3 = . if arrangementnumber == 695 & reviewsequence != "E" & mneumonic == "`mne'"
	}
	
	
		// fix E and L reviewsequence mismatches on program level
	// shift 687 BFOLO L review back one period         // Monica: documented and added to my code, but no impact on output
	replace tminus3 = tminus2 if arrangementnumber == 687 & mneumonic == "BFOL_O" & reviewsequence == "L"
	replace tminus2 = tminus1 if arrangementnumber == 687 & mneumonic == "BFOL_O" & reviewsequence == "L"
	replace tminus1 = t if arrangementnumber == 687 & mneumonic == "BFOL_O" & reviewsequence == "L"
	replace t = tplus1 if arrangementnumber == 687 & mneumonic == "BFOL_O" & reviewsequence == "L"
	replace tplus1 = tplus2 if arrangementnumber == 687 & mneumonic == "BFOL_O" & reviewsequence == "L"
	replace tplus2 = tplus3 if arrangementnumber == 687 & mneumonic == "BFOL_O" & reviewsequence == "L"
	replace tplus3 = tplus4 if arrangementnumber == 687 & mneumonic == "BFOL_O" & reviewsequence == "L"
	
	
			// #572 Haiti
		replace tminus1 = 23.22 if arrangementnumber == 572 & reviewsequence == "L" & mneumonic == "GCENL" //CONFIRMED FROM COUNTRY REPORT
		
		
		
	
		// DATA ENTRY ISSUE 3: DATA ENTRY PERSON FELL INTO WRONG LINE
		// ENTERED DATA FROM ABOVE/BELOW LINE ITEM
		// 559 E FMB                              =>  Monica: documented, but did not add to do file
		replace tminus3 = 27.20944948 if arrangementnumber == 559 & reviewsequence == "E" & mneumonic == "FMB"
		replace tminus2 = 35.18181818 if arrangementnumber == 559 & reviewsequence == "E" & mneumonic == "FMB"
		replace tminus1 = 45.67541557 if arrangementnumber == 559 & reviewsequence == "E" & mneumonic == "FMB"
		replace t = 52.19000819 if arrangementnumber == 559 & reviewsequence == "E" & mneumonic == "FMB"
		replace tplus1 = 63.724 if arrangementnumber == 559 & reviewsequence == "E" & mneumonic == "FMB"
		replace tplus2 = 72.454188 if arrangementnumber == 559 & reviewsequence == "E" & mneumonic == "FMB"
		replace tplus3 = 82.96004526 if arrangementnumber == 559 & reviewsequence == "E" & mneumonic == "FMB"
		replace tplus4 = 82.96004526 if arrangementnumber == 559 & reviewsequence == "E" & mneumonic == "FMB"
	
	

	// DATA ENTRY ISSUE 3: MISSING DATA

	* #537 Serbia and Montenegro (entered period avg inflation rates)
	expand 2  if (arrangementnumber ==537 & mneumonic == "PCPIE_index"), generate (dup_old)
	replace   reviewsequence = "E"                              if dup_old==1
	replace    tminus3 = .          if arrangementnumber == 537   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = .          if arrangementnumber == 537   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 39         if arrangementnumber == 537   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 14.2             if arrangementnumber == 537   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 10          if arrangementnumber == 537   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 7           if arrangementnumber == 537   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = 5           if arrangementnumber == 537   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus4 = .           if arrangementnumber == 537   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	sort  arrangementnumber  mneumonic  reviewsequence
	
	
	replace    t = 151              if arrangementnumber == 632   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #632 MALAWI
	replace    t = 1370             if arrangementnumber == 642   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #642 TANZANIA
	replace    t = 385              if arrangementnumber == 649   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #649 ARMENIA
	replace    t = 1.67             if arrangementnumber == 683   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #683 GEORGIA
	replace    t = 506              if arrangementnumber == 686   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #686 CENTRAL AFRICAN REPUBLIC
	replace    t = 1590             if arrangementnumber == 687   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #687 TANZANIA
	replace    t = 19008            if arrangementnumber == 688   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #688 SAO TOME AND PRINCIPE
	replace    t = 260              if arrangementnumber == 689   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #689 MALAWI
	replace    t = 94.14            if arrangementnumber == 697   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #697 JAMAICA
	replace    t = 410              if arrangementnumber == 710   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #710 ARMENIA
//	replace    t = 10.95            if arrangementnumber == 711   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #711 UKRAINE
	replace    t = 214.89           if arrangementnumber == 718   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #718 YEMEN
	replace    t = 89.35            if arrangementnumber == 722   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #722 KENYA
	replace    t = 93.6202          if arrangementnumber == 723   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #723 SERBIA,REPUBLIC OF
	replace    t = 532.3            if arrangementnumber == 730   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #730 GUINEA-BISSAU
	replace    t = 143              if arrangementnumber == 738   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #738 SRI LANKA
	replace    t = 592.7            if arrangementnumber == 754   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #754 BENIN
    replace    t = 2.65             if arrangementnumber == 755   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #755 GEORGIA
    replace    t = 2489.4           if arrangementnumber == 757   & mneumonic == "ENDA"        &  reviewsequence == "E"   // #757 MONGOLIA

	* #711 Ukraine
	replace    tminus3 = 8          if arrangementnumber == 711   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tminus2 = 8          if arrangementnumber == 711   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tminus1 = 8.2         if arrangementnumber == 711   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    t = 10.6             if arrangementnumber == 711   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tplus1 = 11.6          if arrangementnumber == 711   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tplus2 = 11.9           if arrangementnumber == 711   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tplus3 = 12.2           if arrangementnumber == 711   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tplus4 = 12.5           if arrangementnumber == 711   & mneumonic == "ENDA" &  reviewsequence == "E"

	* #679 GUINEA: ENDA use R1 data (t is still a forecast)
	replace    tminus1=tminus1[_n+1]        if arrangementnumber == 679   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    t=t[_n+1]                    if arrangementnumber == 679   & mneumonic == "ENDA"        &  reviewsequence == "E"

    * #724 UKRAINE
    replace    t = 21.7             if arrangementnumber == 724   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus1 = 22.5        if arrangementnumber == 724   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus2 = 23.1        if arrangementnumber == 724   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus3 = 23.5        if arrangementnumber == 724   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus4 = 23.7        if arrangementnumber == 724   & mneumonic == "ENDA"        &  reviewsequence == "E"

	* #758 SIERRA LEONE
	replace    t = 7195             if arrangementnumber == 758   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus1 = 7195        if arrangementnumber == 758   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus2 = 7195        if arrangementnumber == 758   & mneumonic == "ENDA"        &  reviewsequence == "E"


	* #685 Gambia: inflation data from EBS entered
	replace    tminus2 = 5.80        if arrangementnumber == 685   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 4.40        if arrangementnumber == 685   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 5.00              if arrangementnumber == 685   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 6.00         if arrangementnumber == 685   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 5.00         if arrangementnumber == 685   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = 5.00         if arrangementnumber == 685   & mneumonic == "PCPIE_index" &  reviewsequence == "E"


	* #709 ALBANIA: inflation data from EBS entered
	replace    reviewsequence = "E"  if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewtype == "R2R3"
	replace    tminus3 = 1.70        if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 2.40        if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 1.90        if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 0.70              if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 2.40         if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 2.80         if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = 3            if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus4 = 3            if arrangementnumber == 709   & mneumonic == "PCPIE_index" &  reviewsequence == "E"

	* #714 TANZANIA: inflation data from EBS entered
	replace    tminus2 = 17.4        if arrangementnumber == 714   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 7.6         if arrangementnumber == 714   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 5.7               if arrangementnumber == 714   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 5            if arrangementnumber == 714   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 5            if arrangementnumber == 714   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = 5            if arrangementnumber == 714   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus4 = 5            if arrangementnumber == 714   & mneumonic == "PCPIE_index" &  reviewsequence == "E"


	* #731 SAO TOME AND PRINCIPE: inflation data from EBS entered
	replace    tminus3 = 10.4        if arrangementnumber == 731   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 7.0         if arrangementnumber == 731   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 6.4         if arrangementnumber == 731   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 4.0               if arrangementnumber == 731   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 4.0          if arrangementnumber == 731   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 3.0          if arrangementnumber == 731   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = 3.0          if arrangementnumber == 731   & mneumonic == "PCPIE_index" &  reviewsequence == "E"

	* #739 RWANDA: inflation data from EBS entered
	replace    tminus3 = .         if arrangementnumber == 739   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 2.1         if arrangementnumber == 739   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 4.5         if arrangementnumber == 739   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 4.7               if arrangementnumber == 739   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 5.0          if arrangementnumber == 739   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 5.0          if arrangementnumber == 739   & mneumonic == "PCPIE_index" &  reviewsequence == "E"

	* #741 Iraq: inflation data from EBS entered
	replace    tminus3 = 1.9         if arrangementnumber == 741   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus2 = 2.2         if arrangementnumber == 741   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tminus1 = 1.4         if arrangementnumber == 741   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    t = 2.0               if arrangementnumber == 741   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus1 = 2.0          if arrangementnumber == 741   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus2 = 2.0          if arrangementnumber == 741   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus3 = 2.0          if arrangementnumber == 741   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	replace    tplus4 = 2.0          if arrangementnumber == 741   & mneumonic == "PCPIE_index" &  reviewsequence == "E"
	

	* #572 HAITI: exchange rate data from EBS entered
	replace    t = 42               if arrangementnumber == 572   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #610 SAO TOME AND PRINCIPE: exchange rate data from EBS entered
	replace    t = 15897               if arrangementnumber == 610   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #624 MALDIVES: exchange rate data from EBS entered
	replace    t = 12.8               if arrangementnumber == 624   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #648 RWANDA: exchange rate data from EBS entered
	replace    tminus1 = 27.1        if arrangementnumber == 648   & mneumonic == "NM" &  reviewsequence == "E"
	replace    t = 27.4               if arrangementnumber == 648   & mneumonic == "NM" &  reviewsequence == "E"
	replace    tplus1 = 26.7          if arrangementnumber == 648   & mneumonic == "NM" &  reviewsequence == "E"
	
	* #651 HAITI: exchange rate data from EBS entered
	replace    t = 40               if arrangementnumber == 651   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #678 BURUNDI: exchange rate data from EBS entered
	replace    t = 1311.8               if arrangementnumber == 678   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #691 MOROCCO: exchange rate data from EBS entered
	replace    t = 8.429               if arrangementnumber == 691   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #698 CYPRUS: exchange rate data from EBS entered
	replace    t = 0.7645               if arrangementnumber == 698   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #699 TUNISIA: exchange rate data from EBS entered
	replace    t = 1.55235               if arrangementnumber == 699   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #702 UGANDA: exchange rate data from EBS entered
	replace    t = 2594.8               if arrangementnumber == 702   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #703 PAKISTAN: exchange rate data from EBS entered
	replace    t = 99.66               if arrangementnumber == 703   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #705 PAKISTAN: exchange rate data from EBS entered
	replace    t = 4334               if arrangementnumber == 705   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	
	*Duplicate trade data on #711
	expand 2  if (mneumonic == "NM" & arrangementnumber == 711), generate (nm_dup)
	expand 2  if (mneumonic == "NX" & arrangementnumber == 711), generate (nx_dup)
	
	replace reviewtype = "R0" if nm_dup == 1
	replace reviewsequence = "E" if nm_dup == 1
	
	replace reviewtype = "R0" if nx_dup == 1
	replace reviewsequence = "E" if nx_dup == 1
	drop nm_dup nx_dup
	
	
	* #711 SERBIA AND MONTENEGRO: import data from EBS entered
	replace    tminus3 = 99        if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	replace    tminus2 = 104.3        if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	replace    tminus1 = 100.8         if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	replace    t = 86.3               if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	replace    tplus1 = 89.3          if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	replace    tplus2 = 93.8          if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	replace    tplus3 =99.4          if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	replace    tplus4 =105.7          if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	
	
	* #711 SERBIA AND MONTENEGRO: export data from EBS entered
	replace    tminus3 = 88.8        if arrangementnumber == 711   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tminus2 = 90         if arrangementnumber == 711   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tminus1 = 85.4        if arrangementnumber == 711   & mneumonic == "NX" &  reviewsequence == "E"
	replace    t = 81.3               if arrangementnumber == 711   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tplus1 = 84.5          if arrangementnumber == 711   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tplus2 = 87.4          if arrangementnumber == 711   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tplus3 = 91.5          if arrangementnumber == 711   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tplus4 =96.8          if arrangementnumber == 711   & mneumonic == "NM" &  reviewsequence == "E"
	
	
	* #712 SEYCHELLES: exchange rate data from EBS entered
	replace    t = 12.13               if arrangementnumber == 712   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #713 GRENADA: export of goods and services data from EBS entered 
	replace    tminus3 = 0.2336        if arrangementnumber == 713   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tminus2 = 0.2457         if arrangementnumber == 713   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tminus1 = 0.2559        if arrangementnumber == 713   & mneumonic == "NX" &  reviewsequence == "E"
	replace    t = 0.2759              if arrangementnumber == 713   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tplus1 = 0.2865          if arrangementnumber == 713   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tplus2 = 0.3018         if arrangementnumber == 713   & mneumonic == "NX" &  reviewsequence == "E"
	replace    tplus3 = 0.3186          if arrangementnumber == 713   & mneumonic == "NX" &  reviewsequence == "E"
	
	
	* #714 TANZANIA: exchange rate data from EBS entered
	replace    t = 1646               if arrangementnumber == 714   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #726 KYRGYZ REPUBLIC: exchange rate data from EBS entered
	replace    t = 60.7523               if arrangementnumber == 726   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tminus2 = 48.4               if arrangementnumber == 726   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #731 SAO TOME AND PRINCIPE: exchange rate data from EBS entered
	replace    t = 20229               if arrangementnumber == 731   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #735 TUNISIA: exchange rate data from EBS entered
	replace    t = 2.01285               if arrangementnumber == 735   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tplus1 = 2.01285               if arrangementnumber == 735   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #739 RWANDA: exchange rate data from EBS entered
	replace    t = 807.2               if arrangementnumber == 739   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #742 MADAGASCAR: exchange rate data from EBS entered
	replace    t = 3199.21               if arrangementnumber == 742   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #749 MOLDOVA: exchange rate data from EBS entered
	replace    tminus1 = 18.8        if arrangementnumber == 749   & mneumonic == "ENDA"        &  reviewsequence == "E"
 	replace    t = 20             if arrangementnumber == 749   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus1 = 20.4        if arrangementnumber == 749   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus2 = 21        if arrangementnumber == 749   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus3 = 21.7        if arrangementnumber == 749   & mneumonic == "ENDA"        &  reviewsequence == "E"
	replace    tplus4 = 22.3        if arrangementnumber == 749   & mneumonic == "ENDA"        &  reviewsequence == "E"
	
	* #764 MAURITANIA: exchange rate data from EBS entered
	replace    t = 358.5               if arrangementnumber == 764   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #765 GUINEA: exchange rate data from EBS entered
	replace    t = 9225.31               if arrangementnumber == 765   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #766 SEYCHELLES: exchange rate data from EBS entered
	replace    t = 13.6735               if arrangementnumber == 766   & mneumonic == "ENDA" &  reviewsequence == "E"
	replace    tplus1 = 13.6735               if arrangementnumber == 766   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #768 MALAWI: exchange rate data from EBS entered
	replace    t = 725               if arrangementnumber == 768   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #769 MALAWI: exchange rate data from EBS entered
	replace    t = 2953               if arrangementnumber == 769   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #770 ARGENTINA: exchange rate data from EBS entered
	replace    reviewsequence = "E" if reviewtype == "R1" & arrangementnumber == 770 & mneumonic == "ENDA"
	replace    t = 41.25               if arrangementnumber == 770   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #772 BARBADOS: exchange rate data from EBS entered
	replace    t = 2               if arrangementnumber == 772   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #778 ARMENIA: exchange rate data from EBS entered
	replace    t = 483.75               if arrangementnumber == 778   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #781 PAKISTAN: exchange rate data from EBS entered
	replace    t = 141.3172               if arrangementnumber == 781   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #782 HONDURAS: exchange rate data from EBS entered
	replace    t = 24.4316               if arrangementnumber == 782   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #786 SAO TOME AND PRINCIPE: exchange rate data from EBS entered
	replace    t = 21.6925               if arrangementnumber == 786   & mneumonic == "ENDA" &  reviewsequence == "E"
	
	* #787 MEXICO: exchange rate data from EBS entered
	replace    t = 19.3               if arrangementnumber == 787   & mneumonic == "ENDA" &  reviewsequence == "E"
		
	//3stdev outliers Reina added here on March 9th, 2021
	* #535 URUGUAY: exchange rate data from EBS entered
	replace tminus2= 12.2     if arrangementnumber == 535  & reviewsequence == "E" & mneumonic == "ENDA"      // #535 URUGUAY
	replace tminus1= 12.3     if arrangementnumber == 535  & reviewsequence == "E" & mneumonic == "ENDA"      // #535 URUGUAY	
	
	* #733 MOZAMBIQUE: exchange rate data from EBS entered
	replace    tminus1 = 45        if arrangementnumber == 733   & mneumonic == "ENDA"        &  reviewsequence == "E"
 	replace    t = 45.9             if arrangementnumber == 733   & mneumonic == "ENDA"        &  reviewsequence == "E"	
	
	* #532 SIERRA LEONE: import data from EBS entered
	replace    tminus1 = 445.4        if arrangementnumber == 532   & mneumonic == "NM"        &  reviewsequence == "E"
 	replace    t = 607.6             if arrangementnumber == 532   & mneumonic == "NM"        &  reviewsequence == "E"		
 	replace    tplus1 = 822.7             if arrangementnumber == 532   & mneumonic == "NM"        &  reviewsequence == "E"	
 	replace    tplus2 = 804.3            if arrangementnumber == 532   & mneumonic == "NM"        &  reviewsequence == "E"	
	replace    tplus3 = 845.2             if arrangementnumber == 532   & mneumonic == "NM"        &  reviewsequence == "E"	
		
	* #538 BURUNDI: export data from EBS entered
	replace    tminus1 = 52        if arrangementnumber == 538   & mneumonic == "NX"        &  reviewsequence == "E"
 	replace    t = 38.5             if arrangementnumber == 538   & mneumonic == "NX"        &  reviewsequence == "E"		
 	replace    tplus1 = 52.7             if arrangementnumber == 538   & mneumonic == "NX"        &  reviewsequence == "E"	
 	replace    tplus2 = 53.9            if arrangementnumber == 538   & mneumonic == "NX"        &  reviewsequence == "E"	
	
	* #547 ZAMBIA: export data from EBS entered
	replace    tminus1 = 9055        if arrangementnumber == 547   & mneumonic == "NX"        &  reviewsequence == "E"
 	replace    t = 9510             if arrangementnumber == 547   & mneumonic == "NX"        &  reviewsequence == "E"		
 	replace    tplus1 = 9928             if arrangementnumber == 547   & mneumonic == "NX"        &  reviewsequence == "E"	
 	replace    tplus2 = 104998            if arrangementnumber == 547   & mneumonic == "NX"        &  reviewsequence == "E"	
	replace    tplus3 = 11215             if arrangementnumber == 547   & mneumonic == "NX"        &  reviewsequence == "E"	
	replace    tplus4 = 12017             if arrangementnumber == 547   & mneumonic == "NX"        &  reviewsequence == "E"	
	
	* #574 MAURITANIA: import data from EBS entered
	replace    tminus1 = 1807        if arrangementnumber == 574   & mneumonic == "NM"        &  reviewsequence == "E"
 	replace    t = 1687.4             if arrangementnumber == 574   & mneumonic == "NM"        &  reviewsequence == "E"		
 	replace    tplus1 = 1745.2             if arrangementnumber == 574   & mneumonic == "NM"        &  reviewsequence == "E"	
 	replace    tplus2 = 1944.4            if arrangementnumber == 574   & mneumonic == "NM"        &  reviewsequence == "E"	
	replace    tplus3 = 2224.5             if arrangementnumber == 574   & mneumonic == "NM"        &  reviewsequence == "E"		

	* #625 CONGO,DEMOCRATIC REPUBLIC OF: exchange rate data from EBS entered
	replace    tminus3 = 6535        if arrangementnumber == 625   & mneumonic == "NX"        &  reviewsequence == "E"
 	replace    tminus2 = 7107             if arrangementnumber == 625   & mneumonic == "NX"        &  reviewsequence == "E"		
	replace    tminus1 = 4482        if arrangementnumber == 625   & mneumonic == "NX"        &  reviewsequence == "E"
 	replace    t = 5098             if arrangementnumber == 625   & mneumonic == "NX"        &  reviewsequence == "E"		
 	replace    tplus1 = 6358             if arrangementnumber == 625   & mneumonic == "NX"        &  reviewsequence == "E"	
 	replace    tplus2 = 7141            if arrangementnumber == 625   & mneumonic == "NX"        &  reviewsequence == "E"	
	replace    tplus3 = 8276             if arrangementnumber == 625   & mneumonic == "NX"        &  reviewsequence == "E"		
	replace    tplus4 = 9544             if arrangementnumber == 625   & mneumonic == "NX"        &  reviewsequence == "E"	
	
	* #765 GUINEA: exchange rate data from EBS entered
	replace    tminus3 = 1958        if arrangementnumber == 765   & mneumonic == "NX"        &  reviewsequence == "E"
 	replace    tminus2 = 1636             if arrangementnumber == 765   & mneumonic == "NX"        &  reviewsequence == "E"		
	replace    tminus1 = 2471.3        if arrangementnumber == 765   & mneumonic == "NX"        &  reviewsequence == "E"
 	replace    t = 3201.2             if arrangementnumber == 765   & mneumonic == "NX"        &  reviewsequence == "E"		
 	replace    tplus1 = 3810.9             if arrangementnumber == 765   & mneumonic == "NX"        &  reviewsequence == "E"	
 	replace    tplus2 = 4438.3            if arrangementnumber == 765   & mneumonic == "NX"        &  reviewsequence == "E"	
	replace    tplus3 = 4806.2             if arrangementnumber == 765   & mneumonic == "NX"        &  reviewsequence == "E"		
	replace    tplus4 = 5101.4             if arrangementnumber == 765   & mneumonic == "NX"        &  reviewsequence == "E"		
	
	
	
	
	
	
	
	// DATA ENTRY ISSUE 4: Temporal error

	* #552 DOMINICAN: move 2 cells to the left for all variables (incl. PCPIE.index) and E reviews in MONA
	replace    tminus3 = tminus1            if arrangementnumber == 552  &  reviewsequence == "E"
	replace    tminus2 = t                  if arrangementnumber == 552  &  reviewsequence == "E"
	replace    tminus1 = tplus1             if arrangementnumber == 552  &  reviewsequence == "E"
	replace    t = tplus2                   if arrangementnumber == 552  &  reviewsequence == "E"
	replace    tplus1 = tplus3              if arrangementnumber == 552  &  reviewsequence == "E"

	// Cleaning up discrepancies in currency names:
	*gen        indicatorcurrency_end = indicatorcurrency
	*label      variable indicatorcurrency_end "Indicator Currency End"
    /*
	gen indicatorcurrency_helper="."
	gen indicatorcurrency_end_helper="."
	replace indicatorcurrency_helper="NCU (billions)" if indicatorcurrency=="Billions" & indicatorcurrency_end=="Billions"
	replace indicatorcurrency_end_helper="NCU (billions)" if indicatorcurrency=="Billions" & indicatorcurrency_end=="Billions"
	replace indicatorcurrency_helper="NCU (billions)" if indicatorcurrency=="Billions" & indicatorcurrency_end=="NCU (billions)"
	replace indicatorcurrency_end_helper="NCU (billions)" if indicatorcurrency=="NCU (billions)" & indicatorcurrency_end=="Billions"
	replace indicatorcurrency_helper="US$ (billions)" if indicatorcurrency=="Billions" & indicatorcurrency_end=="US$ (billions)"
	replace indicatorcurrency_end_helper="NCU/US$" if indicatorcurrency=="NCU/US$" & indicatorcurrency_end=="None"
	replace indicatorcurrency_helper="NCU/US$" if indicatorcurrency=="None" & indicatorcurrency_end=="NCU/US$"
	replace indicatorcurrency_end_helper="Index Number" if indicatorcurrency=="Index Number" & indicatorcurrency_end=="None"
	replace indicatorcurrency_helper="Index Number" if indicatorcurrency=="None" & indicatorcurrency_end=="Index Number"
	drop if indicatorcurrency=="NCU (billions)" & indicatorcurrency_end==" US$ (millions)"
	drop if indicatorcurrency=="US$ (billions)" & indicatorcurrency_end=="NCU (billions)"
	replace indicatorcurrency=indicatorcurrency_helper if indicatorcurrency_helper!="."
	replace indicatorcurrency_end=indicatorcurrency_end_helper if indicatorcurrency_end_helper!="."
	drop indicatorcurrency_helper indicatorcurrency_end_helper
	*/


	// DATA ENTRY ERROR: WRONG REVIEW LABEL

	* #628 KYRGYZ REPUBLIC: change L review to E
	replace    reviewsequence = "E"        if arrangementnumber == 628
	* #734 Kenya: change L review to E
	replace    reviewsequence = "E"        if arrangementnumber == 734




// Create varibles for analysis

* track the length of programs (in months)
format approvaldate %td
gen double startmonth = mofd(approvaldate)
gen double startyear = yofd(approvaldate)
gen double month = month(approvaldate)
*format enddate %td
*gen double endmonth = mofd(enddate)
*gen months=endmonth-startmonth


* Generate continental dummy variables for countries in sample (add later)

// create dummy "tminus1_is_forecast".
gen        dummy_tminus1_is_forecast  = 1  if   boarddocno_year == programyear - 1



order     arrangementnumber   arrangementtype programtype countryname countrycode initialenddate revisedenddate reviewtype  ///
          reviewsequence boarddocno  approvaldate durationofannualarrangementf durationofannualarrangementt  ///
		  indicatorcurrency mneumonic programyear  tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4

save      Mecon_cleaned_forerrorcheck, replace


********************************************
// (iii) merge IMF and NEW MONA data


use       Mecon_cleaned_forerrorcheck, clear

keep      arrangementnumber countrycode programyear  mneumonic      /* use progream year to defint t obs, not startyear */
order     arrangementnumber countrycode programyear  mneumonic
tab       mneumonic
sort      arrangementnumber countrycode programyear  mneumonic
duplicates drop



merge m:1 countrycode mneumonic using IMFdata_mergeNEWMONA
*merge m:1 countrycode mneumonic using "/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/IMFdata_mergeNEWMONA

drop      if _m==2
drop      _m
tab       mneumonic

sort      countrycode programyear mneumonic
drop      if   arrangementnumber==.


reshape   long yvalue, i(arrangementnumber mneumonic countrycode) j(weo_yearid)

sort      arrangementnumber mneumonic weo_yearid
order     arrangementnumber mneumonic weo_yearid

* declear panel data
egen      group_id=group(arrangementnumber mneumonic)
xtset     group_id weo_yearid, yearly
sort      group_id weo_yearid

gen       diff_t = weo_yearid - programyear


* now the _imf notation includes data from IMF WEO/BOP/IFS/GFS
sort      group_id weo_yearid
bysort    group_id:    gen tminus3 = l3.yvalue     if diff_t==0
bysort    group_id:    gen tminus2 = l2.yvalue     if diff_t==0
bysort    group_id:    gen tminus1 = l.yvalue      if diff_t==0
bysort    group_id:    gen t = yvalue              if diff_t==0
bysort    group_id:    gen tplus1 = f.yvalue       if diff_t==0
bysort    group_id:    gen tplus2 = f2.yvalue      if diff_t==0
bysort    group_id:    gen tplus3 = f3.yvalue      if diff_t==0
bysort    group_id:    gen tplus4 = f4.yvalue      if diff_t==0

keep      if diff_t==0     /* keep observations coming from MONA only */
keep      arrangementnumber mneumonic  countrycode t*

gen       label = "x_IMF"

append    using   Mecon_cleaned_forerrorcheck
*append    using   "/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/Mecon_cleaned_forerrorcheck.dta"
order     arrangementnumber countryname mneumonic description label reviewtype reviewsequence boarddocno programyear


replace   label = "First"                     if reviewsequence == "E"
replace   label = "Last"                      if reviewsequence == "L"
replace   label = "Intermed"                  if reviewsequence == "BLANK"

replace   reviewsequence = "x_IMF"            if label == "x_IMF"
replace   reviewtype = "x_IMF"                if label == "x_IMF"

sort      arrangementnumber mneumonic label reviewtype reviewsequence programyear


* generate growth rates:
gen       tminus2_gr = tminus2/tminus3 - 1
gen       tminus1_gr = tminus1/tminus2 - 1
gen       t_gr       = t/tminus1 - 1
gen       tplus1_gr  = tplus1/t - 1
gen       tplus2_gr  = tplus2/tplus1 - 1
gen       tplus3_gr  = tplus3/tplus2 - 1
gen       tplus4_gr  = tplus4/tplus3 - 1


// mark observations with multiple zero entries in IMF
egen    count0 = anycount(tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4), value(0)
*egen    mark_five0  = rowtotal(t tplus1 tplus2 tplus3 tplus4)
	local 	   vars="tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4"
	foreach    v in `vars' {
				  replace `v'=.    if `v'== 0  & count0 >0   &  reviewsequence == "x_IMF"
				//  replace `v'=.    if `v'== 0  & count0 >=4   &  mneumonic == "ENDA"  &  reviewsequence == "x_IMF" //reina changed from PCPIE_rate
				  *replace `v'=.    if `v'== 0  & count0 >0    &  !inlist(mneumonic,"RGDP_rate", "PCPIE_rate")  &  reviewsequence == "x_IMF"
	}
drop    count0


// create dummy to indicate meaning of trade data (goods & service & goods only)
gen       dummy_trade_goods_only = 0   // NM and NX in new MONA are supposed to be for both good and services



//  encode reviewsequence (for consistent sort of new and old MONA)
bysort    arrangementnumber mneumonic (boardactiondate):     gen  n_review = sum(boardactiondate != boardactiondate[_n-1])
sort      arrangementnumber mneumonic n_review

// fix enddate issue

replace       revisedenddate = initialenddate  if  revisedenddate==.


*drop if !inlist(mneumonic, "NM","NX", "ENDA") //Reina Added
save      newMONA_errorcheck, replace
*at cd "/Users/reinakawai/Desktop/Nowcast Research/FX Research/Data file for Theo and Reina/input files_non-MONA"


*erase     IMFdata_mergeNEWMONA.dta
erase     Mecon_cleaned_forerrorcheck.dta

********************************************************************************
*   4. Constructing our paper database
*      (i) MERGE old and new MONA            => MONAall_paper2_cleaned.dta
*      (ii) create data file for regression  =>  MONAall_paper2_regression.dta
*******************************************************************************

*****************************************************
// (i) MERGE old and new MONA   => MONAall_paper2_cleaned.dta


set more off
use newMONA_errorcheck, clear


// create t_end and t_imf variables
drop      if  reviewsequence=="BLANK"
drop      t*_gr

save temp1, replace




drop if inlist(reviewsequence,"x_IMF")

//keep      countrycode arrangementnumber mneumonic reviewsequence t*
keep countrycode countryname arrangementnumber programyear reviewtype reviewsequence mneumonic t*


rename    t  tplus0

duplicates drop //to reshape data Reina


reshape   long t, i(arrangementnumber mneumonic reviewsequence) j(t_id, string)




* now variable y refers to variable values in the long table
rename     t  y_

reshape    wide y_, i(arrangementnumber reviewsequence t_id reviewtype) j(mneumonic, string)

bro if inlist(arrangementnumber,506,537) & t_id=="plus0"

*bro arrangementnumber reviewsequence t_id y_* if inlist(arrangementnumber,506,537) & t_id=="plus0"

// generate new variables NM/ENDA and NX/ENDA and name it as NM, NX for consistency with old MONA

*reina added: new variable ********************************************
*keep countrycode weo_yearid yvalueBMG yvalueBMS yvalueBXG yvalueBXS yvalueNM yvalueNM1 yvalueNX yvalueNX1 yvalueENDA  


gen       y_NM_usd = y_BMGS
*(3,472 missing values generated)
gen       y_NX_usd = y_BXGS
*(3,480 missing values generated)

gen dum_MONA_BMGS = 1 if y_NM_usd !=.
gen dum_MONA_BXGS = 1 if y_NX_usd !=.

replace dum_MONA_BMGS = 0 if y_NM_usd ==.
replace dum_MONA_BXGS = 0 if y_NX_usd ==.



gen y_Msum_usd = y_BMG + y_BMS //(86 missing values generated)
gen y_Xsum_usd = y_BXG + y_BXS //(83 missing values generated)

*Dummy here
replace dum_MONA_BMGS = 2 if y_NM_usd ==. & y_Msum_usd !=.
replace dum_MONA_BXGS = 2 if y_NX_usd ==. & y_Xsum_usd !=.

replace   y_NM_usd = y_Msum_usd    if  y_NM_usd ==. & y_BMG != . & y_BMS != . //(3,386 real changes made)
*checked working fine:bro weo_yearid countrycode yvalueNM1 yvalueNM_usd  yvalueBMG  yvalueBMS 
replace   y_NX_usd = y_Xsum_usd    if  y_NX_usd ==. & y_BXG != . & y_BXS != . //(3,397 real changes made)


*Dummy here AGAIN
replace  dum_MONA_BMGS = 3 if y_NM_usd ==. & y_NM !=. & y_ENDA !=.

replace dum_MONA_BXGS = 3 if y_NX_usd ==. & y_NX !=. & y_ENDA !=.

replace   y_NM_usd = y_NM / y_ENDA    if  y_NM_usd ==. //23 change
replace   y_NX_usd = y_NX / y_ENDA    if  y_NX_usd ==. //19 change
/*
count if y_NM_usd ==.
  63
count if y_NX_usd ==.
  64
*/
*to be consistent with old MONA definition, set up yvalueNM_usd :=yvalueNM_usd;yvalueNX_usd :=yvalueNX_usd
drop y_NM y_NX
rename y_NM_usd  y_NM
rename y_NX_usd  y_NX

rename dum_MONA_BMGS y_dum_MONA_BMGS
rename dum_MONA_BXGS y_dum_MONA_BXGS


*bro if inlist(arrangementnumber,506,537) & t_id=="plus0"

reshape   long y_, i(arrangementnumber reviewsequence reviewtype t_id) j(mneumonic, string)

rename    y_  t
reshape   wide t, i(arrangementnumber mneumonic reviewsequence reviewtype) j(t_id, string)
rename    tplus0  t




merge 1:1 arrangementnumber mneumonic reviewsequence reviewtype using temp1
drop if _m == 1
drop _m
sort arrangementnumber mneumonic reviewsequence
save      temp, replace



*****************************NEW MONA trade data transformed to USD above***********************

// construct PCPIE_rate and RGDP_rate for new MONA
keep      if  mneumonic == "PCPIE_index"  |  mneumonic == "RGDP_level"

* generate growth rates:
gen       gr_tminus2 = tminus2/tminus3 - 1
gen       gr_tminus1 = tminus1/tminus2 - 1
gen       gr_t       = t/tminus1 - 1
gen       gr_tplus1  = tplus1/t - 1
gen       gr_tplus2  = tplus2/tplus1 - 1
gen       gr_tplus3  = tplus3/tplus2 - 1
gen       gr_tplus4  = tplus4/tplus3 - 1



* identify PCPIE_index that are actually inflation:
gen       error_PCPIE_inflation =0        if  mneumonic == "PCPIE_index"
gen       check = t/t[_n+1]               if  reviewsequence == "E"
replace   error_PCPIE_inflation=1         if  mneumonic=="PCPIE_index"    & check<0.5  &  t<=35   /* only need to fix the intial review if it's inflation (smaller number), so removed condition t/t_end>5 */
*** identified list: 510, 521, 527, 535, 539, 545,560,562,564,572,580,588,591,685,709,714,718,731,739,741 
* => #537 E is not the issue. inflation rate was entered for missing data
replace   error_PCPIE_inflation=1         if  mneumonic=="PCPIE_index"    & inlist(arrangementnumber, 556, 718)   &  reviewsequence == "E"


* identify RGDP_level othat are actualy GDP growth:
gen       error_GDP_growth = 0           if  mneumonic == "RGDP_level"
replace   error_GDP_growth = 1           if  mneumonic == "RGDP_level"   & reviewsequence == "E"  &   inlist(arrangementnumber, 598, 510, 535, 539, 610) 
replace   error_GDP_growth = 1           if  mneumonic == "RGDP_level"   & reviewsequence == "L"  &   inlist(arrangementnumber, 610) 



* fix errors in growth //to get level
replace   gr_tminus2 = tminus2/100        if  error_PCPIE_inflation==1    |    error_GDP_growth==1 
replace   gr_tminus1 = tminus1/100        if  error_PCPIE_inflation==1    |    error_GDP_growth==1   
replace   gr_t       = t/100              if  error_PCPIE_inflation==1    |    error_GDP_growth==1   
replace   gr_tplus1  = tplus1/100         if  error_PCPIE_inflation==1    |    error_GDP_growth==1   
replace   gr_tplus2  = tplus2/100         if  error_PCPIE_inflation==1    |    error_GDP_growth==1   
replace   gr_tplus3  = tplus3/100         if  error_PCPIE_inflation==1    |    error_GDP_growth==1   
replace   gr_tplus4  = tplus4/100         if  error_PCPIE_inflation==1    |    error_GDP_growth==1    


keep      arrangementnumber mneumonic countrycode reviewsequence gr_*
reshape   long gr_, i(arrangementnumber mneumonic countrycode reviewsequence) j(id, string)


replace   mneumonic = "PCPIE_rate"     if   mneumonic == "PCPIE_index"
replace   mneumonic = "RGDP_rate"      if   mneumonic == "RGDP_level"

reshape   wide gr_, i(arrangementnumber mneumonic countrycode reviewsequence) j(id, string)

rename    gr_tminus2    tminus2 
rename    gr_tminus1    tminus1
rename    gr_t          t     
rename    gr_tplus1     tplus1
rename    gr_tplus2     tplus2
rename    gr_tplus3     tplus3
rename    gr_tplus4     tplus4


// append the rest variables of new MONA
append    using temp
sort      arrangementnumber mneumonic reviewsequence 
order     arrangementnumber mneumonic reviewsequence tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4


preserve
	// keep program info for merging later
	keep      if   reviewsequence == "E"
	keep      arrangementnumber mneumonic reviewsequence countrycode boarddocno_year programyear  ///
			  approvaldate boardactiondate initialenddate revisedenddate arrangementtype 
			  
	by    arrangementnumber:   replace programyear = programyear[_n-1]           if inlist(mneumonic,"PCPIE_rate", "RGDP_rate") 
	by    arrangementnumber:   replace approvaldate = approvaldate[_n-1]         if inlist(mneumonic,"PCPIE_rate", "RGDP_rate") 
	by    arrangementnumber:   replace boarddocno_year = boarddocno_year[_n-1]   if inlist(mneumonic,"PCPIE_rate", "RGDP_rate") 
	by    arrangementnumber:   replace arrangementtype = arrangementtype[_n-1]   if inlist(mneumonic,"PCPIE_rate", "RGDP_rate") 
	by    arrangementnumber:   replace boardactiondate = boardactiondate[_n-1]  if inlist(mneumonic,"PCPIE_rate", "RGDP_rate") 
	by    arrangementnumber:   replace initialenddate = initialenddate[_n-1]  if inlist(mneumonic,"PCPIE_rate", "RGDP_rate") 
	by    arrangementnumber:   replace revisedenddate = revisedenddate[_n-1]  if inlist(mneumonic,"PCPIE_rate", "RGDP_rate") 
	
	* fix bug of #770 Argentia's ENDA missing program type in the MONA file
    replace   arrangementtype = "SBA"   if     arrangementnumber == 770  & mneumonic=="ENDA"
	save      newMONA_info, replace		  
restore
		  

// reshape data to wide
replace   reviewsequence = "_imf"            if reviewsequence == "x_IMF"
replace   reviewsequence = "_first"          if reviewsequence == "E"
replace   reviewsequence = "_end"            if reviewsequence == "L"
keep      t*  arrangementnumber mneumonic countrycode reviewsequence


reshape   wide tminus3 tminus2 tminus1 t tplus1 tplus2 tplus3 tplus4, i(arrangementnumber mneumonic countrycode) j(reviewsequence, string)

rename 	  tminus3_first  tminus3
rename    tminus2_first  tminus2
rename    tminus1_first  tminus1
rename    t_first        t
rename 	  tplus1_first   tplus1
rename 	  tplus2_first   tplus2
rename 	  tplus3_first   tplus3
rename 	  tplus4_first   tplus4

sort      arrangementnumber mneumonic
merge     1:1  arrangementnumber mneumonic using newMONA_info.dta
drop      _m


* replace missing NI with NFI when applicable
by        arrangementnumber:        egen    t_NI        = sum(t*(mneumonic=="NI"))
by        arrangementnumber:        egen    t_NFI       = sum(t*(mneumonic=="NFI"))
by        arrangementnumber:        egen    tminus1_NFI = sum(tminus1*(mneumonic=="NFI"))

drop      if    mneumonic=="NI"   &   t_NI==0  &  t_NFI*tminus1_NFI >0   // if NI is missing but NFI is not
replace   mneumonic = "NI"             if  mneumonic == "NFI"  &  t_NI==0  &  t_NFI*tminus1_NFI >0   // replace missing NI with NFI
drop      if    mneumonic=="NFI" 
drop      t_NI   t_NFI   tminus1_NFI



// use boardactiondate for new MONA

egen      forecastdate = rowmin(approvaldate boardactiondate)      //take either date is earlier
format    forecastdate %td
label     var forecastdate "Data forecasts were made. use boardactiondate/approvaldate for new MONA; approvaldate/durationfromdate for old MONA"

*gen       forecastdate = approvaldate
*gen       forecastdate = boardactiondate    if  arrangementnumber>500
*replace   forecastdate = approvaldate       if  approvaldate < forecastdate 



//!!!!!!!!! append old MONA data
append    using  oldMONA_forappend.dta

sort      arrangementnumber mneumonic 


// fix bugs of missing info
local 	   vars="programyear approvaldate forecastdate boardactiondate initialenddate revisedenddate boarddocno_year countrycode"
  foreach    v in `vars' {
	       by arrangementnumber:   replace `v' = `v'[_n-1]     if  `v'==.  &  `v'[_n-1]!=.
  }			  
by        arrangementnumber:   replace arrangementtype = arrangementtype[_n-1]     if arrangementtype==""  &  arrangementtype[_n-1]!=""
replace   programyear=1994    if  arrangementnumber==114   & mneumonic=="ENDA"
replace   programyear=2018    if  arrangementnumber==770   & mneumonic=="ENDA"


// save forecastdata in a seperate file (because different variables might come from different review)
preserve
   keep   arrangementnumber  mneumonic  forecastdate
   * rename the rate variables to avoid confusion
   replace   mneumonic = "PCPIE"            if  mneumonic == "PCPIE_rate"
   replace   mneumonic = "RGDP"             if  mneumonic == "RGDP_rate"
   save   forecastdate.dta, replace
restore

*Reina added missing values in trade data
	* #506 BOSNIA AND HERZEGOVINA: import data from EBS entered
	replace    tminus3 = 2.77        if arrangementnumber == 506   & mneumonic == "NM" 
	replace    tminus2 = 2.754         if arrangementnumber == 506   & mneumonic == "NM" 
	replace    tminus1 = 2.868         if arrangementnumber == 506   & mneumonic == "NM"
	replace    t = 2.949               if arrangementnumber == 506   & mneumonic == "NM" 
	replace    tplus1 = 3.098          if arrangementnumber == 506   & mneumonic == "NM" 
	replace    tplus2 = 3.375          if arrangementnumber == 506   & mneumonic == "NM" 
	replace    tplus3 =.          if arrangementnumber == 506   & mneumonic == "NM"
	replace    tplus4 =.          if arrangementnumber == 506   & mneumonic == "NM"
	
	
	
	* #506 BOSNIA AND HERZEGOVINA: export data from EBS entered
	replace    tminus3 = 1.296        if arrangementnumber == 506   & mneumonic == "NX"
	replace    tminus2 = 1.363         if arrangementnumber == 506   & mneumonic == "NX" 
	replace    tminus1 = 1.426         if arrangementnumber == 506   & mneumonic == "NX"
	replace    t = 1.553               if arrangementnumber == 506   & mneumonic == "NX"
	replace    tplus1 = 1.770          if arrangementnumber == 506   & mneumonic == "NX" 
	replace    tplus2 = 2.114          if arrangementnumber == 506   & mneumonic == "NX" 
	replace    tplus3 =.          if arrangementnumber == 506   & mneumonic == "NX" 
	replace    tplus4 =.          if arrangementnumber == 506   & mneumonic == "NX"
	
	
		* #537 SERBIA AND MONTENEGRO: import data from EBS entered
	replace    tminus3 = 3.538        if arrangementnumber == 537   & mneumonic == "NM" 
	replace    tminus2 = 4.004         if arrangementnumber == 537   & mneumonic == "NM" 
	replace    tminus1 = 5.16         if arrangementnumber == 537   & mneumonic == "NM" 
	replace    t = 6.857               if arrangementnumber == 537   & mneumonic == "NM"
	replace    tplus1 = 3.975          if arrangementnumber == 537   & mneumonic == "NM"
	replace    tplus2 = 8.47          if arrangementnumber == 537   & mneumonic == "NM"
	replace    tplus3 =.          if arrangementnumber == 537   & mneumonic == "NM" 
	replace    tplus4 =.          if arrangementnumber == 537   & mneumonic == "NM" 
	
	* #537 SERBIA AND MONTENEGRO: export data from EBS entered
	replace    tminus3 = 2.147        if arrangementnumber == 537   & mneumonic == "NX" 
	replace    tminus2 = 2.547         if arrangementnumber == 537   & mneumonic == "NX" 
	replace    tminus1 = 2.743        if arrangementnumber == 537   & mneumonic == "NX" 
	replace    t = 3.241               if arrangementnumber == 537   & mneumonic == "NX" 
	replace    tplus1 = 3.993          if arrangementnumber == 537   & mneumonic == "NX" 
	replace    tplus2 = 4.603          if arrangementnumber == 537   & mneumonic == "NX" 
	replace    tplus3 = 5.259          if arrangementnumber == 537   & mneumonic == "NX"
	replace    tplus4 =.          if arrangementnumber == 537   & mneumonic == "NX"


// calcualte percent change and forecast error

* percent change for variables in LEVELS 
gen       pct_first_t= t/tminus1 - 1                if !inlist(mneumonic,"PCPIE_rate", "RGDP_rate")   
gen       pct_final_t= t_end/tminus1_end - 1        if !inlist(mneumonic,"PCPIE_rate", "RGDP_rate")   
gen       pct_imf_t  = t_imf/tminus1_imf - 1        if !inlist(mneumonic,"PCPIE_rate", "RGDP_rate")   

* percent change for variables in growth rates or ratio (RGDP_rate, PCPIE_rate, NI_Y, GCECY)
replace   pct_first_t = t                  		    if inlist(mneumonic,"PCPIE_rate", "RGDP_rate")   
replace   pct_final_t = t_end        			    if inlist(mneumonic,"PCPIE_rate", "RGDP_rate")  
replace   pct_imf_t   = t_imf     					if inlist(mneumonic,"PCPIE_rate", "RGDP_rate")  

* fix percent change of NGDP entered from EBS
replace   pct_first_t = t/100              		    if  mneumonic == "NGDP"        &   inlist(arrangementnumber, 510, 539, 607)  

*Reina added missing values in trade data

	* #250 MAURITANIA: ENDA data from EBS entered
	replace    t = 0.026               if arrangementnumber == 250   & mneumonic == "ENDA"
	replace    tminus1 = 0.009               if arrangementnumber == 250   & mneumonic == "ENDA"
	
	* #502 MAURITANIA: ENDA data from EBS entered
	replace    tplus1 = 0.023               if arrangementnumber == 502   & mneumonic == "NM"
	replace    t = 0.073               if arrangementnumber == 502   & mneumonic == "NM"
	replace    tminus1 = -0.055               if arrangementnumber == 502   & mneumonic == "NM"
	replace    tminus2 = 0.215               if arrangementnumber == 502   & mneumonic == "NM"
	replace    tminus3 = -0.042               if arrangementnumber == 502   & mneumonic == "NM"
	
	* #502 MAURITANIA: ENDA data from EBS entered
	replace    tplus1 = 0.109               if arrangementnumber == 502   & mneumonic == "NX"
	replace    t = 0.112               if arrangementnumber == 502   & mneumonic == "NX"
	replace    tminus1 = -0.159               if arrangementnumber == 502   & mneumonic == "NX"
	replace    tminus2 = 0.183               if arrangementnumber == 502   & mneumonic == "NX"
	
	
	
	
* forcast error based on MONA initial and IMF data
gen       fcast_error_t_pct     = pct_final_t - pct_first_t   //  actual - forecast, changed on 9.29.2020
gen       fcast_error_t_pct_imf = pct_imf_t   - pct_first_t 


* summary of statistic
*bys       mneumonic: asdoc tabstat fcast_error_t_pct_imf,     replace stat(N mean sd min p5 p25 p50 p75 p95 max)

* remove the two level variables no longer needed
drop      if  mneumonic == "PCPIE_index"  |  mneumonic == "RGDP_level"

merge m:1 countrycode using countryname_mapping
drop if   _m==2
drop      _m 
sort      arrangementnumber mneumonic 


// specify obs using MONA last data (for verified outliers only)
gen       dummy_useMONAlast = 0
replace   dummy_useMONAlast = 1                         if  arrangementnumber == 118      &   inlist(mneumonic,"PCPIE_rate")  
replace   dummy_useMONAlast = 1                         if  arrangementnumber == 123      &   inlist(mneumonic,"ENDA")  

replace   pct_imf_t = pct_final_t                       if  dummy_useMONAlast == 1  
replace   fcast_error_t_pct_imf = fcast_error_t_pct     if  dummy_useMONAlast == 1  


// replace IMF forecast error with those generated using MONA last, when the former is missing (for missing data only)
replace   dummy_useMONAlast = 2                         if  pct_imf_t==.  & pct_final_t!=.
replace   pct_imf_t = pct_final_t                       if  dummy_useMONAlast == 2
replace   fcast_error_t_pct_imf = fcast_error_t_pct     if  dummy_useMONAlast == 2



gen       dummy_tminus1_is_forecast = 1    if   boarddocno_year == programyear - 1
replace   dummy_tminus1_is_forecast = 0    if   dummy_tminus1_is_forecast != 1  
replace   dummy_tminus1_is_forecast = 1    if   arrangementnumber == 623   // fix wrong doc issue of ANGOLA


* dummy_arrangementtype
* based on sources: https://www.imf.org/en/About/Factsheets/IMF-Lending#:~:text=The%20IMF%20assists%20countries%20hit,prevent%20and%20insure%20against%20crises.
tab       arrangementtype
gen       arrangementtype_new = arrangementtype
replace   arrangementtype_new = "LT_BOP"             if inlist(arrangementtype, "ECF", "EFF", "ECF-EFF", "PRGF-EFF")
replace   arrangementtype_new = "Poverty_Growth"     if inlist(arrangementtype, "SAF", "ESAF", "PRGF")
replace   arrangementtype_new = "Crisis"             if inlist(arrangementtype, "SBA")
replace   arrangementtype_new = "Exog_BOP_Shock"     if inlist(arrangementtype, "ESF", "SCF", "FCL", "PCL", "PLL", "SBA-ESF", "SBA-SCF")
replace   arrangementtype_new = "Non_Fin_Reform"     if inlist(arrangementtype, "PSI", "PCI")
*egen      dummy_arrangementtype = group(arrangementtype)




* dummy_region
kountry   iso3, from(iso3c)  geo(un)
drop      NAMES_STD 
rename    GEO dummy_region
replace   dummy_region = "Europe"     if countryname == "KOSOVO, REPUBLIC OF"    // fix bug of KOSOVO
replace   dummy_region = "Asia"       if countryname == "PAPUA NEW GUINEA" | countryname=="SOLOMON ISLANDS"  // change from Oceania to Asia



* dummy of income group: dummy_LIC, dummy_MIC, dummy_HIC
* use historical definition of WB: http://databank.worldbank.org/data/download/site-content/OGHIST.xls
merge    m:1 countrycode programyear  using     income_group.dta
  //, keepusing(dummy_*)
drop      if _m==2
drop      _m

replace  dummy_LIC=0 if  arrangementnumber==537  // serbia and motenego
replace  dummy_MIC=1 if  arrangementnumber==537  // serbia and motenego
replace  dummy_HIC=0 if  arrangementnumber==537  // serbia and motenego

preserve
drop      dummy_SDR_tradedata  //dummy_*_goods_only not exist
keep      arrangementnumber  programyear approvaldate initialenddate revisedenddate countrycode arrangementtype* income_group_WB  dummy*
duplicates drop arrangementnumber, force
save      MONAall_info, replace		 
restore


order     arrangementnumber mneumonic countrycode countryname iso3 arrangementtype* programyear
sort      arrangementnumber mneumonic
save      MONAall_paper2_cleaned, replace

*****************************************************
// (ii) create data file for regression  =>  MONAall_paper2_regression.dta

use      MONAall_paper2_cleaned, clear

* rename the rate variables to avoid confusion
replace   mneumonic = "PCPIE"            if  mneumonic == "PCPIE_rate"
replace   mneumonic = "RGDP"             if  mneumonic == "RGDP_rate"
keep      if    inlist(mneumonic, "NGDP", "PCPIE", "RGDP", "ENDA", "NM", "NX", "NI","NCP", "NCG") 
		
drop      if countrycode==.   

					 
keep      arrangementnumber countryname countrycode  mneumonic  pct_*  fcast_error_t_pct_imf t  tminus1

rename    pct_first_t            forecast_
rename    pct_final_t            pct_final_t_
rename    pct_imf_t              actual_  
*rename    fcast_error_t_pct      fe_mona_ 
rename    fcast_error_t_pct_imf  fe_imf_
rename    t                      t_            // keep t for NGDP to calculate the ratio of ttlaccess_to_GDP
rename    tminus1                tminus1_      // keep t-1 for NGDP to calculate the ratio of ttlaccess_to_GDP

duplicates drop
reshape   wide forecast_ actual_ pct_final_t_ fe_imf_  t_  tminus1_ , i(arrangementnumber countryname countrycode) j(mneumonic, string)

keep      arrangementnumber countryname countrycode  forecast_* actual_* pct_final_t_* fe_imf_*  t_NGDP   tminus1_NGDP t_RGDP tminus1_RGDP

* merge dummy variables
*merge 1:1 arrangementnumber using  trade_dummy_byprogram
*drop      _m
merge 1:1 arrangementnumber using MONAall_info
drop      _m


* seperate region dummy
tab       dummy_region, generate(region)
rename    region1  Africa
rename    region2  Americas
rename    region3  Asia
rename    region4  Europe
*rename    region5  Oceania


tab       arrangementtype_new, generate(type)
rename    type1    type_new_Crisis
rename    type2    type_new_Exog_BOP_Shock
rename    type3    type_new_LT_BOP
rename    type4    type_new_Poverty_Growth
rename    type5    type_new_Non_Fin_Reform


* dummy_hyper
gen       dummy_hyper = 0
replace   dummy_hyper = 1 if forecast_PCPIE > 0.25  // use forecast PCPIE instead. change on 9.28.2020


* merge total access info
merge 1:1 arrangementnumber using totalaccess.dta
drop      if _m==2
drop      _m
sum       actualamounttotalaccess   approveamounttotalaccess
replace   actualamounttotalaccess = 0     if   actualamounttotalaccess==.  // replace missing value with ZERO, unit in mil of SDR
replace   approveamounttotalaccess = 0    if   approveamounttotalaccess==.  // replace missing value with ZERO, unit in mil of SDR


*merge 1:1 arrangementnumber using "`inputfiles'/quota_formerge.dta", keepusing(quota_t)
merge 1:1 arrangementnumber using quota_formerge.dta, keepusing(quota_t)
drop      _m
replace   quota_t = 467.7    if  arrangementnumber==397   // YUGOSLAVIA 2001
replace   quota_t = 467.7    if  arrangementnumber==537   // SERBIA AND MONTENEGRO 2002


*gen       diff_access = approveamounttotalaccess - actualamounttotalaccess 
gen       accessdrawn_ratio = actualamounttotalaccess  / approveamounttotalaccess
replace   accessdrawn_ratio = 0    if   approveamounttotalaccess==0  // replace missing value with ZERO

drop      t_NGDP  t_RGDP


// total access to QUOTA in t
gen       ttlaccess_to_quota = actualamounttotalaccess/quota_t/100
sum       ttlaccess_to_quota 

gen       approveaccess_to_quota = approveamounttotalaccess/quota_t/100
sum       approveaccess_to_quota 





* merge cancelled programs info
merge 1:1 arrangementnumber using cancelled_all.dta
drop      if _m==2
drop      _m
gen       dummy_cancelled = 0
replace   dummy_cancelled = 1    if  cancelled=="Y"


* merge QPC conditionality 
merge 1:1 arrangementnumber using condition.dta
*merge 1:1 arrangementnumber using condition   /* condition.dta is file for all info , condition_t_only*/

local 	   vars="cond_ML_term_external_debt cond_bop_reserve_test cond_ceiling_external_arrears cond_credit_to_govt_public_s cond_domestic_arrears cond_fiscal_balance cond_no_new_arrears_default_ci cond_short_term_debt cond_total_domestic_credit"
  foreach    v in `vars' {
	       replace `v' = 0     if  _m==1
  }		
drop      if _m==2
drop      _m



* merge SC conditionality
merge 1:1 arrangementnumber using sc_condition.dta

local 	   vars="sc_civil_service sc_econ_stat sc_exchange_sys sc_fin_sector sc_gen_govt sc_intl_trade sc_other sc_pension sc_pub_enterprise sc_central_bank sc_labor_mkt"
  foreach    v in `vars' {
	       replace `v' = 0     if  _m==1
  }		
drop      if _m==2
drop      _m



* merge dummy for paper1 sample
*merge 1:1  arrangementnumber using  "`inputfiles'/sample_paper1.dta"
merge 1:1  arrangementnumber using  sample_paper1.dta

drop      if _m==2
drop      _m
rename    sample_paper1 dummy_paper1sample


// Paste crisis info here later
* dummy_crisis08  /  dummy_crisis97
format    approvaldate %td
*gen		  double startmonth = mofd(approvaldate)
gen 	  double startyear = yofd(approvaldate)
*gen       double month = month(approvaldate)
gen        dummy_crisis08=0
replace    dummy_crisis08=1 	if startyear==2008

gen        dummy_crisis97=0
replace    dummy_crisis97=1 	if startyear==1997



order     arrangementnumber countrycode countryname forecast_* actual_* pct_final_t_*  

*bring back the correct PCPIE of #537
	replace    forecast_PCPIE = -0.6358975        if arrangementnumber == 537  
	replace    fe_imf_PCPIE = actual_PCPIE - forecast_PCPIE  if arrangementnumber == 537 

               


*Reina added (growth rate):
	* #502 STAJIKISTAN: import data from EBS entered
	replace    forecast_NM = 0.073        if arrangementnumber == 502  
	replace    fe_imf_NM = actual_NM - forecast_NM  if arrangementnumber == 502 

	replace    forecast_NX = 0.112        if arrangementnumber == 502  
	replace    fe_imf_NX = actual_NX - forecast_NX  if arrangementnumber == 502   
	
	* #506 BOSNIA AND HERZEGOVINA: import data from EBS entered
	replace    forecast_NM = 0.02949        if arrangementnumber == 506  
	replace    fe_imf_NM = actual_NM - forecast_NM  if arrangementnumber == 506  

	replace    forecast_NX = 0.03241        if arrangementnumber == 506   
	replace    fe_imf_NX = actual_NX - forecast_NX  if arrangementnumber == 506 
	
	* #506 BOSNIA AND HERZEGOVINA: import data from EBS entered
	replace    forecast_NM = 0.02949        if arrangementnumber == 506  
	replace    fe_imf_NM = actual_NM - forecast_NM  if arrangementnumber == 506  

	replace    forecast_NX = 0.03241        if arrangementnumber == 506   
	replace    fe_imf_NX = actual_NX - forecast_NX  if arrangementnumber == 506 	
	
*Reina added on March 9th, 2021
	
	* #14 JAMAICA: import data from EBS entered
	replace    forecast_ENDA = 0.2275        if arrangementnumber == 14  
	replace    fe_imf_ENDA = actual_ENDA - forecast_ENDA  if arrangementnumber == 14 	


	* #132 SIERRA LEONE: export data from EBS entered
	replace    forecast_NX = 0.247        if arrangementnumber == 132  
	replace    fe_imf_NX = actual_NX - forecast_NX  if arrangementnumber == 132 
	
	* #347 KENYA: import data from EBS entered 
	replace    forecast_NM = 0.062        if arrangementnumber == 347  
	replace    fe_imf_NM = actual_NM - forecast_NM  if arrangementnumber == 347 	
	
	* #218 HAITI: export data from EBS entered
	replace    forecast_NX = 0.27        if arrangementnumber == 218  
	replace    fe_imf_NX = actual_NX - forecast_NX  if arrangementnumber == 218 	
	
	* #579 GABON: import data from EBS entered
	replace    forecast_NM = 0.138        if arrangementnumber == 579  
	replace    fe_imf_NM = actual_NM - forecast_NM  if arrangementnumber == 579 	
	
	* #603 ICELAND: export data from EBS entered
	replace    forecast_NX = 0.121        if arrangementnumber == 603  
	replace    fe_imf_NX = actual_NX - forecast_NX  if arrangementnumber == 603 		
	
	* #645 BURKINA FASO: import data from EBS entered
	replace    forecast_NX = 0.207        if arrangementnumber == 645  
	replace    fe_imf_NX = actual_NX - forecast_NX  if arrangementnumber == 645 
		
	* #791 BURKINA FASO: import data from EBS entered
	replace    forecast_NM = 0.113        if arrangementnumber == 791  
	replace    fe_imf_NM = actual_NM - forecast_NM  if arrangementnumber == 791 	
	
*Reina added on June 18th, 2021	
	* #128 CHAD: import data from EBS entered
	replace    forecast_NM = 0.182        if arrangementnumber == 128  
	replace    fe_imf_NM = actual_NM - forecast_NM  if arrangementnumber == 128 	
	
	
	
	
	gen endofyr_dummy =0
	replace endofyr_dummy = 1 if inlist(arrangementnumber, 95, 129, 195)
	replace actual_ENDA = 0.7216890595 if arrangementnumber == 95
	replace actual_ENDA = 0.13284374867 if arrangementnumber == 129
	replace actual_ENDA = 0.12554112554 if arrangementnumber == 195
	
	save      March8th_MONAall_paper2_regression, replace
	
* Since ethe trade currency was switched in OldMONA, we can obtain USD value by following:

replace actual_NM=. if arrangementnumber in 1/330
replace actual_NX=. if arrangementnumber in 1/330

save      append_March8th_MONAall_paper2_regression, replace

*merge 1:1 arrangementnumber using reina_NM_NX_forappend_final
use reina_NM_NX_forappend_final, clear
merge 1:1 arrangementnumber using append_March8th_MONAall_paper2_regression
drop mneumonic label _m

*Fill in the value "L" for the missing values:
replace actual_NM = -0.0060066 if arrangementnumber == 785
replace actual_NX = -0.0140474 if arrangementnumber == 785

sort arrangementnumber
order arrangementnumber countrycode forecast_ENDA-actual_NI actual_NM actual_NX actual_PCPIE-dummy_paper1sample

replace    fe_imf_ENDA = actual_ENDA - forecast_ENDA 
replace    fe_imf_NM = actual_NM - forecast_NM
replace    fe_imf_NX = actual_NX - forecast_NX           

gen prog_ex_rate = 0
replace prog_ex_rate = 1 if inlist(arrangementnumber, 273, 377, 419, 421, 572, 610, 624, 651, 678, 691, 698, 699, 702, 703, 705, 712, 714, 726, 731, 735,739, 742, 764, 765, 766,768,770,772,778,781, 782,786, 787, 10,19,733,114, 632,642,649,679,683,686,687,688,689,697,710,718,722,723,730,754,755,757,758) 

save      March8th_MONAall_paper2_regression, replace
*There are 34 program exchange rate values added:
gen prog_enda_rate = 1
replace prog_enda_rate = . if inlist(arrangementnumber, 273, 377, 419, 421, 572, 610, 624, 651, 678, 691, 698, 699, 702, 703, 705, 712, 714, 726, 731, 735,739, 742, 764, 765, 766,768,770,772,778,781, 782,786, 787, 10,19,733,114, 632,642,649,679,683,686,687,688,689,697,710,718,722,723,730,754,755,757,758) 

save      March11th_MONAall_paper2_regression2, replace

drop forecast_NCG forecast_NCP forecast_NGDP forecast_NI forecast_RGDP actual_NCG actual_NCP actual_NGDP actual_NI actual_RGDP pct_final_t_NCG pct_final_t_NCP pct_final_t_NGDP pct_final_t_NI pct_final_t_RGDP fe_imf_NCG fe_imf_NCP tminus1_NGDP fe_imf_NGDP fe_imf_NI tminus1_RGDP fe_imf_RGDP
rename forecast_NM forecast_NM_usd
rename forecast_NX forecast_NX_usd
rename actual_NM actual_NM_usd
rename actual_NX actual_NX_usd
rename pct_final_t_NM pct_final_t_NM_usd
rename pct_final_t_NX pct_final_t_NX_usd
rename fe_imf_NM fe_imf_NM_usd
rename fe_imf_NX fe_imf_NX_usd


*export excel using "USD_MONAall_paper2_regression"
gen float_ex = 0
replace float_ex = 1 if inlist(countrycode,914,912,233,238,915,258,176,536,916,542,273,921,948,288,293,566,968,965,718)
replace float_ex = 1 if inlist(arrangementnumber,84,508,510,770,92,142,215,284,376,557,602,611,649,227, 291,403,80,181,393,517,548,6,539,552,600,18,19,83,81,23,377,604,753,302,606,673,723,771,356,504,418,556,95, 711,724,776,558,26)

replace float_ex = . if inlist(arrangementnumber,77,197,198,134,308,202,4,5,752,15,597,683,11,111,14,331,21,143,236,237,290,375,703,210,320,383,531,160,601,620,735,185,599,394,535,166,368)
*77 Algeria switch to floating exchange rate on 1994 -> loan program 77 Algeria(program year 1994) shouldn't be considered.
*197,198 Azerbaijan switch to floating exchange rate on 1997 -> loan program 197&198 Azerbaijan(program year 1997) shouldn't be considered.
*134 Belarus switch to "others" exchange rate from floating on 1995 -> loan program 134 Belarus(program year 1995) shouldn't be considered.
*308 Brazil switch to floating exchange rate on 1999 -> loan program 308 Brazil(program year 1999) shouldn't be considered.
*202 Bulgaria switch to "others" exchange rate from floating on 1997 -> loan program 202 Bulgaria(program year 1997) shouldn't be considered.
merge 1:1 arrangementnumber using reinhart_rogoff_dummy
drop _m

*to make exchange rate dummy concrete:
*replace new_ex_reinrog = 2 if inlist(arrangementnumber, 25,70,123,174,223,265,273,274,89,131,196,202,224,253,271,285,305,682,709,737)
*replace new_ex_reinrog = 1 if inlist(arrangementnumber, 71,159,235,390,538,625,704,711,397)

*to make exchange rate dummy consistent with IMF data:
*replace float_dummy = 1 if inlist(arrangementnumber, 227,291,393,403,517,537,548,758,764,765,768,773,774,778,780,781,782,789,791)


merge 1:1 arrangementnumber using new_ex_reinrog
drop _m
/*
replace ex_reinrog =. if ex_reinrog ==0 //42 missing
gen ex_rr = ex_reinrog
replace ex_rr = 1 if inlist(ex_reinrog,2,3,4,5)
*/
gen forecast_RENDA = forecast_ENDA - forecast_PCPIE if forecast_ENDA!=. & forecast_PCPIE!=.
gen actual_RENDA = actual_ENDA - actual_PCPIE  if actual_ENDA!=. & actual_PCPIE!=.
gen pct_final_t_RENDA = pct_final_t_ENDA - pct_final_t_PCPIE  if  pct_final_t_ENDA !=. & pct_final_t_PCPIE !=.
*gen fe_imf_RENDA = fe_imf_ENDA - fe_imf_PCPIE  if  fe_imf_ENDA!=. & fe_imf_PCPIE!=.
gen    fe_imf_RENDA = actual_RENDA - forecast_RENDA 

*Reina added on March 16th, 2021: missing observations list from EBS doc


	
	* #250 MAURITANIA: real exchange rate data from EBS entered
	replace    forecast_RENDA = 0.026        if arrangementnumber == 250  
	replace    fe_imf_RENDA = actual_RENDA - forecast_RENDA  if arrangementnumber == 250 	
	
	* #685 GAMBIA, THE: real exchange rate data from EBS entered
	replace    forecast_RENDA = -0.073        if arrangementnumber == 685  
	replace    fe_imf_RENDA = actual_RENDA - forecast_RENDA  if arrangementnumber == 685 	

	* #750 COTE D'IVOIRE: real exchange rate data from EBS entered
	replace    forecast_RENDA = 0.012        if arrangementnumber == 750  
	replace    fe_imf_RENDA = actual_RENDA - forecast_RENDA  if arrangementnumber == 750 
	
	* #756 TOGO: real exchange rate data from EBS entered
	replace    forecast_RENDA = 0.006        if arrangementnumber == 756  
	replace    fe_imf_RENDA = actual_RENDA - forecast_RENDA  if arrangementnumber == 756 	
	
	* #761 Chad: real exchange rate data from EBS entered
	replace    forecast_RENDA = 0.045        if arrangementnumber == 761  
	replace    fe_imf_RENDA = actual_RENDA - forecast_RENDA  if arrangementnumber == 761 	
	
	* #789 LIBERIA: real exchange rate data from EBS entered
	replace    forecast_RENDA = -0.045        if arrangementnumber == 789  
	replace    fe_imf_RENDA = actual_RENDA - forecast_RENDA  if arrangementnumber == 789 
	
*Reina added on March 16th, 2021: 3stdev errors list from EBS doc	

	* #390 ECUADOR: real exchange rate data from EBS entered
	replace    forecast_RENDA = -0.225        if arrangementnumber == 390  
	replace    fe_imf_RENDA = actual_RENDA - forecast_RENDA  if arrangementnumber == 390 	
	
	* #539 DOMINICAN REPUBLIC: real exchange rate data from EBS entered
	replace    forecast_RENDA = 0.203        if arrangementnumber == 539  
	replace    fe_imf_RENDA = actual_RENDA - forecast_RENDA  if arrangementnumber == 539	
	
	/*
	*Unnecessary to add goods only data here
	* #713 ECUADOR: real exchange rate data from EBS entered
	replace    forecast_NX_usd = 0.1400497        if arrangementnumber == 713  
	replace    actual_NX_usd = 0.005435372        if arrangementnumber == 713  	
	replace    fe_imf_NX_usd = actual_NX_usd - forecast_NX_usd  if arrangementnumber == 713 	
	*/
	
	//////////////////////Construct the desired dummy variable here, created on March 16th

	
	
	*generate dummy follows ARA data:
	gen ara_ex_dummy = 0 
	replace ara_ex_dummy = 1 if inlist(new_ex_reinrog,2,3,4,5)
	replace ara_ex_dummy = 0 if inlist(new_ex_reinrog,1)
	replace ara_ex_dummy =.  if inlist(new_ex_reinrog,6,0)
	replace ara_ex_dummy = float_ex if arrangementnumber in 564/600
	
	*generate floating exchange rate countries for (4)
	gen float_dummy = ara_ex_dummy
	replace float_dummy =. if inlist(ara_ex_dummy,0,.)
	*to be consistent with IMF data:
	replace float_dummy = 1 if inlist(arrangementnumber, 227,291,393,403,517,537,548,758,764,765,768,773,774,778,780,781,782,789,791)
	
	
	gen forecast_float_ENDA = float_dummy*forecast_ENDA 
	gen actual_float_ENDA = float_dummy*actual_ENDA 
	gen pct_float_final_t_ENDA = float_dummy*pct_final_t_ENDA
	gen fe_float_imf_ENDA = float_dummy*fe_imf_ENDA
	
	
	gen forecast_float_RENDA = float_dummy*forecast_RENDA 
	gen actual_float_RENDA = float_dummy*actual_RENDA 
	gen pct_float_final_t_RENDA = float_dummy*pct_final_t_RENDA
	gen fe_float_imf_RENDA = float_dummy*fe_imf_RENDA
	
	
	
	*generate fixed exchange rate countries for (5)
	gen fixed_dummy = ara_ex_dummy
	replace fixed_dummy = 1 if inlist(ara_ex_dummy,0)
	replace fixed_dummy = 0 if inlist(ara_ex_dummy,1)
	replace fixed_dummy =. if inlist(fixed_dummy, 0,.)
	*add the data missing data based on IMF report on March 21st 2021:
	replace fixed_dummy =1 if inlist(arrangementnumber, 650,684,732,751)
	*to be consistent with IMF data: 390 equador eliminated also
	replace fixed_dummy =. if inlist(arrangementnumber, 227,291,393,403,517,537,548,758,764,765,768,773,774,778,780,781,782,789,791)
	
	drop if inlist(arrangementnumber, 804, 805)
	
	*fixed data constructed
	gen forecast_fixed_ENDA = fixed_dummy*forecast_ENDA 
	gen actual_fixed_ENDA = fixed_dummy*actual_ENDA 
	gen pct_fixed_final_t_ENDA = fixed_dummy*pct_final_t_ENDA
	gen fe_fixed_imf_ENDA = fixed_dummy*fe_imf_ENDA
	
	
	gen forecast_fixed_RENDA = fixed_dummy*forecast_RENDA 
	gen actual_fixed_RENDA = fixed_dummy*actual_RENDA 
	gen pct_fixed_final_t_RENDA = fixed_dummy*pct_final_t_RENDA
	gen fe_fixed_imf_RENDA = fixed_dummy*fe_imf_RENDA
	
	*generate adjusted exchange rate and countries with adjusted exchange rate:
	gen forecast_adj_ENDA = prog_enda_rate*forecast_ENDA 
	gen actual_adj_ENDA = prog_enda_rate*actual_ENDA 
	gen pct_adj_final_t_ENDA = prog_enda_rate*pct_final_t_ENDA
	gen fe_adj_imf_ENDA = prog_enda_rate*fe_imf_ENDA
	
	
	gen forecast_adj_RENDA = prog_enda_rate*forecast_RENDA 
	gen actual_adj_RENDA = prog_enda_rate*actual_RENDA 
	gen pct_adj_final_t_RENDA = prog_enda_rate*pct_final_t_RENDA
	gen fe_adj_imf_RENDA = prog_enda_rate*fe_imf_RENDA

	gen forecast_adj_NM_usd = prog_enda_rate*forecast_NM_usd
	gen forecast_adj_NX_usd = prog_enda_rate*forecast_NX_usd
	
	gen actual_adj_NM_usd = prog_enda_rate*actual_NM_usd
	gen actual_adj_NX_usd = prog_enda_rate*actual_NX_usd
	
	gen fe_adj_imf_NM_usd = prog_enda_rate*fe_imf_NM_usd
	gen fe_adj_imf_NX_usd = prog_enda_rate*fe_imf_NX_usd
	
	gen pct_adj_final_t_NM_usd = prog_enda_rate*pct_final_t_NM_usd
	gen pct_adj_final_t_NX_usd = prog_enda_rate*pct_final_t_NX_usd

	
	*generate trade balance data under the fixed and floating exchange rate:
	
	gen forecast_float_NM_usd = float_dummy*forecast_NM_usd
	gen forecast_float_NX_usd = float_dummy*forecast_NX_usd
	
	gen actual_float_NM_usd = float_dummy*actual_NM_usd
	gen actual_float_NX_usd = float_dummy*actual_NX_usd
	
	gen fe_float_imf_NM_usd = float_dummy*fe_imf_NM_usd
	gen fe_float_imf_NX_usd = float_dummy*fe_imf_NX_usd
	
	gen pct_float_final_t_NM_usd = float_dummy*pct_final_t_NM_usd
	gen pct_float_final_t_NX_usd = float_dummy*pct_final_t_NX_usd
	
	*generate trade balance data under the fixed exchange rate:
	gen forecast_fixed_NM_usd = fixed_dummy*forecast_NM_usd
	gen forecast_fixed_NX_usd = fixed_dummy*forecast_NX_usd
	
	gen actual_fixed_NM_usd = fixed_dummy*actual_NM_usd
	gen actual_fixed_NX_usd = fixed_dummy*actual_NX_usd	
	
	gen fe_fixed_imf_NM_usd = fixed_dummy*fe_imf_NM_usd
	gen fe_fixed_imf_NX_usd = fixed_dummy*fe_imf_NX_usd
	
	gen pct_fixed_final_t_NM_usd = fixed_dummy*pct_final_t_NM_usd
	gen pct_fixed_final_t_NX_usd = fixed_dummy*pct_final_t_NX_usd
	
	gen str23 number=string(arrangementnumber)

	gen country_number =  number + countryname
	

	* Theo checked 390 Ecuador was dollarized under 2000, and unclear what is the actual base currency
	replace forecast_fixed_ENDA =. if arrangementnumber == 390
	replace actual_fixed_ENDA =. if arrangementnumber == 390
	replace pct_fixed_final_t_ENDA =. if arrangementnumber == 390
	replace fe_fixed_imf_ENDA =. if arrangementnumber == 390
	replace forecast_fixed_RENDA =. if arrangementnumber == 390
	replace actual_fixed_RENDA =. if arrangementnumber == 390
	replace pct_fixed_final_t_RENDA =. if arrangementnumber == 390
	replace fe_fixed_imf_RENDA =. if arrangementnumber == 390
	
	rename Africa africa  
	rename Americas america  
	rename Asia asia
	rename dummy_crisis08 crisis08 
	drop pct_*
	drop *_adj_*
	drop ara_ex_dummy 
	drop *_ENDA  *_PCPIE
	drop if arrangementnumber > 800
	save X_M_E_6-27-21_updated, replace
	
	keep if cancelled != "Y"
	
	save X_M_E_6-27-21_without_cancelled, replace
	
	*To obtain the BOP programsmde only:
	use X_M_E_6-27-21_updated, clear
	
	keep if !inlist(arrangementtype, "SAF", "PSI", "PRGF-EFF", "PRGF", "PCI", "ESAF")
	
	save BOP_X_M_E_6-27-21_updated, replace
	
	
// erase files
erase     newMONA_info.dta
erase     condition.dta
erase     sc_condition.dta
erase     totalaccess.dta
erase     cancelled_all.dta
erase     append_March8th_MONAall_paper2_regression.dta
erase     ArchMecon_cleaned_forerrorcheck.dta
erase     IMFdata_mergeNEWMONA.dta
erase     IMFdata_mergeOLDMONA.dta
erase     March8th_MONAall_paper2_regression.dta
erase     March11th_MONAall_paper2_regression2.dta
erase     MONAall_paper2_cleaned.dta
erase     newMONA_errorcheck.dta
erase     oldMONA_errorcheck.dta
erase     oldMONA_forappend.dta
erase     oldMONA_reina_forappend_2.dta
erase     oldMONA_reina_forappend_BMT.dta
erase     oldMONA_reina_forappend_BXT.dta
erase     oldMONA_reina_forappend_NM.dta
erase     oldMONA_reina_forappend_NX.dta
erase     oldMONA_reina_forappend1.dta
erase     reina_NM_NX_forappend.dta
erase     reina_NM_NX_forappend_final.dta
erase     temp.dta
erase     temp1.dta
